# -*- coding: utf-8 -*-

eng_lengthened = {
    "againn": "again",
    "aghh": "agh",
    "aah": "ah",
    "aahh": "ah",
    "ahh": "ah",
    "ahaa": "aha",
    "ahha": "aha",
    "al": "all",
    "alonee": "alone",
    "alreadyy": "already",
    "allways": "always",
    "alwayss": "always",
    "amm": "am",
    "amazingg": "amazing",
    "aand": "and",
    "andd": "and",
    "annd": "and",
    "aree": "are",
    "aaw": "aww",
    "aaww": "aww",
    "aw": "aww",
    "awayy": "away",
    "awee": "awe",
    "awwe": "awe",
    "awesomee": "awesome",
    "awhh": "awh",
    "awwh": "awh",
    "awwhh": "awh",
    "ayy": "ay",
    "ayee": "aye",
    "ayye": "aye",
    "ayyee": "aye",
    "ayoo": "ayo",
    "babby": "baby",
    "babyy": "baby",
    "baack": "back",
    "backk": "back",
    "badd": "bad",
    "bee": "be",
    "bedd": "bed",
    "ben": "been",
    "bestt": "best",
    "beter": "better",
    "bihh": "bih",
    "birthdayy": "birthday",
    "bitchh": "bitch",
    "bitchess": "bitches",
    "blahh": "blah",
    "bo": "boo",
    "boii": "boi",
    "boredd": "bored",
    "boyy": "boy",
    "broo": "bro",
    "bruhh": "bruh",
    "bur": "burr",
    "butt": "but",
    "buut": "but",
    "byee": "bye",
    "cal": "call",
    "chil": "chill",
    "chilin": "chillin",
    "col": "cool",
    "coll": "cool",
    "cooll": "cool",
    "comee": "come",
    "comme": "come",
    "craazy": "crazy",
    "crazyy": "crazy",
    "crazzy": "crazy",
    "ctfuu": "ctfu",
    "ctfupp": "ctfup",
    "ctfuup": "ctfup",
    "cutee": "cute",
    "cuzz": "cuz",
    "damm": "dam",
    "daamn": "damn",
    "dammn": "damn",
    "damnn": "damn",
    "dangg": "dang",
    "dawgg": "dawg",
    "dayy": "day",
    "dayss": "days",
    "deff": "def",
    "doo": "do",
    "doee": "doe",
    "donee": "done",
    "downn": "down",
    "dudee": "dude",
    "duhh": "duh",
    "dyingg": "dying",
    "earlyy": "early",
    "ef": "eff",
    "ehh": "eh",
    "ek": "eek",
    "eem": "em",
    "emm": "em",
    "eep": "ep",
    "err": "er",
    "erbody": "errbody",
    "everr": "ever",
    "everyonee": "everyone",
    "eew": "ew",
    "eww": "ew",
    "excitedd": "excited",
    "facee": "face",
    "farr": "far",
    "fel": "feel",
    "fell": "feel",
    "finaly": "finally",
    "finee": "fine",
    "fol": "fool",
    "foll": "fool",
    "followw": "follow",
    "folow": "follow",
    "followerss": "followers",
    "folowers": "followers",
    "fre": "free",
    "fridayy": "friday",
    "fuckk": "fuck",
    "fuuck": "fuck",
    "fukk": "fuk",
    "funn": "fun",
    "funnyy": "funny",
    "gahh": "gah",
    "gamee": "game",
    "ge": "gee",
    "geting": "getting",
    "girll": "girl",
    "girrl": "girl",
    "girlss": "girls",
    "goo": "go",
    "god": "good",
    "godd": "good",
    "goodd": "good",
    "goodmorningg": "goodmorning",
    "goodnightt": "goodnight",
    "gona": "gonna",
    "goona": "gonna",
    "goshh": "gosh",
    "gota": "gotta",
    "grr": "gr",
    "greatt": "great",
    "gues": "guess",
    "guhh": "guh",
    "gurll": "gurl",
    "guyss": "guys",
    "haa": "ha",
    "hha": "ha",
    "haaha": "haha",
    "hahaa": "haha",
    "hahha": "haha",
    "hahhaa": "haha",
    "hhaha": "haha",
    "hahaaha": "hahaha",
    "hahahaa": "hahaha",
    "hahahha": "hahaha",
    "hahahhaa": "hahaha",
    "hahhaha": "hahaha",
    "hhahaha": "hahaha",
    "happyy": "happy",
    "hardd": "hard",
    "hatee": "hate",
    "haave": "have",
    "havee": "have",
    "heel": "hell",
    "hel": "hell",
    "heello": "hello",
    "helloo": "hello",
    "helo": "hello",
    "herr": "her",
    "heree": "here",
    "herre": "here",
    "heey": "hey",
    "heeyy": "hey",
    "heyy": "hey",
    "hii": "hi",
    "himm": "him",
    "hhmm": "hmm",
    "hm": "hmm",
    "hoo": "ho",
    "homee": "home",
    "homme": "home",
    "hoot": "hot",
    "hott": "hot",
    "housee": "house",
    "huhh": "huh",
    "humm": "hum",
    "hungryy": "hungry",
    "hur": "hurr",
    "idkk": "idk",
    "ight": "iight",
    "ightt": "iight",
    "il": "ill",
    "iim": "im",
    "imm": "im",
    "iin": "in",
    "inn": "in",
    "iis": "is",
    "iss": "is",
    "ishh": "ish",
    "issh": "ish",
    "iit": "it",
    "itt": "it",
    "itss": "its",
    "juss": "jus",
    "kil": "kill",
    "knoo": "kno",
    "knoow": "know",
    "knoww": "know",
    "latee": "late",
    "latte": "late",
    "laterr": "later",
    "latter": "later",
    "lawdd": "lawd",
    "leggo": "lego",
    "leggoo": "lego",
    "legoo": "lego",
    "lifee": "life",
    "liike": "like",
    "likee": "like",
    "llike": "like",
    "livee": "live",
    "lmaao": "lmao",
    "lmaaoo": "lmao",
    "lmaoo": "lmao",
    "lmboo": "lmbo",
    "lmfaao": "lmfao",
    "lmfaaoo": "lmfao",
    "lmfaoo": "lmfao",
    "lmmfao": "lmfao",
    "lok": "look",
    "llol": "lol",
    "loll": "lol",
    "lool": "lol",
    "longg": "long",
    "loove": "love",
    "lovee": "love",
    "llss": "lls",
    "ls": "lls",
    "luckyy": "lucky",
    "madd": "mad",
    "maan": "man",
    "mann": "man",
    "manee": "mane",
    "mee": "me",
    "meann": "mean",
    "meeh": "meh",
    "mehh": "meh",
    "mhmm": "mhm",
    "mmhm": "mhm",
    "mmhmm": "mhm",
    "mindd": "mind",
    "mis": "miss",
    "moneyy": "money",
    "mooney": "money",
    "moore": "more",
    "moree": "more",
    "morningg": "morning",
    "moviee": "movie",
    "muahh": "muah",
    "muchh": "much",
    "mmy": "my",
    "myy": "my",
    "naa": "na",
    "naah": "nah",
    "naahh": "nah",
    "nahh": "nah",
    "naww": "naw",
    "ned": "need",
    "neverr": "never",
    "nicee": "nice",
    "niice": "nice",
    "niga": "nigga",
    "niggaa": "nigga",
    "niggass": "niggas",
    "nightt": "night",
    "noo": "no",
    "nopee": "nope",
    "nott": "not",
    "nothingg": "nothing",
    "noww": "now",
    "oo": "ooo",
    "ode": "odee",
    "off": "of",
    "oof": "of",
    "ohh": "oh",
    "ooh": "oh",
    "oohh": "oh",
    "okk": "ok",
    "ook": "ok",
    "okaay": "okay",
    "okayy": "okay",
    "okkay": "okay",
    "omfgg": "omfg",
    "omgg": "omg",
    "onn": "on",
    "oon": "on",
    "onee": "one",
    "oop": "op",
    "opp": "op",
    "opps": "oops",
    "ops": "oops",
    "orr": "or",
    "ouu": "ou",
    "outt": "out",
    "overr": "over",
    "oww": "ow",
    "partyy": "party",
    "peoplee": "people",
    "pff": "pf",
    "pft": "pfft",
    "phonee": "phone",
    "pleasee": "please",
    "plzz": "plz",
    "pplz": "plz",
    "prettyy": "pretty",
    "pshh": "psh",
    "pssh": "psh",
    "psst": "pst",
    "pur": "purr",
    "qq": "qqq",
    "readyy": "ready",
    "reall": "real",
    "reallyy": "really",
    "realy": "really",
    "rightt": "right",
    "riight": "right",
    "rom": "room",
    "samee": "same",
    "sayy": "say",
    "se": "see",
    "sse": "see",
    "sexxy": "sexy",
    "sexyy": "sexy",
    "shh": "sh",
    "ssh": "sh",
    "sheeshh": "sheesh",
    "shii": "shi",
    "shidd": "shid",
    "shiid": "shid",
    "shiit": "shit",
    "shitt": "shit",
    "shoo": "sho",
    "shoree": "shore",
    "shoot": "shot",
    "showw": "show",
    "showerr": "shower",
    "sickk": "sick",
    "sighh": "sigh",
    "sleepp": "sleep",
    "sloww": "slow",
    "smhh": "smh",
    "soo": "so",
    "sso": "so",
    "son": "soon",
    "sonn": "soon",
    "songg": "song",
    "sorryy": "sorry",
    "stil": "still",
    "stoop": "stop",
    "stopp": "stop",
    "stuf": "stuff",
    "suckss": "sucks",
    "suree": "sure",
    "swagg": "swag",
    "swearr": "swear",
    "tel": "tell",
    "thankk": "thank",
    "thankss": "thanks",
    "thanxx": "thanx",
    "thaat": "that",
    "thatt": "that",
    "tthat": "that",
    "thatss": "thats",
    "thee": "the",
    "tthe": "the",
    "themm": "them",
    "thenn": "then",
    "theree": "there",
    "thingg": "thing",
    "thiis": "this",
    "thiss": "this",
    "thoo": "tho",
    "thoughh": "though",
    "timee": "time",
    "tiredd": "tired",
    "too": "to",
    "tto": "to",
    "todaay": "today",
    "todayy": "today",
    "tommorow": "tomorrow",
    "tommorrow": "tomorrow",
    "tomorow": "tomorrow",
    "tonightt": "tonight",
    "truu": "tru",
    "truee": "true",
    "twiiter": "twitter",
    "twiter": "twitter",
    "twitterr": "twitter",
    "ug": "ugg",
    "uggh": "ugh",
    "ugghh": "ugh",
    "ughh": "ugh",
    "uugghh": "ugh",
    "uhh": "uh",
    "uhmm": "uhm",
    "umm": "um",
    "upp": "up",
    "uss": "us",
    "vv": "vvv",
    "veryy": "very",
    "ww": "www",
    "wackk": "wack",
    "waah": "wah",
    "wahh": "wah",
    "waitt": "wait",
    "wana": "wanna",
    "wannaa": "wanna",
    "waas": "was",
    "wass": "was",
    "wassupp": "wassup",
    "wasup": "wassup",
    "waay": "way",
    "wayy": "way",
    "wee": "we",
    "wwe": "we",
    "wel": "well",
    "welcomee": "welcome",
    "whaa": "wha",
    "whaat": "what",
    "whatt": "what",
    "wheree": "where",
    "wheww": "whew",
    "whoo": "who",
    "whoaa": "whoa",
    "whop": "whoop",
    "whyy": "why",
    "wif": "wiff",
    "wil": "will",
    "wo": "woo",
    "woahh": "woah",
    "wooah": "woah",
    "wohoo": "woohoo",
    "wop": "woop",
    "wordd": "word",
    "workk": "work",
    "worldd": "world",
    "wot": "woot",
    "woow": "wow",
    "woww": "wow",
    "wtff": "wtf",
    "xdd": "xd",
    "xii": "xi",
    "yaa": "ya",
    "yahh": "yah",
    "yal": "yall",
    "yass": "yas",
    "yaay": "yay",
    "yayy": "yay",
    "yee": "ye",
    "yeaa": "yea",
    "yeeaa": "yea",
    "yeaah": "yeah",
    "yeaahh": "yeah",
    "yeahh": "yeah",
    "yeeah": "yeah",
    "yepp": "yep",
    "yess": "yes",
    "yoo": "yo",
    "yoou": "you",
    "youu": "you",
    "yuu": "yu",
    "yumm": "yum",
    "yupp": "yup",
    "yuup": "yup",
    "zz": "zzz"
}
eng_typo = {
    "Afica": "Africa",
    "Altanta": "Atlanta",
    "Ameircan": "American",
    "Amercia": "America",
    "Amercian": "American",
    "Anahiem": "Anaheim",
    "Antartic": "Antarctic",
    "Apenines": "Apennines",
    "Appenines": "Apennines",
    "Archimedian": "Archimedean",
    "Artic Circle": "Arctic Circle",
    "Artic Ocean": "Arctic Ocean",
    "Athenean": "Athenian",
    "Atheneans": "Athenians",
    "Australiasia": "Australasia",
    "Bejing": "Beijing",
    "Belguim": "Belgium",
    "Bernouilli": "Bernoulli",
    "Blitzkreig": "Blitzkrieg",
    "Bonnano": "Bonanno",
    "Brasillian": "Brazilian",
    "Brazillian": "Brazilian",
    "Brigandier": "Brigadier",
    "Britan": "Britain",
    "Britian": "Britain",
    "Brittish": "British",
    "Brussells": "Brussels",
    "Buddah": "Buddha",
    "Buddist": "Buddhist",
    "Califronia": "California",
    "Califronian": "Californian",
    "Cambrige": "Cambridge",
    "Canadaian": "Canadian",
    "Canadain": "Canadian",
    "Capetown": "Cape Town",
    "Carmalite": "Carmelite",
    "Carnagie": "Carnegie",
    "Carnagie-Mellon": "Carnegie-Mellon",
    "Carnigie": "Carnegie",
    "Carnigie-Mellon": "Carnegie-Mellon",
    "Carribbean": "Caribbean",
    "Carribean": "Caribbean",
    "Carthagian": "Carthaginian",
    "Ceasar": "Caesar",
    "Celcius": "Celsius",
    "Champange": "Champagne",
    "Charolette": "Charlotte",
    "Chattisgarh": "Chhattisgarh",
    "Chhatisgarh": "Chhattisgarh",
    "Chineese": "Chinese",
    "Chrismas": "Christmas",
    "Cincinatti": "Cincinnati",
    "Cincinnatti": "Cincinnati",
    "Coca Cola": "Coca-Cola",
    "Conneticut": "Connecticut",
    "Conventry": "Coventry",
    "Dardenelles": "Dardanelles",
    "Detriot": "Detroit",
    "Dravadian": "Dravidian",
    "Dwight Yokam": "Dwight Yoakam",
    "Euorpe": "Europe",
    "Euorpean": "European",
    "Europian": "European",
    "Europians": "Europeans",
    "Eurpean": "European",
    "Eurpoean": "European",
    "Fabruary": "February",
    "Farenheit": "Fahrenheit",
    "Febrary": "February",
    "Februaury": "February",
    "Februrary": "February",
    "Februray": "February",
    "Februsry": "February",
    "Febuary": "February",
    "Feburary": "February",
    "Ferbruary": "February",
    "Ferbuary": "February",
    "Ferburary": "February",
    "Flemmish": "Flemish",
    "Formalhaut": "Fomalhaut",
    "Foundland": "Newfoundland",
    "Franfurt": "Frankfurt",
    "Fransiscan": "Franciscan",
    "Fransiscans": "Franciscans",
    "Galations": "Galatians",
    "Gameboy": "Game Boy",
    "German Shepard": "German Shepherd",
    "German Sheperd": "German Shepherd",
    "German Shephard": "German Shepherd",
    "Ghandi": "Gandhi",
    "Godounov": "Godunov",
    "Goerge": "George",
    "Gothenberg": "Gothenburg",
    "Gottleib": "Gottlieb",
    "Government Minster": "Government Minister",
    "Greecian": "Grecian",
    "Guatamala": "Guatemala",
    "Guatamalan": "Guatemalan",
    "Guilia": "Giulia",
    "Guiliani": "Giuliani",
    "Guilio": "Giulio",
    "Guiness": "Guinness",
    "Guiseppe": "Giuseppe",
    "Habsbourg": "Habsburg",
    "Hallowean": "Halloween",
    "Hatian": "Haitian",
    "Heidelburg": "Heidelberg",
    "Ihaca": "Ithaca",
    "Illionis": "Illinois",
    "Israelies": "Israelis",
    "Israely": "Israeli",
    "Isreal": "Israel",
    "Isrealite": "Israelite",
    "Jamacia": "Jamaica",
    "Janaury": "January",
    "Janurary": "January",
    "Januray": "January",
    "Janusry": "January",
    "Japaneese": "Japanese",
    "Japanes": "Japanese",
    "Jersualem": "Jerusalem",
    "Jharkand": "Jharkhand",
    "Johanine": "Johannine",
    "Jospeh": "Joseph",
    "Juadaism": "Judaism",
    "Juadism": "Judaism",
    "Klu Klux Klan": "Ku Klux Klan",
    "Linconshire": "Lincolnshire",
    "Los Angles": "Los Angeles",
    "Lousiana": "Louisiana",
    "Lybia": "Libya",
    "Malcom": "Malcolm",
    "Manhatten": "Manhattan",
    "Marixist": "Marxist",
    "Massachussets": "Massachusetts",
    "Massachussetts": "Massachusetts",
    "Mediteranean": "Mediterranean",
    "Michagan": "Michigan",
    "Michgian": "Michigan",
    "Minesota": "Minnesota",
    "Misouri": "Missouri",
    "Missisipi": "Mississippi",
    "Missisippi": "Mississippi",
    "Mississipi": "Mississippi",
    "Monacco": "Monaco",
    "Monserrat": "Montserrat",
    "Montnana": "Montana",
    "Morisette": "Morissette",
    "Morrisette": "Morissette",
    "Morrocco": "Morocco",
    "Mythraic": "Mithraic",
    "Naploeon": "Napoleon",
    "Napolean": "Napoleon",
    "Napoleonian": "Napoleonic",
    "Nazereth": "Nazareth",
    "Niagra Falls": "Niagara Falls",
    "Norweigan": "Norwegian",
    "Novemebr": "November",
    "Novermber": "November",
    "Nullabour": "Nullarbor",
    "Nuremburg": "Nuremberg",
    "Okalahoma": "Oklahoma",
    "Ottowa": "Ottawa",
    "Palistian": "Palestinian",
    "Palistinian": "Palestinian",
    "Palistinians": "Palestinians",
    "Papanicalou": "Papanicolaou",
    "Peloponnes": "Peloponnesus",
    "Pennsilvania": "Pennsylvania",
    "Pennsylvaina": "Pennsylvania",
    "Pennyslvania": "Pennsylvania",
    "Pharoah": "Pharaoh",
    "Philadephia": "Philadelphia",
    "Philedelphia": "Philadelphia",
    "Philipines": "Philippines",
    "Philippino": "Filipino",
    "Phillipine": "Philippine",
    "Phillipines": "Philippines",
    "Phillipino": "Filipino",
    "Phillippine": "Philippine",
    "Phillippines": "Philippines",
    "Phillippino": "Filipino",
    "Phonecian": "Phoenecian",
    "Phonecian": "Phoenician",
    "Portugese": "Portuguese",
    "Postdam": "Potsdam",
    "Prauge": "Prague",
    "Premonasterians": "Premonstratensians",
    "Pricilla": "Priscilla",
    "Prime Minster": "Prime Minister",
    "Princton": "Princeton",
    "Pucini": "Puccini",
    "Puertorrican": "Puerto Rican",
    "Puertorricans": "Puerto Ricans",
    "Queenland": "Queensland",
    "Rio de Janerio": "Rio de Janeiro",
    "Rio de Janero": "Rio de Janeiro",
    "Rio de Janiero": "Rio de Janeiro",
    "Rockerfeller": "Rockefeller",
    "Russain": "Russian",
    "Russina": "Russian",
    "Russion": "Russian",
    "Sacremento": "Sacramento",
    "San Deigo": "San Diego",
    "San Franciso": "San Francisco",
    "San Fransico": "San Francisco",
    "San Fransisco": "San Francisco",
    "Sanhedrim": "Sanhedrin",
    "Saterday": "Saturday",
    "Saterdays": "Saturdays",
    "Scandanavia": "Scandinavia",
    "Scandanavian": "Scandinavian",
    "Scottland": "Scotland",
    "Septemper": "September",
    "Septmber": "September",
    "Septmeber": "September",
    "Sionist": "Zionist",
    "Sionists": "Zionists",
    "Sixtin": "Sistine",
    "Skagerak": "Skagerrak",
    "Southhampton": "Southampton",
    "Spainard": "Spaniard",
    "Sweeden": "Sweden",
    "Sweedish": "Swedish",
    "Telengana": "Telangana",
    "Teusday": "Tuesday",
    "Tiajuana": "Tijuana",
    "Tolkein": "Tolkien",
    "Tuscon": "Tucson",
    "Ukrane": "Ukraine",
    "Ukranian": "Ukrainian",
    "United Kingdon": "United Kingdom",
    "UnitesStates": "UnitedStates",
    "Venezeula": "Venezuela",
    "Venezuala": "Venezuela",
    "Venezulea": "Venezuela",
    "Volkswagon": "Volkswagen",
    "Wisconson": "Wisconsin",
    "Yorkhire": "Yorkshire",
    "Ziegfield Follies": "Ziegfeld Follies",
    "aaked": "asked",
    "aamerica": "america",
    "aand": "and",
    "aanyone": "anyone",
    "aapps": "apps",
    "abailable": "available",
    "abandonned": "abandoned",
    "abberation": "aberration",
    "abbout": "about",
    "abbrieviated": "abbreviated",
    "abbriviated": "abbreviated",
    "abbriviation": "abbreviation",
    "abcess": "abscess",
    "aberation": "aberration",
    "aberrent": "aberrant",
    "abilites": "abilities",
    "abilityes": "abilities",
    "abillity": "ability",
    "abilties": "abilities",
    "abilty": "ability",
    "abiut": "about",
    "abke": "able",
    "ablle": "able",
    "ablt": "able",
    "abnd": "and",
    "abnormalites": "abnormalities",
    "abobe": "adobe",
    "aboit": "about",
    "aboiut": "about",
    "abondon": "abandon",
    "abondoned": "abandoned",
    "abondoning": "abandoning",
    "abondons": "abandons",
    "aboout": "about",
    "aborigene": "aborigine",
    "abortificant": "abortifacient",
    "abot": "about",
    "abotu": "about",
    "abour": "about",
    "abouta": "about a",
    "abouta": "about",
    "abouth": "about",
    "abouti": "about",
    "aboutit": "about it",
    "aboutr": "about",
    "aboutt": "about",
    "aboutthe": "about the",
    "abouy": "about",
    "abouyt": "about",
    "aboyt": "about",
    "abput": "about",
    "abreviate": "abbreviate",
    "abreviated": "abbreviated",
    "abreviation": "abbreviation",
    "abritrary": "arbitrary",
    "absail": "abseil",
    "absailing": "abseiling",
    "abscence": "absence",
    "absense": "absence",
    "absolutley": "absolutely",
    "absolutly": "absolutely",
    "absorbsion": "absorption",
    "absorbtion": "absorption",
    "absorpsion": "absorption",
    "absoulte": "absolute",
    "abudance": "abundance",
    "abundacies": "abundances",
    "abundancies": "abundances",
    "abundence": "abundance",
    "abundunt": "abundant",
    "abutts": "abuts",
    "abwt": "abt",
    "acadamy": "academy",
    "acadmic": "academic",
    "accadamy": "academy",
    "accademic": "academic",
    "accademy": "academy",
    "acccess": "access",
    "acccount": "account",
    "acccused": "accused",
    "accellerate": "accelerate",
    "accelleration": "acceleration",
    "acceptence": "acceptance",
    "acceptible": "acceptable",
    "acces": "access",
    "accesed": "accessed",
    "accesories": "accessories",
    "accesory": "accessory",
    "accessable": "accessible",
    "accesss": "access",
    "accidant": "accident",
    "accidentaly": "accidentally",
    "accidentially": "accidentally",
    "accidently": "accidentally",
    "acclimitization": "acclimatization",
    "accoding": "according",
    "accomadate": "accommodate",
    "accomadated": "accommodated",
    "accomadates": "accommodates",
    "accomadating": "accommodating",
    "accomadation": "accommodation",
    "accomadations": "accommodations",
    "accomdate": "accommodate",
    "accomodate": "accommodate",
    "accomodated": "accommodated",
    "accomodates": "accommodates",
    "accomodating": "accommodating",
    "accomodation": "accommodation",
    "accomodations": "accommodations",
    "accompaning": "accompanying",
    "accompanyed": "accompanied",
    "accont": "account",
    "acconut": "account",
    "accordeon": "accordion",
    "accordian": "accordion",
    "accordind": "according",
    "accordng": "according",
    "accoreding": "according",
    "accoriding": "according",
    "accoring": "according",
    "accoumt": "account",
    "accoungts": "accounts",
    "accouns": "account",
    "accountu": "account",
    "accoustic": "acoustic",
    "accout": "account",
    "accoutn": "account",
    "accouts": "accounts",
    "accouunt": "account",
    "accquainted": "acquainted",
    "accrediation": "accreditation",
    "accredidation": "accreditation",
    "accreditate": "accredit",
    "accroding": "according",
    "accros": "across",
    "accross": "across",
    "accsess": "access",
    "acctually": "actually",
    "accually": "actually",
    "accussed": "accused",
    "acedemic": "academic",
    "acessories": "accessories",
    "acheive": "achieve",
    "acheived": "achieved",
    "acheivement": "achievement",
    "acheivements": "achievements",
    "acheives": "achieves",
    "acheiving": "achieving",
    "acheivment": "achievement",
    "acheivments": "achievements",
    "achievment": "achievement",
    "achievments": "achievements",
    "achivement": "achievement",
    "achivements": "achievements",
    "acident": "accident",
    "acking": "acting",
    "acknowldeged": "acknowledged",
    "acknowledgeing": "acknowledging",
    "acnt": "acct",
    "acocunt": "account",
    "acolade": "accolade",
    "acommercial": "commercial",
    "acommodate": "accommodate",
    "acomplish": "accomplish",
    "acomplished": "accomplished",
    "acomplishment": "accomplishment",
    "acomplishments": "accomplishments",
    "acoording": "according",
    "acoount": "account",
    "acording": "according",
    "acordingly": "accordingly",
    "acouple": "couple",
    "acquaintence": "acquaintance",
    "acquaintences": "acquaintances",
    "acquiantence": "acquaintance",
    "acquiantences": "acquaintances",
    "acquistion": "acquisition",
    "acquistions": "acquisitions",
    "acquited": "acquitted",
    "acreen": "screen",
    "acroos": "across",
    "acsess": "access",
    "actally": "actually",
    "actaully": "actually",
    "actinn": "acting",
    "actinq": "acting",
    "activite": "activate",
    "activites": "activities",
    "activly": "actively",
    "activtedfor": "activatedfor",
    "actuall": "actual",
    "actuallly": "actually",
    "actualy": "actually",
    "actully": "actually",
    "acually": "actually",
    "acuracy": "accuracy",
    "acused": "accused",
    "acustom": "accustom",
    "acustommed": "accustomed",
    "acutally": "actually",
    "adavance": "advance",
    "adavanced": "advanced",
    "adbandon": "abandon",
    "addcited": "addicted",
    "addedd": "added",
    "addeed": "added",
    "adderss": "address",
    "addiccted": "addicted",
    "addiciton": "addiction",
    "addictd": "addicted",
    "addictied": "addicted",
    "addional": "additional",
    "addionally": "additionally",
    "additcted": "addicted",
    "additinally": "additionally",
    "additionaly": "additionally",
    "additonal": "additional",
    "additonally": "additionally",
    "addittion": "addition",
    "addmission": "admission",
    "addmitted": "admitted",
    "addopt": "adopt",
    "addopted": "adopted",
    "addoptive": "adoptive",
    "addres": "address",
    "addresable": "addressable",
    "addresed": "addressed",
    "addreses": "address",
    "addresing": "addressing",
    "addressess": "addresses",
    "addtion": "addition",
    "addtional": "additional",
    "addwords": "adwords",
    "addz": "adds",
    "adecuate": "adequate",
    "aded": "added",
    "adequit": "adequate",
    "adesnse": "adsense",
    "adhear": "adhere",
    "adhearence": "adherence",
    "adhearing": "adhering",
    "adherance": "adherence",
    "adicted": "addicted",
    "adition": "addition",
    "aditional": "additional",
    "admendment": "amendment",
    "admininistrative": "administrative",
    "administartion": "administration",
    "adminstered": "administered",
    "adminstrate": "administrate",
    "adminstration": "administration",
    "adminstrative": "administrative",
    "adminstrator": "administrator",
    "admissability": "admissibility",
    "admissable": "admissible",
    "admited": "admitted",
    "admitedly": "admittedly",
    "admiting": "admitting",
    "admitt": "admit",
    "adn": "and",
    "adoby": "adobe",
    "adolecent": "adolescent",
    "adquire": "acquire",
    "adquired": "acquired",
    "adquires": "acquires",
    "adquiring": "acquiring",
    "adquisitions": "acquisitions",
    "adres": "address",
    "adresable": "addressable",
    "adresing": "addressing",
    "adress": "address",
    "adressable": "addressable",
    "adressed": "addressed",
    "adroid": "android",
    "adrwords": "adwords",
    "adsence": "adsense",
    "adsende": "adsense",
    "adsene": "adsense",
    "adsm": "ads",
    "adswords": "adwords",
    "adticle": "article",
    "advailable": "available",
    "advanage": "advantage",
    "advantagous": "advantageous",
    "advantge": "advantage",
    "adventrous": "adventurous",
    "advertisment": "advertisement",
    "advertisments": "advertisements",
    "advesary": "adversary",
    "advetising": "advertising",
    "advicea": "advice",
    "adviced": "advised",
    "advisoy": "advisory",
    "advoid": "avoid",
    "adwards": "adwords",
    "adworks": "adwords",
    "adwrods": "adwords",
    "aeriel": "aerial",
    "aeriels": "aerials",
    "aexcuse": "excuse",
    "afaid": "afraid",
    "afair": "affair",
    "afeected": "affected",
    "affectd": "affected",
    "afffected": "affected",
    "afficianados": "aficionados",
    "afficionado": "aficionado",
    "afficionados": "aficionados",
    "affilate": "affiliate",
    "affilliate": "affiliate",
    "affliate": "affiliate",
    "affter": "after",
    "afganistan": "afghanistan",
    "aford": "afford",
    "aforememtioned": "aforementioned",
    "afraind": "afraid",
    "afriad": "afraid",
    "afrom": "from",
    "after-affect": "after-effect",
    "afteraffect": "aftereffect",
    "afternood": "afternoon",
    "aftet": "after",
    "aftr": "after",
    "againist": "against",
    "againnst": "against",
    "agains": "against",
    "againsts": "against",
    "againt": "against",
    "agaisnt": "against",
    "aganist": "against",
    "aggaravates": "aggravates",
    "aggitate": "agitate",
    "aggree": "agree",
    "aggreed": "agreed",
    "aggreement": "agreement",
    "aggregious": "egregious",
    "aggresive": "aggressive",
    "agian": "again",
    "agianst": "against",
    "agin": "again",
    "aginst": "against",
    "agoogle": "google",
    "agraid": "afraid",
    "agravate": "aggravate",
    "agre": "agree",
    "agreat": "great",
    "agred": "agreed",
    "agreee": "agree",
    "agreeement": "agreement",
    "agreemnt": "agreement",
    "agregate": "aggregate",
    "agregates": "aggregates",
    "agreing": "agreeing",
    "agression": "aggression",
    "agressive": "aggressive",
    "agressively": "aggressively",
    "agressor": "aggressor",
    "agricultue": "agriculture",
    "agriculure": "agriculture",
    "agricuture": "agriculture",
    "agrieved": "aggrieve",
    "agrieved": "aggrieved",
    "agter": "after",
    "ahave": "have",
    "ahaving": "having",
    "ahev": "have",
    "ahha": "haha",
    "ahold of": "a hold of",
    "ahome": "home",
    "ahot": "shot",
    "ahould": "should",
    "ahppen": "happen",
    "ahuge": "huge",
    "ahve": "have",
    "aicraft": "aircraft",
    "aidso": "aids",
    "ainvite": "invite",
    "aiont": "aint",
    "aiport": "airport",
    "airbourne": "airborne",
    "aircaft": "aircraft",
    "aircrafts'": "aircraft's",
    "aircrafts": "aircraft",
    "airporta": "airports",
    "airrcraft": "aircraft",
    "aisian": "asian",
    "aith": "with",
    "ajacent": "adjacent",
    "ajah": "aja",
    "aje": "aja",
    "ajoin": "adjoin",
    "ajoining": "adjoining",
    "ajust": "adjust",
    "akak": "aka",
    "akward": "awkward",
    "albiet": "albeit",
    "albulm": "album",
    "alchohol": "alcohol",
    "alchoholic": "alcoholic",
    "alchol": "alcohol",
    "alcholic": "alcoholic",
    "alcohal": "alcohol",
    "alcoholical": "alcoholic",
    "aledge": "allege",
    "aledged": "alleged",
    "aledges": "alleges",
    "alege": "allege",
    "aleged": "alleged",
    "alegience": "allegiance",
    "alerady": "already",
    "algebraical": "algebraic",
    "algorhitms": "algorithms",
    "algoritm": "algorithm",
    "algoritms": "algorithms",
    "alhpa": "alpha",
    "alientating": "alienating",
    "alil": "all",
    "alink": "link",
    "alking": "talking",
    "allagory": "allegory",
    "allaince": "alliance",
    "allance": "alliance",
    "alledge": "allege",
    "alledged": "alleged",
    "alledgedly": "allegedly",
    "alledges": "alleges",
    "allegedely": "allegedly",
    "allegedy": "allegedly",
    "allegely": "allegedly",
    "allegence": "allegiance",
    "allegience": "allegiance",
    "allience": "alliance",
    "allign": "align",
    "alligned": "aligned",
    "alliviate": "alleviate",
    "alliw": "allow",
    "allk": "all",
    "allmost": "almost",
    "allopone": "allophone",
    "allopones": "allophones",
    "alloted": "allotted",
    "alloting": "allotting",
    "allready": "already",
    "allso": "also",
    "allthough": "although",
    "alltime": "all-time",
    "alltogether": "altogether",
    "allw": "allow",
    "allz": "all",
    "almoest": "almost",
    "almoust": "almost",
    "almsot": "almost",
    "alochol": "alcohol",
    "alol": "all",
    "alomst": "almost",
    "alook": "look",
    "alooks": "looks",
    "aloot": "alot",
    "alott": "alot",
    "alotted": "allotted",
    "alotting": "allotting",
    "alowed": "allowed",
    "alowing": "allowing",
    "alows": "allows",
    "alrady": "already",
    "alre": "are",
    "alreadly": "already",
    "alreadt": "already",
    "alreay": "already",
    "alreayd": "already",
    "alredy": "already",
    "alrets": "alerts",
    "alse": "else",
    "alseep": "asleep",
    "alsot": "also",
    "alsow": "also",
    "alsways": "always",
    "altenative": "alternative",
    "alterated": "altered",
    "alterenative": "alternative",
    "alternateives": "alternatives",
    "alternitives": "alternatives",
    "alterpiece": "altarpiece",
    "altho": "although",
    "althought": "although",
    "altough": "although",
    "alunch": "launch",
    "aluvial": "alluvial",
    "alwasy": "always",
    "alwaysz": "always",
    "alwayz": "always",
    "alwso": "also",
    "alwyas": "always",
    "alwys": "always",
    "amaerican": "american",
    "amaing": "amazing",
    "amake": "make",
    "amalgomated": "amalgamated",
    "amasing": "amazing",
    "amatuer": "amateur",
    "amazez": "amazed",
    "amaziong": "amazing",
    "ambigious": "ambiguous",
    "ameican": "american",
    "ameircans": "americans",
    "amendmant": "amendment",
    "amenites": "amenities",
    "amercan": "american",
    "amercian": "american",
    "amercican": "american",
    "amerian": "american",
    "americain": "american",
    "americn": "american",
    "amerliorate": "ameliorate",
    "amessage": "message",
    "amke": "make",
    "amking": "making",
    "ammass": "amass",
    "ammend": "amend",
    "ammended": "amended",
    "ammendment": "amendment",
    "ammendments": "amendments",
    "ammenity": "amenity",
    "ammount": "amount",
    "ammused": "amused",
    "amnd": "and",
    "amnisty": "amnesty",
    "amost": "most",
    "amother": "another",
    "amoung": "among",
    "amoungst": "amongst",
    "amout": "amount",
    "amuch": "much",
    "amung": "among",
    "amunition": "ammunition",
    "amuzing": "amazing",
    "amzaing": "amazing",
    "amzazon": "amazon",
    "amzing": "amazing",
    "analagous": "analogous",
    "analaytics": "analytics",
    "analitic": "analytic",
    "analitics": "analytics",
    "analiytics": "analytics",
    "analogeous": "analogous",
    "analtics": "analytics",
    "analtyics": "analytics",
    "analyics": "analytics",
    "analyitcs": "analytics",
    "analyitics": "analytics",
    "analystics": "analytics",
    "analytcs": "analytics",
    "analytica": "analytics",
    "analyttics": "analytics",
    "ananlytics": "analytics",
    "anarchim": "anarchism",
    "anarchistm": "anarchism",
    "anaylsis": "analysis",
    "anayltics": "analytics",
    "anaytics": "analytics",
    "anbd": "and",
    "anbody": "anybody",
    "ancester": "ancestor",
    "ancesteral": "ancestral",
    "ancestory": "ancestry",
    "ancilliary": "ancillary",
    "andaroid": "android",
    "andd": "and",
    "andoid": "android",
    "andriod": "android",
    "andrioid": "android",
    "androd": "android",
    "androgenous": "androgynous",
    "androgeny": "androgyny",
    "angainst": "against",
    "anglees": "angeles",
    "anice": "nice",
    "anihilate": "annihilate",
    "anihilation": "annihilation",
    "aniiversary": "anniversary",
    "anit": "aint",
    "aniversary": "anniversary",
    "ankel": "ankle",
    "anlalytics": "analytics",
    "anlaytics": "analytics",
    "anlytics": "analytics",
    "annd": "and",
    "anniverary": "anniversary",
    "anniversay": "anniversary",
    "annivesary": "anniversary",
    "annoint": "anoint",
    "annointed": "anointed",
    "annointing": "anointing",
    "annoints": "anoints",
    "annonce": "announce",
    "annoncement": "announcement",
    "annouce": "announce",
    "annouced": "announced",
    "annoucement": "announcement",
    "annouces": "announces",
    "annoucned": "announced",
    "announed": "announced",
    "annualy": "annually",
    "annuled": "annulled",
    "annyone": "anyone",
    "anoher": "another",
    "anohter": "another",
    "anomolies": "anomalies",
    "anomolous": "anomalous",
    "anomoly": "anomaly",
    "anonimity": "anonymity",
    "anotger": "another",
    "anothr": "another",
    "anounce": "announce",
    "anounced": "announced",
    "anouncement": "announcement",
    "anounces": "announces",
    "anouther": "another",
    "anoying": "annoying",
    "anoyone": "anyone",
    "anroid": "android",
    "ansalisation": "nasalisation",
    "ansalization": "nasalization",
    "ansestors": "ancestors",
    "antalytics": "analytics",
    "antartic": "antarctic",
    "antbody": "anybody",
    "anthromorphization": "anthropomorphization",
    "anthropolgist": "anthropologist",
    "anthropolgy": "anthropology",
    "antiapartheid": "anti-apartheid",
    "antropology": "anthropology",
    "anual": "annual",
    "anually": "annually",
    "anubody": "anybody",
    "anulled": "annulled",
    "anunciar": "anuncia",
    "anw": "and",
    "anwer": "answer",
    "anwesome": "awesome",
    "anwser": "answer",
    "anwsered": "answered",
    "anybdy": "anybody",
    "anyboady": "anybody",
    "anybodya": "anybody",
    "anybodyy": "anybody",
    "anyhone": "anyone",
    "anyhwere": "anywhere",
    "anyine": "anyone",
    "anyne": "anyone",
    "anyody": "anybody",
    "anyoen": "anyone",
    "anyome": "anyone",
    "anyonr": "anyone",
    "anyonw": "anyone",
    "anyoone": "anyone",
    "anyother": "any other",
    "anyt": "any",
    "anythig": "anything",
    "anythimg": "anything",
    "anytying": "anything",
    "anywone": "anyone",
    "anyy": "any",
    "aobut": "about",
    "aocial": "social",
    "aomething": "something",
    "apalca": "alpaca",
    "apalled": "appalled",
    "aparatus": "apparatus",
    "aparent": "apparent",
    "aparently": "apparently",
    "aparment": "apartment",
    "apear": "appear",
    "apearance": "appearance",
    "apeared": "appeared",
    "apearing": "appearing",
    "apears": "appears",
    "apicture": "picture",
    "aplha": "alpha",
    "aplication": "application",
    "aplications": "applications",
    "aplied": "applied",
    "aplle": "apple",
    "apllication": "application",
    "apolegetics": "apologetics",
    "apoligize": "apologize",
    "apparant": "apparent",
    "apparantly": "apparently",
    "apparentaly": "apparently",
    "apparentley": "apparently",
    "apparenty": "apparently",
    "apparetly": "apparently",
    "appart": "apart",
    "appartently": "apparently",
    "appartmant": "apartment",
    "appartment": "apartment",
    "appartments": "apartments",
    "appeareance": "appearance",
    "appearence": "appearance",
    "appearences": "appearances",
    "appearently": "apparently",
    "appeear": "appear",
    "appele": "apple",
    "appened": "happened",
    "apperance": "appearance",
    "apperances": "appearances",
    "appereance": "appearance",
    "appereances": "appearances",
    "apperent": "apparent",
    "apperently": "apparently",
    "appication": "application",
    "appilication": "application",
    "applaication": "application",
    "applciation": "application",
    "applee": "apple",
    "appli": "apple",
    "appliacation": "application",
    "applicaion": "application",
    "applicaiton": "application",
    "applicaitons": "applications",
    "applicatoin": "application",
    "applicaton": "application",
    "applictaion": "application",
    "appliction": "application",
    "applie": "apple",
    "applr": "apple",
    "appls": "apps",
    "appoinment": "appointment",
    "appointmentt": "appointment",
    "appoitment": "appointment",
    "appologies": "apologies",
    "appologize": "apologize",
    "appology": "apology",
    "apporach": "approach",
    "apporoved": "approved",
    "apportunity": "opportunity",
    "appple": "apple",
    "appps": "apps",
    "appreaciate": "appreciate",
    "apprearance": "appearance",
    "apprecaite": "appreciate",
    "appreciatet": "appreciated",
    "apprecite": "appreciate",
    "apprently": "apparently",
    "appriciate": "appreciate",
    "apprieciate": "appreciate",
    "approachs": "approaches",
    "approch": "approach",
    "appropiate": "appropriate",
    "appropraite": "appropriate",
    "appropropiate": "appropriate",
    "approproximate": "approximate",
    "approvd": "approved",
    "approxamately": "approximately",
    "approxiately": "approximately",
    "approximatley": "approximately",
    "approximatly": "approximately",
    "approximently": "approximately",
    "approximitely": "approximately",
    "appss": "apps",
    "appstroe": "appstore",
    "appsu": "apps",
    "appystore": "appstore",
    "appz": "apps",
    "apreciated": "appreciated",
    "aprehensive": "apprehensive",
    "aproach": "approach",
    "apropriate": "appropriate",
    "aproval": "approval",
    "aprox.": "approx.",
    "aproximate": "approximate",
    "aproximately": "approximately",
    "aproximation": "approximation",
    "apz": "app",
    "aqe": "age",
    "aqo": "ago",
    "aqree": "agree",
    "aqs": "as",
    "aquaduct": "aqueduct",
    "aquaintance": "acquaintance",
    "aquainted": "acquainted",
    "aquiantance": "acquaintance",
    "aquifier": "aquifer",
    "aquire": "acquire",
    "aquired": "acquired",
    "aquiring": "acquiring",
    "aquisition": "acquisition",
    "aquisitions": "acquisitions",
    "aquitted": "acquitted",
    "araid": "afraid",
    "aranged": "arranged",
    "arangement": "arrangement",
    "arbia": "arabia",
    "arbitarily": "arbitrarily",
    "arbitary": "arbitrary",
    "archaelogical": "archaeological",
    "archaelogists": "archaeologists",
    "archaelogy": "archaeology",
    "archetect": "architect",
    "archetects": "architects",
    "archetectural": "architectural",
    "archetecturally": "architecturally",
    "archetecture": "architecture",
    "archiac": "archaic",
    "archictect": "architect",
    "archimedian": "archimedean",
    "architecht": "architect",
    "architechturally": "architecturally",
    "architechture": "architecture",
    "architechtures": "architectures",
    "architectual": "architectural",
    "archivement": "achievement",
    "archs": "arches",
    "archtype": "archetype",
    "archtypes": "archetypes",
    "aready": "already",
    "areh": "are",
    "areodynamics": "aerodynamics",
    "arer": "are",
    "argubly": "arguably",
    "argueably": "arguably",
    "arguebly": "arguably",
    "arguement": "argument",
    "arguements": "arguments",
    "arial view": "aerial view",
    "ariel view": "aerial view",
    "arised": "arose",
    "ariund": "around",
    "arival": "arrival",
    "arive": "arrive",
    "arive": "drive",
    "arleady": "already",
    "armamant": "armament",
    "armistace": "armistice",
    "arogant": "arrogant",
    "arogent": "arrogant",
    "arond": "around",
    "aroud": "around",
    "aroudn": "around",
    "arouind": "around",
    "aroune": "around",
    "aroung": "around",
    "arouond": "around",
    "arrage": "arrange",
    "arragement": "arrangement",
    "arrangment": "arrangement",
    "arrangments": "arrangements",
    "arre": "are",
    "arrengement": "arrangement",
    "arrengements": "arrangements",
    "arrivie": "arrive",
    "arround": "around",
    "artcile": "article",
    "artical": "article",
    "artice": "article",
    "articel": "article",
    "artifical": "artificial",
    "artifically": "artificially",
    "artificialy": "artificially",
    "artilce": "article",
    "artillary": "artillery",
    "arund": "around",
    "asend": "ascend",
    "asetic": "ascetic",
    "asfar": "as far",
    "ashphalt": "asphalt",
    "asign": "assign",
    "asimilate": "assimilate",
    "askd": "asked",
    "askinf": "asking",
    "askn": "ask",
    "askng": "asking",
    "asknig": "asking",
    "aslo": "also",
    "asmile": "smile",
    "asociate": "associate",
    "asociated": "associated",
    "asociation": "association",
    "asorbed": "absorbed",
    "asphyxation": "asphyxiation",
    "assasin": "assassin",
    "assasinate": "assassinate",
    "assasinated": "assassinated",
    "assasinates": "assassinates",
    "assasination": "assassination",
    "assasinations": "assassinations",
    "assasined": "assassinated",
    "assasins": "assassins",
    "assassintation": "assassination",
    "asscoiate": "associate",
    "assemple": "assemble",
    "assertation": "assertion",
    "asside": "aside",
    "assimiliated": "assimilated",
    "assinate": "assassinate",
    "assination": "assassination",
    "assisnate": "assassinate",
    "assisstance": "assistance",
    "assit": "assist",
    "assitance": "assistance",
    "assitant": "assistant",
    "assocation": "association",
    "assoicate": "associate",
    "assoicated": "associated",
    "assoicates": "associates",
    "assosication": "assassination",
    "asssassans": "assassins",
    "assualt": "assault",
    "assualted": "assaulted",
    "assumme": "assume",
    "assymetric": "asymmetric",
    "assymetrical": "asymmetrical",
    "astep": "step",
    "asterick": "asterisk",
    "asteriks": "asterisk",
    "asteriod": "asteroid",
    "asthetic": "aesthetic",
    "asthetical": "aesthetical",
    "asthetically": "aesthetically",
    "asume": "assume",
    "aswell": "as well",
    "aswine": "swine",
    "asz": "as",
    "atacking": "attacking",
    "atain": "attain",
    "atarting": "starting",
    "atempt": "attempt",
    "atempting": "attempting",
    "atheistical": "atheistic",
    "athelete": "athlete",
    "atheletic": "athletic",
    "atheltic": "athletic",
    "athenean": "athenian",
    "atheneans": "athenians",
    "athiesm": "atheism",
    "athiest": "atheist",
    "athlethe": "athlete",
    "athmosphere": "atmosphere",
    "athough": "although",
    "athough": "though",
    "aticle": "article",
    "atlethe": "athlete",
    "atlot": "alot",
    "atomach": "stomach",
    "atomatically": "automatically",
    "atomsphere": "atmosphere",
    "atorney": "attorney",
    "atower": "tower",
    "atractions": "attractions",
    "atribute": "attribute",
    "atributed": "attributed",
    "atributes": "attributes",
    "attaction": "attraction",
    "attactive": "attractive",
    "attatch": "attach",
    "attemp": "attempt",
    "attemped": "attempted",
    "attemt": "attempt",
    "attemted": "attempted",
    "attemting": "attempting",
    "attemts": "attempts",
    "attendence": "attendance",
    "attendent": "attendant",
    "attendents": "attendants",
    "attened": "attended",
    "attension": "attention",
    "attept": "attempt",
    "attetion": "attention",
    "attitide": "attitude",
    "attone": "atone",
    "attributred": "attributed",
    "attrocities": "atrocities",
    "atttention": "attention",
    "atually": "actually",
    "atweetment": "tweetment",
    "audeince": "audience",
    "audiance": "audience",
    "augemented": "augmented",
    "augmentd": "augmented",
    "augmentef": "augmented",
    "augmentet": "augmented",
    "augmeted": "augmented",
    "augumented": "augmented",
    "aumented": "augmented",
    "aupported": "supported",
    "aupports": "supports",
    "auromated": "automated",
    "austrailia": "Australia",
    "austrailian": "Australian",
    "australlia": "australia",
    "auther": "author",
    "authobiographic": "autobiographic",
    "authobiography": "autobiography",
    "authorative": "authoritative",
    "authorites": "authorities",
    "authorithy": "authority",
    "authoritiers": "authorities",
    "authoritive": "authoritative",
    "authrorities": "authorities",
    "autochtonous": "autochthonous",
    "autoctonous": "autochthonous",
    "automaticly": "automatically",
    "automibile": "automobile",
    "automonomous": "autonomous",
    "autopiot": "autopilot",
    "autor": "author",
    "autorities": "authorities",
    "autority": "authority",
    "auxilary": "auxiliary",
    "auxillaries": "auxiliaries",
    "auxillary": "auxiliary",
    "auxilliaries": "auxiliaries",
    "auxilliary": "auxiliary",
    "avaiable": "available",
    "avaialable": "available",
    "avaialble": "available",
    "avaidable": "available",
    "availabe": "available",
    "availablity": "availability",
    "availablr": "available",
    "availabne": "available",
    "availabvle": "available",
    "availaible": "available",
    "availalbe": "available",
    "availalble": "available",
    "availale": "available",
    "availbale": "available",
    "availble": "available",
    "availiable": "available",
    "availible": "available",
    "availlable": "available",
    "avalable": "available",
    "avalance": "avalanche",
    "avaliable": "available",
    "avalible": "available",
    "avation": "aviation",
    "avengence": "a vengeance",
    "averageed": "averaged",
    "averege": "average",
    "avilable": "available",
    "avin": "havin",
    "aviod": "avoid",
    "avnt": "aint",
    "avoud": "avoid",
    "awared": "awarded",
    "awarenss": "awareness",
    "awarness": "awareness",
    "awating": "awaiting",
    "awayy": "away",
    "aweosme": "awesome",
    "awfil": "awful",
    "awhole": "whole",
    "awine": "swine",
    "awords": "adwords",
    "awseome": "awesome",
    "awway": "away",
    "awya": "away",
    "ayone": "anyone",
    "aything": "anything",
    "babay": "baby",
    "bacame": "became",
    "baccine": "vaccine",
    "baceause": "because",
    "bacjground": "background",
    "backberry": "blackberry",
    "backgorund": "background",
    "backi": "back",
    "backk": "back",
    "backrounds": "backgrounds",
    "backruptcy": "bankruptcy",
    "backsreet": "backstreet",
    "backsteet": "backstreet",
    "backstrteet": "backstreet",
    "backtreet": "backstreet",
    "bacq": "back",
    "baded": "based",
    "badmiton": "badminton",
    "badmitton": "badminton",
    "bady": "body",
    "baest": "best",
    "bakc": "back",
    "bakk": "back",
    "bakwards": "backwards",
    "balace": "balance",
    "balackberry": "blackberry",
    "balanace": "balance",
    "balckberry": "blackberry",
    "balence": "balance",
    "ballest": "ballast",
    "balloom": "balloon",
    "banannas": "bananas",
    "bandn": "band",
    "bandwith": "bandwidth",
    "bankf": "bank",
    "bankrupcy": "bankruptcy",
    "bannana": "banana",
    "banruptcy": "bankruptcy",
    "baord": "board",
    "baout": "about",
    "baq": "bad",
    "barly": "barely",
    "barnd": "brand",
    "basd": "based",
    "basicaly": "basically",
    "basicly": "basically",
    "batallion": "battalion",
    "batery": "battery",
    "batroom": "bathroom",
    "battary": "battery",
    "batterly": "battery",
    "battey": "battery",
    "battleing": "battling",
    "battlinq": "battling",
    "battrey": "battery",
    "battry": "battery",
    "baught": "bought",
    "baught": "caught",
    "bauk": "balk",
    "bbcz": "bbc",
    "bbeen": "been",
    "bblackberry": "blackberry",
    "bbrother": "brother",
    "bbut": "but",
    "bcak": "back",
    "bcame": "came",
    "bckground": "background",
    "bckwards": "backwards",
    "bcuz": "cuz",
    "bcz": "bc",
    "bdy": "body",
    "beacame": "became",
    "beacause": "because",
    "beachead": "beachhead",
    "beacuse": "because",
    "bealtes": "beatles",
    "beardman": "beardyman",
    "beastiality": "bestiality",
    "beatiful": "beautiful",
    "beattles": "beatles",
    "beauiful": "beautiful",
    "beaurocracy": "bureaucracy",
    "beaurocrat": "bureaucrat",
    "beaurocratic": "bureaucratic",
    "beause": "because",
    "beautifuly": "beautifully",
    "beautyfull": "beautiful",
    "becamae": "became",
    "becamed": "became",
    "becase": "because",
    "becasue": "because",
    "becauce": "because",
    "becaude": "because",
    "becaue": "because",
    "becaues": "because",
    "beccause": "because",
    "becme": "become",
    "becoause": "because",
    "becomeing": "becoming",
    "becomming": "becoming",
    "becomnig": "becoming",
    "becouse": "because",
    "becuase": "because",
    "becuse": "because",
    "bedore": "before",
    "beebn": "been",
    "beecause": "because",
    "beee": "been",
    "beeen": "been",
    "beeing": "being",
    "beem": "been",
    "beeng": "being",
    "beeter": "better",
    "beetter": "better",
    "beetween": "between",
    "beetwen": "between",
    "befoer": "before",
    "befoore": "before",
    "beforee": "before",
    "befre": "before",
    "befroe": "before",
    "begginer": "beginner",
    "begginers": "beginners",
    "beggining": "beginning",
    "begginings": "beginnings",
    "begginning": "beginning",
    "beggins": "begins",
    "beging": "begin",
    "beging": "being",
    "begining": "beginning",
    "beginings": "beginnings",
    "beginnig": "beginning",
    "beginnins": "beginning",
    "beginnning": "beginning",
    "beig": "being",
    "beign": "being",
    "beileve": "believe",
    "beinga": "being",
    "beingg": "being",
    "beinn": "being",
    "beinq": "being",
    "beleagured": "beleaguered",
    "beleif": "belief",
    "beleive": "believe",
    "beleived": "believed",
    "beleives": "believes",
    "beleiving": "believing",
    "beliebe": "believe",
    "beliee": "believe",
    "believ": "belive",
    "believeable": "believable",
    "beligum": "belgium",
    "belive": "believe",
    "beliver": "believer",
    "belligerant": "belligerent",
    "bellweather": "bellwether",
    "bemusemnt": "bemusement",
    "benchs": "benches",
    "benefical": "beneficial",
    "beneficary": "beneficiary",
    "beng": "being",
    "benificial": "beneficial",
    "benifit": "benefit",
    "benifits": "benefits",
    "bennefit": "benefit",
    "beofer": "before",
    "beofre": "before",
    "beore": "before",
    "bereau": "bureau",
    "berfore": "before",
    "bergamont": "bergamot",
    "bernadino": "bernardino",
    "bertter": "better",
    "beseige": "besiege",
    "beseiged": "besieged",
    "beseiging": "besieging",
    "besetted": "beset",
    "besst": "best",
    "bestr": "best",
    "bestt": "best",
    "beteen": "between",
    "beter": "better",
    "bettaer": "better",
    "bettar": "better",
    "bettee": "better",
    "betterh": "better",
    "betteri": "better",
    "bettero": "better",
    "betterr": "better",
    "bettery": "battery",
    "bettery": "better",
    "bettet": "better",
    "bettr": "better",
    "bettrr": "better",
    "bettter": "better",
    "betweeen": "between",
    "betweent": "between",
    "betwen": "between",
    "betwwen": "between",
    "beutiful": "beautiful",
    "beween": "between",
    "bews": "news",
    "bewteen": "between",
    "bezt": "best",
    "bfing": "being",
    "bfor": "for",
    "bfore": "before",
    "bhere": "here",
    "bicth": "bitch",
    "bieng": "being",
    "bigining": "beginning",
    "biginning": "beginning",
    "biig": "big",
    "biit": "bit",
    "bilateraly": "bilaterally",
    "bilbliography": "bibliography",
    "billingualism": "bilingualism",
    "binominal": "binomial",
    "biphone": "iphone",
    "biq": "big",
    "birf": "bird",
    "birght": "bright",
    "birtday": "birthday",
    "birthay": "birthday",
    "birthdaay": "birthday",
    "birthdayy": "birthday",
    "bisrthday": "birthday",
    "bitchh": "bitch",
    "bithday": "birthday",
    "bitrhday": "birthday",
    "biuld": "build",
    "biulding": "building",
    "biyfriend": "boyfriend",
    "biys": "boys",
    "bizzare": "bizarre",
    "blabkberry": "blackberry",
    "blacberry": "blackberry",
    "blacc": "black",
    "blaccberry": "blackberry",
    "blackbarry": "blackberry",
    "blackbberry": "blackberry",
    "blackbeery": "blackberry",
    "blackberrry": "blackberry",
    "blackberryy": "blackberry",
    "blackbery": "blackberry",
    "blackblerry": "blackberry",
    "blackburry": "blackberry",
    "blackeberry": "blackberry",
    "blackerry": "blackberry",
    "blaclberry": "blackberry",
    "blaim": "blame",
    "blaimed": "blamed",
    "blakberry": "blackberry",
    "blakc": "black",
    "blakcberry": "blackberry",
    "blakk": "black",
    "blakkberry": "blackberry",
    "blatent": "blatant",
    "blaxkberry": "blackberry",
    "blck": "black",
    "blckberry": "blackberry",
    "blessure": "blessing",
    "blmae": "blame",
    "bloge": "blog",
    "blogg": "blog",
    "blol": "lol",
    "bloosom": "blossom",
    "blossem": "blossom",
    "blowning": "blowing",
    "blst": "blast",
    "bmm": "bbm",
    "bnew": "new",
    "bno": "no",
    "boad": "board",
    "bobdy": "body",
    "bodly": "bodily",
    "bodydbuilder": "bodybuilder",
    "boey": "boy",
    "boght": "bought",
    "boight": "bought",
    "boiught": "bought",
    "bolwing": "bowling",
    "bombardement": "bombardment",
    "bombarment": "bombardment",
    "boming": "coming",
    "bondary": "boundary",
    "boogle": "google",
    "bookr": "book",
    "bookz": "books",
    "boomz": "boom",
    "booo": "book",
    "boook": "book",
    "boought": "bought",
    "bopy": "boy",
    "bopys": "boys",
    "borad": "bored",
    "boreanez": "boreanaz",
    "boreanz": "boreanaz",
    "boredd": "bored",
    "borh": "born",
    "borke": "broke",
    "borred": "bored",
    "borther": "brother",
    "borthers": "brothers",
    "bothh": "both",
    "botle": "bottle",
    "bottem": "bottom",
    "botu": "bout",
    "bougt": "bought",
    "bouh": "bout",
    "bouht": "bought",
    "bouling": "bowling",
    "boundries": "boundaries",
    "boundry": "boundary",
    "boutt": "bout",
    "boutz": "bout",
    "bouyancy": "buoyancy",
    "bouyant": "buoyant",
    "bowking": "bowling",
    "bowlef": "bowled",
    "bowlig": "bowling",
    "bowlinq": "bowling",
    "bowlng": "bowling",
    "bowt": "bout",
    "boyant": "buoyant",
    "boyfreind": "boyfriend",
    "boys's": "boys'",
    "bphone": "iphone",
    "bpought": "bought",
    "bprn": "born",
    "bqck": "back",
    "bradcast": "broadcast",
    "braek": "break",
    "brakish": "brackish",
    "braqnd": "brand",
    "breakthough": "breakthrough",
    "breakthroughts": "breakthroughs",
    "breand": "brand",
    "breat": "beat",
    "breif": "brief",
    "breifcase": "briefcase",
    "breifly": "briefly",
    "brethen": "brethren",
    "bretheren": "brethren",
    "brethrens": "brethren",
    "briano": "brian",
    "bribary": "bribery",
    "brid": "bird",
    "bridqe": "bridge",
    "brigde": "bridge",
    "briliant": "brilliant",
    "brillant": "brilliant",
    "brimestone": "brimstone",
    "brimg": "bring",
    "brinn": "brin",
    "britghtcove": "brightcove",
    "brithday": "birthday",
    "brither": "brother",
    "brke": "broke",
    "brlieve": "believe",
    "broacasted": "broadcast",
    "broadacasting": "broadcasting",
    "broady": "broadly",
    "brodcast": "broadcast",
    "broght": "brought",
    "broowser": "browser",
    "broser": "browser",
    "broswer": "browser",
    "brotherr": "brother",
    "brth": "birth",
    "brther": "brother",
    "brushn": "brush",
    "bsafe": "safe",
    "bsckup": "backup",
    "bsing": "using",
    "bsst": "best",
    "bsuiness": "business",
    "btetter": "better",
    "btich": "bitch",
    "btter": "better",
    "btween": "between",
    "buccanners": "buccaneers",
    "budle": "bundle",
    "buget": "budget",
    "buggle": "boggle",
    "bugi": "bug",
    "bugz": "bug",
    "buh": "but",
    "buht": "but",
    "buiding": "building",
    "buidling": "building",
    "buiiding": "building",
    "buildng": "building",
    "builiding": "building",
    "builidng": "building",
    "builing": "building",
    "builld": "build",
    "buisness": "business",
    "buisnessman": "businessman",
    "buks": "bucks",
    "buld": "build",
    "bulding": "building",
    "bulid": "build",
    "buliding": "building",
    "bulliten": "bulletin",
    "bumber": "number",
    "bumch": "bunch",
    "buoancy": "buoyancy",
    "buring": "during",
    "burrial": "burial",
    "burried": "buried",
    "burrying": "burying",
    "busb": "bus",
    "busiiness": "business",
    "busines": "business",
    "busineses": "business",
    "businesess": "businesses",
    "businessem": "businesses",
    "businness": "business",
    "businss": "business",
    "busness": "business",
    "bussines": "business",
    "bussiness": "business",
    "buttond": "button",
    "buttonles": "buttonless",
    "buut": "but",
    "bux": "buy",
    "buyinq": "buying",
    "buyng": "buying",
    "buyt": "buy",
    "buzy": "busy",
    "bve": "be",
    "bwitter": "twitter",
    "bxtch": "bitch",
    "byepass": "bypass",
    "bytch": "bitch",
    "byuing": "buying",
    "caant": "cant",
    "cacaphonous": "cacophonous",
    "cacaphony": "cacophony",
    "caccination": "vaccination",
    "caculater": "calculator",
    "cacuses": "caucuses",
    "caeses": "cases",
    "cahnge": "change",
    "cahracters": "characters",
    "caht": "chat",
    "caight": "caught",
    "calaber": "caliber",
    "calandar": "calendar",
    "calculater": "calculator",
    "calculs": "calculus",
    "calcultor": "calculator",
    "caled": "called",
    "calenar": "calendar",
    "calenders": "calendars",
    "califorina": "california",
    "caligraphy": "calligraphy",
    "caling": "calling",
    "callled": "called",
    "caluclate": "calculate",
    "caluclated": "calculated",
    "caluculate": "calculate",
    "caluculated": "calculated",
    "calulate": "calculate",
    "calulated": "calculated",
    "calulater": "calculator",
    "camea": "camera",
    "camed": "came",
    "cameraa": "camera",
    "cameraderie": "camaraderie",
    "camoflage": "camouflage",
    "campagin": "campaign",
    "campain": "campaign",
    "campains": "campaigns",
    "camraderie": "camaraderie",
    "camt": "cant",
    "cancle": "cancel",
    "cancled": "canceled",
    "candadate": "candidate",
    "candiate": "candidate",
    "candidiate": "candidate",
    "canidate": "candidate",
    "cannister": "canister",
    "cannisters": "canisters",
    "cannnot": "cannot",
    "cannonical": "canonical",
    "cannotation": "connotation",
    "cannotations": "connotations",
    "canr": "cant",
    "cantt": "cant",
    "canv": "can",
    "caost": "coast",
    "caought": "caught",
    "caould": "could",
    "capabilites": "capabilities",
    "capacites": "capacities",
    "caperbility": "capability",
    "capible": "capable",
    "capitivity": "captivity",
    "captial": "capital",
    "captialize": "capitalize",
    "captian": "captain",
    "captued": "captured",
    "capturd": "captured",
    "carachter": "character",
    "caracterized": "characterized",
    "carefull": "careful",
    "careing": "caring",
    "carger": "charger",
    "carier": "carrier",
    "carii": "cari",
    "carismatic": "charismatic",
    "carniverous": "carnivorous",
    "carnt": "cant",
    "carraige": "carriage",
    "carrear": "career",
    "carreer": "career",
    "carrers": "careers",
    "carres": "cares",
    "carring": "carrying",
    "carryng": "carrying",
    "cartdridge": "cartridge",
    "carthographer": "cartographer",
    "cartilege": "cartilage",
    "cartilidge": "cartilage",
    "cartrige": "cartridge",
    "cartt": "cart",
    "casette": "cassette",
    "casion": "caisson",
    "casn": "can",
    "cassawory": "cassowary",
    "casses": "cases",
    "cassete": "cassette",
    "cassowarry": "cassowary",
    "casualites": "casualties",
    "casualtes": "casualties",
    "casue": "cause",
    "casued": "caused",
    "casues": "causes",
    "casuing": "causing",
    "casulaties": "casualties",
    "casulaty": "casualty",
    "catagories": "categories",
    "catagorise": "categorise",
    "catagorize": "categorize",
    "catagorized": "categorized",
    "catagory": "category",
    "catalouge": "catalogue",
    "catapillar": "caterpillar",
    "catapillars": "caterpillars",
    "catapiller": "caterpillar",
    "catapillers": "caterpillars",
    "catchh": "catch",
    "catchig": "catching",
    "catchinn": "catching",
    "catchn": "catch",
    "catchng": "catching",
    "catchs": "catches",
    "catcu": "catch",
    "catepillar": "caterpillar",
    "catepillars": "caterpillars",
    "catergorize": "categorize",
    "catergorized": "categorized",
    "catergory": "category",
    "caterpilar": "caterpillar",
    "caterpilars": "caterpillars",
    "caterpiller": "caterpillar",
    "caterpillers": "caterpillars",
    "cathc": "catch",
    "cathegory": "category",
    "cathes": "catches",
    "cathlic": "catholic",
    "catholocism": "catholicism",
    "catn": "can",
    "catterpilar": "caterpillar",
    "catterpilars": "caterpillars",
    "catterpillar": "caterpillar",
    "catterpillars": "caterpillars",
    "cattleship": "battleship",
    "catvh": "catch",
    "caue": "case",
    "caughts": "caught",
    "caugt": "caught",
    "cauight": "caught",
    "cauqht": "caught",
    "causalities": "casualties",
    "causd": "caused",
    "cauvght": "caught",
    "cauz": "cuz",
    "cavarly": "cavalry",
    "cayght": "caught",
    "cayse": "cause",
    "cchrome": "chrome",
    "ccntrol": "control",
    "ccuz": "cuz",
    "cdnt": "cant",
    "ceck": "check",
    "cehck": "check",
    "celbrating": "celebrating",
    "celeberate": "celebrate",
    "celebrites": "celebrities",
    "celebrtaes": "celebrates",
    "celibrate": "celebrate",
    "cellpading": "cellpadding",
    "cementary": "cemetery",
    "cementery": "cemetery",
    "cemetarey": "cemetery",
    "cemetaries": "cemeteries",
    "cemetary": "cemetery",
    "cemetry": "cemetery",
    "cencus": "census",
    "centenial": "centennial",
    "cententenial": "centennial",
    "centraly": "centrally",
    "centruies": "centuries",
    "centruy": "century",
    "centures": "centuries",
    "centuties": "centuries",
    "centuty": "century",
    "cerimonial": "ceremonial",
    "cerimonies": "ceremonies",
    "cerimonious": "ceremonious",
    "cerimony": "ceremony",
    "ceromony": "ceremony",
    "certainity": "certainty",
    "certian": "certain",
    "certifed": "certified",
    "cetch": "catch",
    "cganged": "changed",
    "cgrome": "chrome",
    "chacne": "chance",
    "chaeck": "check",
    "chaffeine": "caffeine",
    "chage": "change",
    "chager": "changer",
    "chaging": "changing",
    "chalenging": "challenging",
    "challange": "challenge",
    "challanged": "challenged",
    "challanger": "challenger",
    "challege": "challenge",
    "challenage": "challenge",
    "chanage": "change",
    "chanche": "chance",
    "chaned": "changed",
    "chaneged": "changed",
    "changable": "changeable",
    "changeing": "changing",
    "changend": "changed",
    "chanllenge": "challenge",
    "channal": "channel",
    "chante": "chance",
    "chapotle": "chipotle",
    "charachter": "character",
    "charachters": "characters",
    "charactersistic": "characteristic",
    "characterstic": "characteristic",
    "charactor": "character",
    "charactors": "characters",
    "charasmatic": "charismatic",
    "charater": "character",
    "charaterized": "characterized",
    "charcter": "character",
    "charer": "charger",
    "chargibg": "charging",
    "chargng": "charging",
    "chargr": "charger",
    "chargwr": "charger",
    "chariman": "chairman",
    "charistics": "characteristics",
    "chatching": "catching",
    "cheak": "check",
    "cheapy": "cheap",
    "cheapz": "cheap",
    "checc": "check",
    "chechk": "check",
    "checing": "checking",
    "checkd": "checked",
    "checkig": "checking",
    "cheerleeder": "cheerleader",
    "cheif": "chief",
    "cheifs": "chiefs",
    "chekcing": "checking",
    "chekcked": "checked",
    "cheking": "checking",
    "chemcial": "chemical",
    "chemcially": "chemically",
    "chemestry": "chemistry",
    "chemicaly": "chemically",
    "chichken": "chicken",
    "chickn": "chicken",
    "chieftan": "chieftain",
    "chiildren": "children",
    "childbird": "childbirth",
    "childen": "children",
    "childrem": "children",
    "chiliin": "chillin",
    "chilin": "chillin",
    "chillinq": "chillin",
    "chilln": "chillin",
    "chipolte": "chipotle",
    "chipotele": "chipotle",
    "chiptole": "chipotle",
    "chirstmas": "christmas",
    "chldren": "children",
    "chnace": "chance",
    "chnces": "chances",
    "chnge": "change",
    "chnged": "changed",
    "choclate": "chocolate",
    "chool": "school",
    "choosen": "chosen",
    "chorme": "chrome",
    "choses": "chooses",
    "chosing": "choosing",
    "chould": "could",
    "chracter": "character",
    "chrck": "check",
    "chrge": "charge",
    "christmans": "christmas",
    "christmass": "christmas",
    "christmasx": "christmas",
    "christmis": "christmas",
    "chrme": "chrome",
    "chroe": "chrome",
    "chromse": "chrome",
    "chrone": "chrome",
    "chroome": "chrome",
    "chuch": "church",
    "churchs": "churches",
    "chwecked": "checked",
    "chyllin": "chillin",
    "cieling": "ceiling",
    "cilent": "client",
    "cilnic": "clinic",
    "cinic": "clinic",
    "ciome": "come",
    "circiut": "circuit",
    "circuituous": "circuitous",
    "circulaton": "circulation",
    "circumsicion": "circumcision",
    "circut": "circuit",
    "ciricuit": "circuit",
    "ciriculum": "curriculum",
    "cirus": "cyrus",
    "civillian": "civilian",
    "ckan": "can",
    "ckant": "cant",
    "ckeck": "check",
    "ckick": "click",
    "ckome": "come",
    "ckrib": "crib",
    "cladded": "clad",
    "claer": "clear",
    "claerer": "clearer",
    "claerly": "clearly",
    "claimes": "claims",
    "clal": "call",
    "clas": "class",
    "clasd": "class",
    "clasic": "classic",
    "clasical": "classical",
    "clasically": "classically",
    "classicaly": "classically",
    "classifed": "classified",
    "clasz": "class",
    "claustraphobia": "claustrophobia",
    "clcik": "click",
    "clck": "click",
    "cleareance": "clearance",
    "clearence": "clearance",
    "clebrating": "celebrating",
    "clevland": "cleveland",
    "cliams": "claims",
    "clicc": "click",
    "clickd": "click",
    "clikc": "click",
    "cliking": "clicking",
    "cliks": "clicks",
    "climatd": "climate",
    "climete": "climate",
    "clinc": "clinic",
    "clincial": "clinical",
    "clincs": "clinics",
    "clinet": "client",
    "clinicaly": "clinically",
    "clinicis": "clinics",
    "clinincs": "clinics",
    "clinis": "clinics",
    "clkimate": "climate",
    "clnic": "clinic",
    "clniics": "clinics",
    "cloose": "close",
    "closley": "closely",
    "closr": "closer",
    "clould": "could",
    "cmae": "came",
    "cmin": "comin",
    "cming": "coming",
    "cmo": "com",
    "cmoputer": "computer",
    "cmpare": "compare",
    "cname": "name",
    "cnat": "cant",
    "cnfirmed": "confirmed",
    "cnonsole": "console",
    "cntrol": "control",
    "co-incided": "coincided",
    "co-stared": "co-starred",
    "co-staring": "co-starring",
    "co-starr": "co-star",
    "coaltion": "coalition",
    "coatch": "coach",
    "coctail": "cocktail",
    "coee": "code",
    "coefficent": "coefficient",
    "coem": "come",
    "coerse": "coerce",
    "cofee": "coffee",
    "coference": "conference",
    "coffe": "coffee",
    "coform": "conform",
    "cognizent": "cognizant",
    "coiming": "coming",
    "coincedentally": "coincidentally",
    "coinsidence": "coincidence",
    "coiuld": "could",
    "colaborate": "collaborate",
    "colaboration": "collaboration",
    "colaborations": "collaborations",
    "colateral": "collateral",
    "coldd": "cold",
    "colection": "collection",
    "colelctive": "collective",
    "colf": "cold",
    "collaberate": "collaborate",
    "collaberation": "collaboration",
    "collaberative": "collaborative",
    "colleciton": "collection",
    "collecton": "collection",
    "collegate": "collegiate",
    "collegue": "colleague",
    "collegues": "colleagues",
    "coller": "cooler",
    "colloboration": "collaboration",
    "collonade": "colonnade",
    "collonies": "colonies",
    "collony": "colony",
    "collosal": "colossal",
    "collumn": "column",
    "colonizators": "colonizers",
    "coloquial": "colloquial",
    "comand": "command",
    "comando": "commando",
    "comandos": "commandos",
    "comany": "company",
    "comapany": "company",
    "comback": "comeback",
    "combanations": "combinations",
    "combinatins": "combinations",
    "combonation": "combination",
    "combusion": "combustion",
    "comdemnation": "condemnation",
    "comemmorate": "commemorate",
    "comemmorates": "commemorates",
    "comemoretion": "commemoration",
    "comencement": "commencement",
    "coment": "comment",
    "comerce": "commerce",
    "comercially": "commercially",
    "cometition": "competition",
    "comfirmed": "confirmed",
    "comig": "coming",
    "comign": "coming",
    "comination": "combination",
    "comingg": "coming",
    "cominng": "coming",
    "cominq": "coming",
    "comision": "commission",
    "comisioned": "commissioned",
    "comisioner": "commissioner",
    "comisioning": "commissioning",
    "comisions": "commissions",
    "comission": "commission",
    "comissioned": "commissioned",
    "comissioner": "commissioner",
    "comissioning": "commissioning",
    "comissions": "commissions",
    "comited": "committed",
    "comiting": "committing",
    "comitted": "committed",
    "comittee": "committee",
    "comitting": "committing",
    "comlains": "complains",
    "comman": "common",
    "commandoes": "commandos",
    "commedic": "comedic",
    "commemerative": "commemorative",
    "commemmorate": "commemorate",
    "commemmorating": "commemorating",
    "commen": "common",
    "commerate": "commemorate",
    "commerating": "commemorating",
    "commeration": "commemoration",
    "commerative": "commemorative",
    "commerial": "commercial",
    "commerical": "commercial",
    "commerically": "commercially",
    "commericial": "commercial",
    "commericially": "commercially",
    "commerorative": "commemorative",
    "commertial": "commercial",
    "commin": "comin",
    "comming": "coming",
    "comminication": "communication",
    "commision": "commission",
    "commisioned": "commissioned",
    "commisioner": "commissioner",
    "commisioning": "commissioning",
    "commisions": "commissions",
    "commited": "committed",
    "commitee": "committee",
    "commiting": "committing",
    "committe": "committee",
    "committies": "committees",
    "committment": "commitment",
    "committments": "commitments",
    "committy": "committee",
    "commmemorated": "commemorated",
    "commom": "common",
    "commongly": "commonly",
    "commonweath": "commonwealth",
    "commuications": "communications",
    "commuinications": "communications",
    "communciation": "communication",
    "communiation": "communication",
    "communites": "communities",
    "communitys": "communities",
    "communty": "community",
    "communual": "communal",
    "comn": "comin",
    "comnbat": "combat",
    "comng": "coming",
    "comnig": "coming",
    "comning": "coming",
    "comong": "coming",
    "comonly": "commonly",
    "compability": "compatibility",
    "compaired": "compared",
    "compairison": "comparison",
    "compareable": "comparable",
    "comparision": "comparison",
    "comparisions": "comparisons",
    "comparitive": "comparative",
    "comparitively": "comparatively",
    "comparsion": "comparison",
    "compatabilities": "compatibilities",
    "compatability": "compatibility",
    "compatable": "compatible",
    "compatablities": "compatibilities",
    "compatablity": "compatibility",
    "compatbile": "compatible",
    "compatiable": "compatible",
    "compatibe": "compatible",
    "compatiblities": "compatibilities",
    "compatiblity": "compatibility",
    "compatition": "competition",
    "compeet": "compete",
    "compeeting": "competing",
    "compeitions": "competitions",
    "compensantion": "compensation",
    "compertition": "competition",
    "competance": "competence",
    "competant": "competent",
    "competative": "competitive",
    "competitiion": "competition",
    "competiting": "competing",
    "competiton": "competition",
    "competive": "competitive",
    "competively": "competitively",
    "competiveness": "competitiveness",
    "comphrehensive": "comprehensive",
    "compitent": "competent",
    "compites": "competes",
    "complaintant": "complainant",
    "compleete": "complete",
    "completedthe": "completed the",
    "completelyl": "completely",
    "completetion": "completion",
    "completly": "completely",
    "complier": "compiler",
    "compnay": "company",
    "componant": "component",
    "comprable": "comparable",
    "compred": "compared",
    "comprimise": "compromise",
    "comprimize": "compromise",
    "compu": "comp",
    "compulsary": "compulsory",
    "compulsery": "compulsory",
    "computar": "computer",
    "computarized": "computerized",
    "compution": "computation",
    "computr": "computer",
    "comradarie": "camaraderie",
    "comraderie": "camaraderie",
    "comunicate": "communicate",
    "comws": "comes",
    "conbination": "combination",
    "conbined": "combined",
    "concecutive": "consecutive",
    "concensus": "consensus",
    "concers": "concerns",
    "concersn": "concern",
    "concide": "coincide",
    "concider": "consider",
    "concidered": "considered",
    "concidering": "considering",
    "conciders": "considers",
    "concience": "conscience",
    "concieted": "conceited",
    "concieved": "conceived",
    "concious": "conscious",
    "conciously": "consciously",
    "conciousness": "consciousness",
    "conclution": "conclusion",
    "conctete": "concrete",
    "conctract": "contract",
    "conctrete": "concrete",
    "concurent": "concurrent",
    "concuring": "concurring",
    "concurr": "concur",
    "condamned": "condemned",
    "condelences": "condolences",
    "condemed": "condemned",
    "condemm": "condemn",
    "condemmed": "condemned",
    "condidtion": "condition",
    "condidtions": "conditions",
    "conditionsof": "conditions of",
    "condolances": "condolences",
    "condoleces": "condolences",
    "condolensces": "condolences",
    "condolonces": "condolences",
    "conducter": "conductor",
    "conect": "connect",
    "conected": "connected",
    "conection": "connection",
    "conerned": "concerned",
    "conesencus": "consensus",
    "conferance": "conference",
    "confered": "conferred",
    "confermed": "confirmed",
    "conferr": "confer",
    "confidance": "confidence",
    "confidental": "confidential",
    "confidentally": "confidentially",
    "confids": "confides",
    "configureable": "configurable",
    "confimed": "confirmed",
    "confimrmed": "confirmed",
    "confired": "confirmed",
    "confirned": "confirmed",
    "confortable": "comfortable",
    "confrence": "conference",
    "confrim": "confirm",
    "confrims": "confirms",
    "confussed": "confused",
    "congradulate": "congratulate",
    "congradulations": "congratulations",
    "congresional": "congressional",
    "coninced": "convinced",
    "conincide": "coincide",
    "conived": "connived",
    "conjecutre": "conjecture",
    "conjour": "conjure",
    "conjuction": "conjunction",
    "conjuntion": "conjunction",
    "conncect": "connect",
    "connextion": "connection",
    "conotations": "connotations",
    "conputer": "computer",
    "conquerd": "conquered",
    "conquerer": "conqueror",
    "conquerers": "conquerors",
    "conqured": "conquered",
    "conrtact": "contract",
    "consacrate": "consecrate",
    "conscent": "consent",
    "consciouness": "consciousness",
    "consdider": "consider",
    "consdidered": "considered",
    "consdiered": "considered",
    "consective": "consecutive",
    "consectutive": "consecutive",
    "consel": "counsel",
    "consenquently": "consequently",
    "consentrate": "concentrate",
    "consentrated": "concentrated",
    "consentrates": "concentrates",
    "consept": "concept",
    "consequentually": "consequently",
    "consequeseces": "consequences",
    "consern": "concern",
    "conserned": "concerned",
    "conserning": "concerning",
    "conservitive": "conservative",
    "consession": "concession",
    "consiciousness": "consciousness",
    "consicousness": "consciousness",
    "considerd": "considered",
    "consideres": "considered",
    "consious": "conscious",
    "consistancy": "consistency",
    "consistant": "consistent",
    "consistantly": "consistently",
    "consituencies": "constituencies",
    "consituency": "constituency",
    "consituted": "constituted",
    "consitution": "constitution",
    "consitutional": "constitutional",
    "consolodate": "consolidate",
    "consolodated": "consolidated",
    "consonent": "consonant",
    "consonents": "consonants",
    "consorcium": "consortium",
    "conspiracys": "conspiracies",
    "conspiriator": "conspirator",
    "consquently": "consequently",
    "constaints": "constraints",
    "constanly": "constantly",
    "constarnation": "consternation",
    "constatn": "constant",
    "constinually": "continually",
    "constituant": "constituent",
    "constituants": "constituents",
    "constituion": "constitution",
    "constituional": "constitutional",
    "consttruction": "construction",
    "constuction": "construction",
    "consulant": "consultant",
    "consumate": "consummate",
    "consumated": "consummated",
    "contacs": "contacts",
    "contactcs": "contacts",
    "contageous": "contagious",
    "contagiousa": "contagious",
    "contaiminate": "contaminate",
    "containes": "contains",
    "contamporaries": "contemporaries",
    "contamporary": "contemporary",
    "contempoary": "contemporary",
    "contemporaneus": "contemporaneous",
    "contempory": "contemporary",
    "contendor": "contender",
    "contension": "contention",
    "contestent": "contestant",
    "contian": "contain",
    "contians": "contains",
    "contibute": "contribute",
    "contibuted": "contributed",
    "contibutes": "contributes",
    "contigent": "contingent",
    "contined": "continued",
    "continential": "continental",
    "continiued": "continued",
    "continous": "continuous",
    "continously": "continuously",
    "continueing": "continuing",
    "continum": "continuum",
    "continuty": "continuity",
    "contious": "continuous",
    "contolled": "controlled",
    "contracter": "contractor",
    "contractng": "contracting",
    "contravercial": "controversial",
    "contraversy": "controversy",
    "contributer": "contributor",
    "contributers": "contributors",
    "contributery": "contributory",
    "contritutions": "contributions",
    "contrl": "control",
    "contrller": "controller",
    "controled": "controlled",
    "controling": "controlling",
    "controll": "control",
    "controlls": "controls",
    "controvercial": "controversial",
    "controvercy": "controversy",
    "controveries": "controversies",
    "controversal": "controversial",
    "controversey": "controversy",
    "controvertial": "controversial",
    "controvery": "controversy",
    "contruction": "construction",
    "contry": "country",
    "contstruction": "construction",
    "conveinent": "convenient",
    "convenant": "covenant",
    "conveniant": "convenient",
    "convential": "conventional",
    "conventionaly": "conventionally",
    "conver": "cover",
    "convergance": "convergence",
    "convergant": "convergent",
    "converned": "concerned",
    "conversley": "conversely",
    "conversly": "conversely",
    "convertable": "convertible",
    "convertables": "convertibles",
    "convertion": "conversion",
    "convetional": "conventional",
    "convice": "convince",
    "conviced": "convinced",
    "convience": "convince",
    "convienient": "convenient",
    "convinient": "convenient",
    "convitee": "convite",
    "coolestz": "coolest",
    "coolist": "coolest",
    "coolsest": "coolest",
    "coool": "cool",
    "coordiantion": "coordination",
    "coorperations": "corporations",
    "copmetitors": "competitors",
    "copming": "coming",
    "coporation": "corporation",
    "coppy": "copy",
    "copss": "cops",
    "copuld": "could",
    "copuple": "couple",
    "coputer": "computer",
    "copywrite": "copyright",
    "corect": "correct",
    "coreect": "correct",
    "corespond": "correspond",
    "coridal": "cordial",
    "cornmitted": "committed",
    "corode": "corrode",
    "corosion": "corrosion",
    "corparate": "corporate",
    "corparation": "corporation",
    "corperate": "corporate",
    "corperation": "corporation",
    "corperations": "corporations",
    "correcters": "correctors",
    "correlary": "corollary",
    "correponding": "corresponding",
    "correposding": "corresponding",
    "correspondance": "correspondence",
    "correspondant": "correspondent",
    "correspondants": "correspondents",
    "correspondet": "correspondent",
    "corridoors": "corridors",
    "corrispond": "correspond",
    "corrispondant": "correspondent",
    "corrispondants": "correspondents",
    "corrisponded": "corresponded",
    "corrisponding": "corresponding",
    "corrisponds": "corresponds",
    "cossin": "cousin",
    "costitution": "constitution",
    "coucil": "council",
    "coudl": "could",
    "couged": "coughed",
    "couldent": "couldnt",
    "coulld": "could",
    "coulnt": "couldnt",
    "couls": "could",
    "coult": "could",
    "counries": "countries",
    "counsin": "cousin",
    "countain": "contain",
    "countains": "contains",
    "countires": "countries",
    "couole": "couple",
    "coupel": "couple",
    "couplw": "couple",
    "couqh": "cough",
    "coures": "course",
    "courtesey": "courtesy",
    "courtisy": "courtesy",
    "couse": "house",
    "cousing": "cousin",
    "cousion": "cousin",
    "cousre": "course",
    "coustom": "custom",
    "coutry": "country",
    "couz": "cuz",
    "cphone": "iphone",
    "craap": "crap",
    "cracced": "cracked",
    "crae": "care",
    "craete": "create",
    "craftly": "craftily",
    "crapi": "crap",
    "crapp": "crap",
    "crawlabe": "crawlable",
    "craz": "crap",
    "creaeted": "created",
    "creater": "creator",
    "creaters": "creators",
    "creati": "create",
    "creche": "crèche",
    "creedence": "credence",
    "crhome": "chrome",
    "criate": "create",
    "crimnal": "criminal",
    "cristened": "christened",
    "critcal": "critical",
    "critereon": "criterion",
    "criterias": "criteria",
    "criticaly": "critically",
    "criticists": "critics",
    "critiscise": "criticise",
    "critiscism": "criticism",
    "critiscize": "criticize",
    "critisising": "criticising",
    "critisism": "criticism",
    "critisisms": "criticisms",
    "critized": "criticized",
    "critizing": "criticizing",
    "crockodiles": "crocodiles",
    "crontrol": "control",
    "crowm": "crown",
    "crtical": "critical",
    "crticised": "criticised",
    "crucifiction": "crucifixion",
    "crusies": "cruises",
    "crutial": "crucial",
    "cryed": "cried",
    "crystalisation": "crystallisation",
    "cryus": "cyrus",
    "csrt": "cart",
    "csun": "sun",
    "ctach": "catch",
    "cty": "city",
    "cuaght": "caught",
    "cuase": "cause",
    "cught": "caught",
    "cuh": "cuz",
    "cuhz": "cuz",
    "culiminating": "culminating",
    "cultery": "cutlery",
    "cuming": "coming",
    "cumulatative": "cumulative",
    "cumz": "cuz",
    "curch": "church",
    "curcuit": "circuit",
    "curent": "current",
    "curently": "currently",
    "curiuos": "curious",
    "currenlty": "currently",
    "currenly": "currently",
    "currentley": "currently",
    "currenty": "currently",
    "curretly": "currently",
    "curriculem": "curriculum",
    "currrent": "current",
    "cuse": "cause",
    "cuty": "city",
    "cuzo": "cuz",
    "cuzz": "cuz",
    "cxan": "cyan",
    "cyclinder": "cylinder",
    "cyrius": "cyrus",
    "daay": "day",
    "dacquiri": "daiquiri",
    "daed": "dead",
    "daignosed": "diagnosed",
    "dalmation": "dalmatian",
    "damagd": "damaged",
    "damageing": "damaging",
    "damenor": "demeanor",
    "dammage": "damage",
    "dammn": "damn",
    "damnn": "damn",
    "damoa": "samoa",
    "danceing": "dancing",
    "dangerious": "dangerous",
    "dangerouse": "dangerous",
    "danm": "damn",
    "darw": "dare",
    "daschund": "dachshund",
    "daugher": "daughter",
    "daughtr": "daughter",
    "daugter": "daughter",
    "daugther": "daughter",
    "dayi": "day",
    "daymn": "damn",
    "dayss": "days",
    "dayy": "day",
    "dayz": "days",
    "dcctors": "doctors",
    "dctor": "doctor",
    "ddnt": "dont",
    "ddot": "dot",
    "ddsgusting": "disgusting",
    "deactive": "deactivate",
    "dealths": "deaths",
    "deaprtment": "department",
    "deask": "desk",
    "debateable": "debatable",
    "debatinn": "debating",
    "debo": "demo",
    "debute": "debut",
    "decadance": "decadence",
    "decadant": "decadent",
    "decalres": "declares",
    "decathalon": "decathlon",
    "deceided": "decided",
    "decend": "descend",
    "decendant": "descendant",
    "decendants": "descendants",
    "decendent": "descendant",
    "decendents": "descendants",
    "deciced": "decided",
    "decidded": "decided",
    "decideable": "decidable",
    "decidely": "decidedly",
    "decidly": "decidedly",
    "decied": "decided",
    "deciede": "decide",
    "decieded": "decided",
    "decieved": "deceived",
    "deciided": "decided",
    "decison": "decision",
    "decist": "desist",
    "decited": "decided",
    "deckk": "deck",
    "declaired": "declared",
    "declars": "declares",
    "decleared": "declared",
    "decloared": "declared",
    "declrared": "declared",
    "decomissioned": "decommissioned",
    "decomposit": "decompose",
    "decomposited": "decomposed",
    "decompositing": "decomposing",
    "decomposits": "decomposes",
    "decress": "decrees",
    "decribe": "describe",
    "decribed": "described",
    "decribes": "describes",
    "decribing": "describing",
    "decsent": "decent",
    "dectect": "detect",
    "deep-seeded": "deep-seated",
    "defecit": "deficit",
    "defendent": "defendant",
    "defendents": "defendants",
    "defenitely": "definitely",
    "deffensively": "defensively",
    "deffine": "define",
    "deffined": "defined",
    "deffinite": "definite",
    "deffinition": "definition",
    "definance": "defiance",
    "definate": "definite",
    "definately": "definitely",
    "definatly": "definitely",
    "definetely": "definitely",
    "definetly": "definitely",
    "definiation": "definition",
    "definining": "defining",
    "definit": "definite",
    "definitelly": "definitely",
    "definitley": "definitely",
    "definitly": "definitely",
    "definiton": "definition",
    "definityly": "definitely",
    "defintely": "definitely",
    "defintion": "definition",
    "defintitely": "definitely",
    "defuncted": "defunct",
    "defunitely": "definitely",
    "degrate": "degrade",
    "degredation": "degradation",
    "deinitely": "definitely",
    "deites": "deities",
    "dekstop": "desktop",
    "delagate": "delegate",
    "delagates": "delegates",
    "delapidate": "dilapidate",
    "delapidated": "dilapidated",
    "delcared": "declared",
    "delcares": "declares",
    "delclared": "declared",
    "delerious": "delirious",
    "delevopment": "development",
    "deliberatly": "deliberately",
    "delusionally": "delusively",
    "demenor": "demeanor",
    "demographical": "demographic",
    "demolision": "demolition",
    "demond": "demon",
    "demorcracy": "democracy",
    "demostration": "demonstration",
    "denegrating": "denigrating",
    "denocracy": "democracy",
    "densly": "densely",
    "deosnt": "doesnt",
    "deparment": "department",
    "deparmental": "departmental",
    "deparments": "departments",
    "dependance": "dependence",
    "dependancy": "dependency",
    "depeneds": "depends",
    "deperately": "desperately",
    "depnds": "depends",
    "deriviated": "derived",
    "deriviative": "derivative",
    "derivitive": "derivative",
    "derogitory": "derogatory",
    "descendands": "descendants",
    "descibed": "described",
    "descide": "decide",
    "descision": "decision",
    "descisions": "decisions",
    "descovered": "discovered",
    "descriibes": "describes",
    "descripters": "descriptors",
    "descripton": "description",
    "desctruction": "destruction",
    "descuss": "discuss",
    "desease": "disease",
    "desend": "descend",
    "desgin": "design",
    "desginate": "designate",
    "desgined": "designed",
    "desgners": "designers",
    "deside": "decide",
    "desided": "decided",
    "desiging": "designing",
    "desigining": "designing",
    "designes": "designs",
    "desimination": "dissemination",
    "desinations": "destinations",
    "desing": "design",
    "desinged": "designed",
    "desinger": "designer",
    "desingners": "designers",
    "desintegrated": "disintegrated",
    "desintegration": "disintegration",
    "desireable": "desirable",
    "desirible": "desirable",
    "desitned": "destined",
    "deskop": "desktop",
    "desktiop": "desktop",
    "deskx": "desk",
    "desolution": "dissolution",
    "desolve": "dissolve",
    "desorder": "disorder",
    "desoriented": "disoriented",
    "desparately": "desperately",
    "desparation": "desperation",
    "desperatly": "desperately",
    "despict": "depict",
    "despiration": "desperation",
    "desribe": "describe",
    "desse": "desde",
    "dessicated": "desiccated",
    "dessigned": "designed",
    "destablized": "destabilized",
    "destkop": "desktop",
    "destop": "desktop",
    "destory": "destroy",
    "destoryer": "destroyer",
    "detachement": "detachment",
    "detailled": "detailed",
    "detals": "details",
    "detatch": "detach",
    "detatched": "detached",
    "deteoriated": "deteriorated",
    "deterance": "deterrence",
    "deterant": "deterrent",
    "deterence": "deterrence",
    "deterent": "deterrent",
    "deteriate": "deteriorate",
    "deteriation": "deterioration",
    "deterioriating": "deteriorating",
    "determing": "determining",
    "determinining": "determining",
    "deterrance": "deterrence",
    "deterrant": "deterrent",
    "detrement": "detriment",
    "detremental": "detrimental",
    "devasted": "devastated",
    "devcided": "decided",
    "deve": "dev",
    "develeper": "developer",
    "develepment": "development",
    "develope": "develop",
    "developement": "development",
    "developemet": "development",
    "developerr": "developer",
    "developmers": "developers",
    "developp": "develop",
    "developp": "develops",
    "developped": "developed",
    "developper": "developer",
    "developpers": "developers",
    "develp": "develop",
    "develpment": "development",
    "develpo": "develop",
    "devels": "delves",
    "devestate": "devastate",
    "devestated": "devastated",
    "devestating": "devastating",
    "devestation": "devastation",
    "devide": "divide",
    "devided": "decided",
    "devided": "divided",
    "devie": "device",
    "devistate": "devastate",
    "devistating": "devastating",
    "devistation": "devastation",
    "devleoper": "developer",
    "devleoping": "developing",
    "devleopment": "development",
    "devloper": "developer",
    "devlopment": "development",
    "devolopement": "development",
    "devoloper": "developer",
    "devolopment": "development",
    "devolopped": "developed",
    "dextor": "dexter",
    "dhat": "that",
    "dhats": "thats",
    "dhot": "shot",
    "diablical": "diabolical",
    "diaganosed": "diagnosed",
    "diagnoesed": "diagnosed",
    "diagnoised": "diagnosed",
    "diagnoset": "diagnosed",
    "diagnsed": "diagnosed",
    "dialate": "dilate",
    "dialation": "dilation",
    "diamons": "diamonds",
    "diangosed": "diagnosed",
    "dianosed": "diagnosed",
    "diaster": "disaster",
    "dichtomy": "dichotomy",
    "dicide": "decide",
    "diciple": "disciple",
    "dicision": "decision",
    "diconnects": "disconnects",
    "dicover": "discover",
    "dicovered": "discovered",
    "dicovering": "discovering",
    "dicovers": "discovers",
    "dicovery": "discovery",
    "dics": "docs",
    "dictionarys": "dictionaries",
    "dictor": "doctor",
    "dicuss": "discuss",
    "dicussed": "discussed",
    "dicussion": "discussion",
    "didd": "did",
    "diddnt": "didnt",
    "dident": "didnt",
    "didmt": "didnt",
    "didnr": "didnt",
    "didnt": "didn't",
    "didntb": "didnt",
    "didt": "didnt",
    "diect": "direct",
    "diedd": "died",
    "dieds": "died",
    "diend": "died",
    "diesal": "diesel",
    "dieties": "deities",
    "diety": "deity",
    "diference": "difference",
    "diferent": "different",
    "diferrent": "different",
    "differant": "different",
    "differencce": "difference",
    "differentiatiations": "differentiations",
    "differeny": "different",
    "differewnce": "difference",
    "differnet": "different",
    "differnt": "different",
    "differrnt": "different",
    "difficulity": "difficulty",
    "diffrence": "difference",
    "diffrent": "different",
    "diffricult": "difficult",
    "dificult": "difficult",
    "dificulties": "difficulties",
    "dificulty": "difficulty",
    "diggign": "digging",
    "digitaly": "digitally",
    "digitial": "digital",
    "dignatary": "dignitary",
    "dignosed": "diagnosed",
    "diidnt": "didnt",
    "dilletante": "dilettante",
    "dilligence": "diligence",
    "dillute": "dilute",
    "dimaond": "diamond",
    "dimenion": "dimension",
    "dimenions": "dimensions",
    "dimention": "dimension",
    "dimentional": "dimensional",
    "dimentions": "dimensions",
    "dimesnional": "dimensional",
    "diminuation": "diminution",
    "diminuative": "diminutive",
    "diminuition": "diminution",
    "diminuitive": "diminutive",
    "dimished": "diminished",
    "dimishes": "diminishes",
    "dimunitive": "diminutive",
    "dinasty": "dynasty",
    "dinning room": "dining room",
    "diognosed": "diagnosed",
    "diosese": "diocese",
    "diphtong": "diphthong",
    "diphtongs": "diphthongs",
    "diplay": "display",
    "diplayed": "displayed",
    "diplomancy": "diplomacy",
    "dipthong": "diphthong",
    "dipthongs": "diphthongs",
    "direcly": "directly",
    "directcly": "directly",
    "directley": "directly",
    "directon": "direction",
    "directoty": "directory",
    "dirived": "derived",
    "disabilites": "disabilities",
    "disagreeed": "disagreed",
    "disapear": "disappear",
    "disapeared": "disappeared",
    "disapoint": "disappoint",
    "disapointed": "disappointed",
    "disapointing": "disappointing",
    "disapointment": "disappointment",
    "disappeard": "disappears",
    "disappearence": "disappearance",
    "disappearred": "disappeared",
    "disappinted": "disappointed",
    "disaproval": "disapproval",
    "disaprove": "disapprove",
    "disasterous": "disastrous",
    "disatisfaction": "dissatisfaction",
    "disatisfied": "dissatisfied",
    "disatrous": "disastrous",
    "discontentment": "discontent",
    "discovererd": "discovered",
    "discoverey": "discovery",
    "discrepency": "discrepancy",
    "discribe": "describe",
    "discribed": "described",
    "discribes": "describes",
    "discribing": "describing",
    "discription": "description",
    "disctinction": "distinction",
    "disctinctive": "distinctive",
    "disemination": "dissemination",
    "disenchanged": "disenchanted",
    "diseny": "disney",
    "disgnosed": "diagnosed",
    "disimisses": "dismisses",
    "disiplined": "disciplined",
    "disist": "desist",
    "disobediance": "disobedience",
    "disobediant": "disobedient",
    "disolution": "dissolution",
    "disolved": "dissolved",
    "disover": "discover",
    "dispair": "despair",
    "disparingly": "disparagingly",
    "dispence": "dispense",
    "dispenced": "dispensed",
    "dispencing": "dispensing",
    "dispicable": "despicable",
    "dispite": "despite",
    "dispostion": "disposition",
    "disproportiate": "disproportionate",
    "disputandem": "disputandum",
    "disricts": "districts",
    "dissagreement": "disagreement",
    "dissapear": "disappear",
    "dissapearance": "disappearance",
    "dissapeared": "disappeared",
    "dissapearing": "disappearing",
    "dissapears": "disappears",
    "dissapoint": "disappoint",
    "dissapointment": "disappointment",
    "dissappear": "disappear",
    "dissappears": "disappears",
    "dissappointed": "disappointed",
    "dissappointment": "disappointment",
    "dissarray": "disarray",
    "dissobediance": "disobedience",
    "dissobediant": "disobedient",
    "dissobedience": "disobedience",
    "dissobedient": "disobedient",
    "dissoluted": "dissolved",
    "distiction": "distinction",
    "distilation": "distillation",
    "distingish": "distinguish",
    "distingished": "distinguished",
    "distingishes": "distinguishes",
    "distingishing": "distinguishing",
    "distingquished": "distinguished",
    "distirb": "disturb",
    "distroy": "destroy",
    "distrub": "disturb",
    "distrubed": "disturbed",
    "distrubution": "distribution",
    "distruction": "destruction",
    "distructive": "destructive",
    "ditributed": "distributed",
    "divice": "device",
    "divinition": "divination",
    "divison": "division",
    "divisons": "divisions",
    "diwn": "down",
    "diwnload": "download",
    "diwnloaded": "downloaded",
    "dlove": "love",
    "doccument": "document",
    "doccumented": "documented",
    "doccuments": "documents",
    "docotor": "doctor",
    "docotr": "doctor",
    "docrines": "doctrines",
    "docters": "doctors",
    "doctines": "doctrines",
    "doctoe": "doctor",
    "doctoes": "doctors",
    "doctorb": "doctors",
    "doctorr": "doctor",
    "doctorss": "doctors",
    "documenatry": "documentary",
    "documentery": "documentary",
    "documentry": "documentary",
    "doding": "doing",
    "dodnt": "dont",
    "doea": "does",
    "doens": "does",
    "doenst": "doesnt",
    "doent": "dont",
    "doesent": "doesnt",
    "doeses": "doses",
    "doesnot": "doesnt",
    "doesnt": "doesn't",
    "doez": "does",
    "doign": "doing",
    "doiing": "doing",
    "doint": "dont",
    "doktors": "doctors",
    "dollers": "dollars",
    "dollor": "dollar",
    "dominaton": "domination",
    "dominent": "dominant",
    "dominiant": "dominant",
    "domt": "dont",
    "dondt": "dont",
    "donic": "sonic",
    "donig": "doing",
    "donjt": "dont",
    "donkt": "dont",
    "donload": "download",
    "donlt": "dont",
    "donnt": "dont",
    "donr": "dont",
    "donst": "dont",
    "dontt": "dont",
    "donw": "down",
    "donwgrade": "downgrade",
    "donwload": "download",
    "donwloaded": "downloaded",
    "donwnloaded": "downloaded",
    "dony": "dont",
    "dooesnt": "doesnt",
    "doogle": "doodle",
    "doorjam": "door jamb",
    "doqn": "down",
    "dores": "does",
    "dorment": "dormant",
    "dosen't": "doesn't",
    "dosent": "doesnt",
    "doslreports": "dslreports",
    "dosnt": "dont",
    "dotn": "dont",
    "doubht": "doubt",
    "doulbe": "double",
    "dould": "would",
    "dous": "does",
    "dowb": "down",
    "dowh": "down",
    "dowload": "download",
    "dowloaded": "downloaded",
    "dowloading": "downloading",
    "dowloads": "downloads",
    "dowm": "down",
    "downdoad": "download",
    "downi": "down",
    "downkoad": "download",
    "downlaod": "download",
    "downlaoded": "downloaded",
    "downliad": "download",
    "downliaded": "downloaded",
    "downloaden": "downloaded",
    "downloadn": "download",
    "downloaed": "downloaded",
    "downloan": "download",
    "downloard": "download",
    "downloded": "downloaded",
    "downoad": "download",
    "downoaded": "downloaded",
    "dozend": "dozen",
    "dpends": "depends",
    "dplay": "play",
    "draded": "dreaded",
    "dramtic": "dramatic",
    "draughtman": "draughtsman",
    "dreakm": "dream",
    "dreasm": "dreams",
    "dredded": "dreaded",
    "dreded": "dreaded",
    "driectly": "directly",
    "driend": "friend",
    "dril": "drill",
    "drilll": "drill",
    "driod": "droid",
    "drnik": "drink",
    "drobbox": "dropbox",
    "droped": "dropped",
    "droping": "dropping",
    "dropox": "dropbox",
    "droppped": "dropped",
    "dropxox": "dropbox",
    "drpped": "dropped",
    "druing": "during",
    "drumed": "drummed",
    "drumer": "drummer",
    "druming": "drumming",
    "drummless": "drumless",
    "drumms": "drums",
    "dryed": "dried",
    "dryll": "drill",
    "dsnt": "dont",
    "dsnt": "isnt",
    "dswine": "swine",
    "dtopped": "dropped",
    "dtunes": "itunes",
    "duaghter": "daughter",
    "dubt": "doubt",
    "duely": "duly",
    "dugged": "dug",
    "dum": "dumb",
    "dumn": "damn",
    "dunnoo": "dunno",
    "dunnow": "dunno",
    "dupicate": "duplicate",
    "durig": "during",
    "durinf": "during",
    "durng": "during",
    "durring": "during",
    "duting": "during",
    "dwas": "was",
    "dwess": "dress",
    "dwn": "down",
    "dwnload": "download",
    "dwnloaded": "downloaded",
    "dwnloading": "downloading",
    "dwonload": "download",
    "dwonloaded": "downloaded",
    "dyas": "dryas",
    "dyeng": "dying",
    "dyinh": "dying",
    "dyying": "dying",
    "eady": "ready",
    "eahc": "each",
    "ealier": "earlier",
    "ealiest": "earliest",
    "eangine": "engine",
    "eant": "want",
    "earch": "search",
    "earching": "searching",
    "earhquake": "earthquake",
    "earht": "earth",
    "eariler": "earlier",
    "earleir": "earlier",
    "earler": "earlier",
    "earlies": "earliest",
    "earnt": "earned",
    "earthquare": "earthquake",
    "earthqyake": "earthquake",
    "earthwom": "earthworm",
    "eartquake": "earthquake",
    "earty": "earth",
    "earyl": "early",
    "easiliy": "easily",
    "easly": "easily",
    "easonal": "seasonal",
    "eastermost": "easternmost",
    "eastest": "fastest",
    "easyier": "easier",
    "eathquake": "earthquake",
    "ebst": "best",
    "eccept": "except",
    "eccessive": "excessive",
    "ecclectic": "eclectic",
    "ecclesiatic": "ecclesiastic",
    "ecclesiatical": "ecclesiastical",
    "ecclestiastical": "ecclesiastical",
    "eceonomy": "economy",
    "echfon": "echofon",
    "echofin": "echofon",
    "ecidious": "deciduous",
    "eclectric": "eclectic",
    "eclispe": "eclipse",
    "ecofon": "echofon",
    "ecomonic": "economic",
    "ecomony": "economy",
    "ecpecially": "especially",
    "ecperience": "experience",
    "ect": "etc",
    "editig": "editing",
    "editon": "edition",
    "edtion": "edition",
    "educaitonal": "educational",
    "eductional": "educational",
    "eearly": "early",
    "eearth": "earth",
    "eeek": "peek",
    "eere": "were",
    "eeriely": "eerily",
    "efel": "evil",
    "effeciency": "efficiency",
    "effecient": "efficient",
    "effeciently": "efficiently",
    "efficency": "efficiency",
    "efficent": "efficient",
    "efficently": "efficiently",
    "effict": "effect",
    "effulence": "effluence",
    "egen": "even",
    "egift": "gift",
    "ehas": "has",
    "ehen": "when",
    "eher": "her",
    "ehow": "how",
    "eiffell": "eiffel",
    "eiffle": "eiffel",
    "eill": "will",
    "eiter": "either",
    "eith": "with",
    "eithr": "either",
    "elaborite": "elaborate",
    "elae": "else",
    "elction": "election",
    "electrial": "electrical",
    "electricly": "electrically",
    "electricty": "electricity",
    "elemantary": "elementary",
    "elementay": "elementary",
    "eleminated": "eliminated",
    "eleminating": "eliminating",
    "eles": "eels",
    "eles": "elses",
    "elese": "else",
    "eletricity": "electricity",
    "eletronic": "electronic",
    "elicided": "elicited",
    "elieve": "believe",
    "eligability": "eligibility",
    "eligable": "eligible",
    "elimentary": "elementary",
    "ellected": "elected",
    "ellusive": "elusive",
    "elphant": "elephant",
    "elsee": "else",
    "elus": "telus",
    "emaild": "email",
    "emaill": "email",
    "emal": "email",
    "embarass": "embarrass",
    "embarassed": "embarrassed",
    "embarassing": "embarrassing",
    "embarassment": "embarrassment",
    "embargos": "embargoes",
    "embarras": "embarrass",
    "embarrased": "embarrassed",
    "embarrasing": "embarrassing",
    "embarrasment": "embarrassment",
    "embedd": "embed",
    "embeded": "embedded",
    "embeed": "embed",
    "embelish": "embellish",
    "embelishment": "embellishment",
    "embezelled": "embezzled",
    "emblamatic": "emblematic",
    "emercency": "emergency",
    "emergancy": "emergency",
    "emergencey": "emergency",
    "emergnecy": "emergency",
    "emerqency": "emergency",
    "emglish": "english",
    "eminate": "emanate",
    "eminated": "emanated",
    "emision": "emission",
    "emited": "emitted",
    "emiter": "emitter",
    "emiting": "emitting",
    "emitt": "emit",
    "emmediately": "immediately",
    "emmense": "immense",
    "emmigrant": "emigrant",
    "emmigrated": "emigrated",
    "emminently": "eminently",
    "emmisaries": "emissaries",
    "emmisarries": "emissaries",
    "emmisarry": "emissary",
    "emmisary": "emissary",
    "emmision": "emission",
    "emmisions": "emissions",
    "emmission": "emission",
    "emmited": "emitted",
    "emmiting": "emitting",
    "emmitted": "emitted",
    "emmitting": "emitting",
    "emnity": "enmity",
    "empahsis": "emphasis",
    "empahsize": "emphasize",
    "empede": "impede",
    "emperical": "empirical",
    "emphaised": "emphasised",
    "emphsis": "emphasis",
    "emphysyma": "emphysema",
    "emporer": "emperor",
    "empound": "impound",
    "empoundment": "impoundment",
    "emprisoned": "imprisoned",
    "emrgency": "emergency",
    "enalbe": "enable",
    "enameld": "enameled",
    "enaugh": "enough",
    "enbankment": "embankment",
    "enchance": "enhance",
    "enchancement": "enhancement",
    "encorperate": "incorporate",
    "encorporate": "incorporate",
    "encouraing": "encouraging",
    "encouter": "encounter",
    "encryptiion": "encryption",
    "encylopedia": "encyclopedia",
    "endevors": "endeavors",
    "endevour": "endeavour",
    "endig": "ending",
    "endolithes": "endoliths",
    "enduce": "induce",
    "endurace": "endurance",
    "ened": "need",
    "enemey": "enemy",
    "energey": "energy",
    "enfected": "infected",
    "enforceing": "enforcing",
    "engagment": "engagement",
    "engeneer": "engineer",
    "engeneering": "engineering",
    "engieneer": "engineer",
    "engieneers": "engineers",
    "engilsh": "english",
    "engineeer": "engineer",
    "engineeering": "engineering",
    "engish": "english",
    "englih": "english",
    "englisch": "english",
    "engnies": "engines",
    "enigne": "engine",
    "enity": "entity",
    "enivoriment": "environment",
    "enlargment": "enlargement",
    "enlargments": "enlargements",
    "enogh": "enough",
    "enought": "enough",
    "enougn": "enough",
    "enouqh": "enough",
    "enourmous": "enormous",
    "enourmously": "enormously",
    "ensconsed": "ensconced",
    "enspired": "inspired",
    "entaglements": "entanglements",
    "enteprise": "enterprise",
    "enteratinment": "entertainment",
    "entere": "enter",
    "enterpreneur": "entrepreneur",
    "entertainement": "entertainment",
    "enthusiatic": "enthusiastic",
    "entilted": "entitled",
    "entirly": "entirely",
    "entited": "entitled",
    "entitied": "entitled",
    "entitity": "entity",
    "entitlied": "entitled",
    "entorely": "entirely",
    "entrace": "entrance",
    "entrepeneur": "entrepreneur",
    "entrepeneurial": "entrepreneurial",
    "entrepeneurs": "entrepreneurs",
    "enugh": "enough",
    "envention": "invention",
    "enviorment": "environment",
    "enviormental": "environmental",
    "enviormentally": "environmentally",
    "enviorments": "environments",
    "enviornment": "environment",
    "enviornmental": "environmental",
    "enviornmentalist": "environmentalist",
    "enviornmentally": "environmentally",
    "enviornments": "environments",
    "enviroment": "environment",
    "enviromental": "environmental",
    "enviromentalist": "environmentalist",
    "enviromentally": "environmentally",
    "enviroments": "environments",
    "envite": "invite",
    "envolutionary": "evolutionary",
    "envrionments": "environments",
    "enw": "new",
    "enxt": "next",
    "enybody": "anybody",
    "eonline": "online",
    "eonly": "only",
    "eople": "people",
    "eorge": "george",
    "eorks": "works",
    "eother": "other",
    "eould": "could",
    "eover": "over",
    "epademic": "epidemic",
    "epedemic": "epidemic",
    "ephone": "iphone",
    "epidmic": "epidemic",
    "epidsemic": "epidemic",
    "epidsodes": "episodes",
    "epiode": "episode",
    "epsiode": "episode",
    "eptitude": "aptitude",
    "epxlain": "explain",
    "equaly": "equally",
    "equialent": "equivalent",
    "equilavent": "equivalent",
    "equilibium": "equilibrium",
    "equilibrum": "equilibrium",
    "equiped": "equipped",
    "equippment": "equipment",
    "equiptment": "equipment",
    "equitorial": "equatorial",
    "equivalant": "equivalent",
    "equivalrnt": "equivalent",
    "equivelant": "equivalent",
    "equivelent": "equivalent",
    "equivilant": "equivalent",
    "equivilent": "equivalent",
    "equivlalent": "equivalent",
    "equvalent": "equivalent",
    "erally": "really",
    "erath": "earth",
    "eratic": "erratic",
    "eratically": "erratically",
    "eraticly": "erratically",
    "erlier": "earlier",
    "errect": "erect",
    "errode": "erode",
    "errosion": "erosion",
    "errupted": "erupted",
    "escpecially": "especially",
    "esctasy": "ecstasy",
    "esence": "essence",
    "esential": "essential",
    "esitmated": "estimated",
    "esle": "else",
    "espacially": "especially",
    "especiallly": "especially",
    "especialy": "especially",
    "espeically": "especially",
    "espose": "expose",
    "espresson": "espresso",
    "essencial": "essential",
    "essenger": "messenger",
    "essense": "essence",
    "essentail": "essential",
    "essental": "essential",
    "essentialy": "essentially",
    "essentual": "essential",
    "essesital": "essential",
    "estabilish": "establish",
    "estabishes": "establishes",
    "establised": "established",
    "establishement": "establishment",
    "establising": "establishing",
    "estalbish": "establish",
    "eswine": "swine",
    "etam": "team",
    "ethnocentricm": "ethnocentrism",
    "ethymology": "etymology",
    "euology": "eulogy",
    "euphamism": "euphemism",
    "europex": "europe",
    "eurpean": "european",
    "evean": "even",
    "evebn": "even",
    "eveen": "even",
    "evem": "ever",
    "evenhtually": "eventually",
    "evenn": "even",
    "eventally": "eventually",
    "eventhough": "even though",
    "eventially": "eventually",
    "eventualy": "eventually",
    "evernyone": "everyone",
    "evero": "ever",
    "everone": "everyone",
    "everr": "every",
    "everthing": "everything",
    "evertything": "everything",
    "everyonee": "everyone",
    "everyonr": "everyone",
    "everyopne": "everyone",
    "everythig": "everything",
    "everythinq": "everything",
    "everythjng": "everything",
    "everytime": "every time",
    "everyting": "everything",
    "evey": "every",
    "eveyone": "everyone",
    "eveyr": "every",
    "eveything": "everything",
    "evidentally": "evidently",
    "evindence": "evidence",
    "evre": "ever",
    "evrrything": "everything",
    "evrybody": "everybody",
    "evryone": "everyone",
    "evrytime": "everytime",
    "evul": "evil",
    "ewant": "want",
    "exacly": "exactly",
    "exactky": "exactly",
    "exagerate": "exaggerate",
    "exagerated": "exaggerated",
    "exagerates": "exaggerates",
    "exagerating": "exaggerating",
    "exagerrate": "exaggerate",
    "exagerrated": "exaggerated",
    "exagerrates": "exaggerates",
    "exagerrating": "exaggerating",
    "examinated": "examined",
    "exampt": "exempt",
    "examsa": "exams",
    "exapansion": "expansion",
    "exaplain": "explain",
    "exasparated": "exasperated",
    "exatly": "exactly",
    "exaust": "exhaust",
    "excact": "exact",
    "excactly": "exactly",
    "excange": "exchange",
    "excape": "escape",
    "excected": "expected",
    "excecute": "execute",
    "excecuted": "executed",
    "excecutes": "executes",
    "excecuting": "executing",
    "excecution": "execution",
    "excedded": "exceeded",
    "excelent": "excellent",
    "excell": "excel",
    "excellance": "excellence",
    "excellant": "excellent",
    "excells": "excels",
    "excempt": "exempt",
    "excercise": "exercise",
    "exchage": "exchange",
    "exchanching": "exchanging",
    "exchnage": "exchange",
    "excied": "excited",
    "excisted": "existed",
    "excitd": "excited",
    "excitied": "excited",
    "excitted": "excited",
    "exclsuive": "exclusive",
    "exclusieve": "exclusive",
    "excpt": "except",
    "excrutiating": "excruciating",
    "exctied": "excited",
    "exculsivly": "exclusively",
    "execising": "exercising",
    "execpt": "except",
    "exection": "execution",
    "exectly": "exactly",
    "exectued": "executed",
    "exeedingly": "exceedingly",
    "exelent": "excellent",
    "exellent": "excellent",
    "exemple": "example",
    "exept": "except",
    "exeptional": "exceptional",
    "exerbate": "exacerbate",
    "exerbated": "exacerbated",
    "exerciese": "exercises",
    "exericise": "exercise",
    "exerpt": "excerpt",
    "exerpts": "excerpts",
    "exersize": "exercise",
    "exerternal": "external",
    "exhalt": "exalt",
    "exhaltation": "exaltation",
    "exhalted": "exalted",
    "exhcange": "exchange",
    "exhibtion": "exhibition",
    "exhilirate": "exhilarate",
    "exhofon": "echofon",
    "exhuast": "exhaust",
    "exhuberance": "exuberance",
    "exhuberant": "exuberant",
    "exibit": "exhibit",
    "exibition": "exhibition",
    "exibitions": "exhibitions",
    "exicited": "excited",
    "exicted": "excited",
    "exicting": "exciting",
    "exinct": "extinct",
    "exisiting": "existing",
    "existance": "existence",
    "existant": "existent",
    "existince": "existence",
    "exliled": "exiled",
    "exlporing": "exploring",
    "exludes": "excludes",
    "exlusive": "exclusive",
    "exmaple": "example",
    "exonorate": "exonerate",
    "exoskelaton": "exoskeleton",
    "expain": "explain",
    "expalin": "explain",
    "expantion": "expansion",
    "expatriot": "expatriate",
    "expeced": "expected",
    "expecially": "especially",
    "expectede": "expected",
    "expeditonary": "expeditionary",
    "expeiments": "experiments",
    "expell": "expel",
    "expells": "expels",
    "expercience": "experience",
    "experement": "experiment",
    "experia": "xperia",
    "experiance": "experience",
    "experianced": "experienced",
    "experiecne": "experience",
    "experiense": "experience",
    "experince": "experience",
    "experment": "experiment",
    "expiditions": "expeditions",
    "expierence": "experience",
    "expierience": "experience",
    "expirement": "experiment",
    "explaied": "explained",
    "explaination": "explanation",
    "explaing": "explain",
    "explan": "explain",
    "explanantion": "explanation",
    "explane": "explain",
    "explaned": "explained",
    "explaning": "explaining",
    "explantion": "explanation",
    "explenation": "explanation",
    "explian": "explain",
    "explicitely": "explicitly",
    "explictly": "explicitly",
    "explination": "explanation",
    "exploititive": "exploitative",
    "explorring": "exploring",
    "explose": "expose",
    "explotation": "exploitation",
    "exporer": "explorer",
    "exposded": "exposed",
    "expropiated": "expropriated",
    "expropiation": "expropriation",
    "exressed": "expressed",
    "exscape": "escape",
    "exsist": "exist",
    "exsistance": "existence",
    "exsistence": "existence",
    "exspecially": "especially",
    "exsplain": "explain",
    "exstensive": "extensive",
    "extemely": "extremely",
    "extention": "extension",
    "extentions": "extensions",
    "extered": "exerted",
    "extermist": "extremist",
    "extradiction": "extradition",
    "extraterestrial": "extraterrestrial",
    "extraterrestial": "extraterrestrial",
    "extraterrestials": "extraterrestrials",
    "extravagence": "extravagance",
    "extravagent": "extravagant",
    "extre": "extra",
    "extreame": "extreme",
    "extrememly": "extremely",
    "extremeophile": "extremophile",
    "extremley": "extremely",
    "extremly": "extremely",
    "extrordinarily": "extraordinarily",
    "extrordinary": "extraordinary",
    "eyez": "eyes",
    "eyou": "you",
    "ezperience": "experience",
    "facbook": "facebook",
    "facebbok": "facebook",
    "facebok": "facebook",
    "faceboon": "facebook",
    "facefook": "facebook",
    "faceook": "facebook",
    "faciliate": "facilitate",
    "faciliated": "facilitated",
    "faciliates": "facilitates",
    "facilites": "facilities",
    "facillitate": "facilitate",
    "facillity": "facility",
    "facimile": "facsimile",
    "facinate": "fascinate",
    "facinated": "fascinated",
    "facination": "fascination",
    "facist": "fascist",
    "fackbook": "facebook",
    "facorite": "favorite",
    "facrbook": "facebook",
    "facsimilie": "facsimile",
    "facus": "focus",
    "faebook": "facebook",
    "fael": "feel",
    "fainally": "finally",
    "fairwell": "farewell",
    "fakt": "fact",
    "faliure": "failure",
    "falking": "talking",
    "fally": "fall",
    "falsley": "falsely",
    "falsly": "falsely",
    "famaly": "family",
    "familes": "families",
    "familey": "family",
    "familier": "familiar",
    "familiy": "family",
    "familliar": "familiar",
    "familt": "family",
    "familu": "family",
    "familyy": "family",
    "famiy": "family",
    "famliy": "family",
    "famouse": "famous",
    "famoust": "famous",
    "fanally": "finally",
    "fanasy": "fantasy",
    "fanatism": "fanaticism",
    "fanily": "family",
    "fanz": "fan",
    "farward": "forward",
    "fascitious": "facetious",
    "fashism": "fascism",
    "fasinate": "fascinate",
    "fasion": "fashion",
    "fatalies": "fatalities",
    "fatalites": "fatalities",
    "fataly": "fatally",
    "fatc": "fact",
    "fately": "fatally",
    "faught": "caught",
    "faught": "fought",
    "favoirte": "favorite",
    "favorate": "favorite",
    "favoritee": "favorite",
    "favortie": "favorite",
    "favorute": "favorite",
    "favouriye": "favourite",
    "favoutrable": "favourable",
    "favroite": "favorite",
    "fbook": "book",
    "fcebook": "facebook",
    "fcked": "fucked",
    "fcking": "fucking",
    "fcukin": "fuckin",
    "fcuking": "fucking",
    "fcus": "focus",
    "fdo": "do",
    "fdor": "for",
    "feasability": "feasibility",
    "feasable": "feasible",
    "featue": "feature",
    "feauture": "feature",
    "feautures": "features",
    "federaly": "federally",
    "fedreally": "federally",
    "feedz": "feeds",
    "feeel": "feel",
    "feeeling": "feeling",
    "feeels": "feels",
    "feek": "feel",
    "feeld": "feels",
    "feelf": "feel",
    "feelig": "feeling",
    "feelign": "feeling",
    "feelinn": "feeling",
    "feelinq": "feeling",
    "feell": "feel",
    "feell": "feels",
    "feelling": "feeling",
    "feeln": "feel",
    "feelng": "feeling",
    "feelong": "feeling",
    "feelt": "feel",
    "feelz": "feel",
    "feelz": "feels",
    "feew": "few",
    "feiel": "feel",
    "feiends": "friends",
    "feirce": "fierce",
    "feling": "feeling",
    "felliw": "fellow",
    "felp": "help",
    "fely": "felt",
    "femaile": "female",
    "femminist": "feminist",
    "fense": "fence",
    "fergot": "forgot",
    "feromone": "pheromone",
    "fertily": "fertility",
    "ferw": "few",
    "fesktop": "desktop",
    "festval": "festival",
    "fetaures": "features",
    "feveer": "fever",
    "feverr": "fever",
    "feww": "few",
    "ffice": "office",
    "ffind": "find",
    "ffixed": "fixed",
    "ffor": "for",
    "ffrom": "from",
    "fght": "fight",
    "fgor": "for",
    "fhat": "that",
    "fiamily": "family",
    "fianally": "finally",
    "fianite": "finite",
    "fianl": "final",
    "fianlly": "finally",
    "ficition": "fiction",
    "ficitional": "fictional",
    "ficiton": "fiction",
    "ficticious": "fictitious",
    "fictious": "fictitious",
    "fictonal": "fictional",
    "fictous": "fictitious",
    "fidn": "find",
    "fiercly": "fiercely",
    "fiest": "first",
    "figd": "find",
    "fighing": "fighting",
    "fightings": "fighting",
    "fightinhg": "fighting",
    "fightning": "fighting",
    "figiring": "figuring",
    "figture": "figure",
    "figue": "figure",
    "figuerd": "figured",
    "figuered": "figured",
    "figuire": "figure",
    "figurd": "figure",
    "figurd": "figured",
    "figuren": "figure",
    "fiinally": "finally",
    "fiind": "find",
    "fiirst": "first",
    "fiit": "fit",
    "filiament": "filament",
    "fillament": "filament",
    "filmaker": "filmmaker",
    "filmaking": "filmmaking",
    "fimally": "finally",
    "fimilies": "families",
    "finacial": "financial",
    "finalley": "finally",
    "finallly": "finally",
    "finallt": "finally",
    "finaly": "finally",
    "finalyl": "finally",
    "finalzly": "finally",
    "financialy": "financially",
    "finda": "find",
    "findd": "find",
    "fineally": "finally",
    "finelly": "finally",
    "fingure": "figure",
    "finially": "finally",
    "finilly": "finally",
    "finised": "finished",
    "finlly": "finally",
    "finnally": "finally",
    "finnaly": "finally",
    "finnished": "finished",
    "finnisher": "finisher",
    "finshed": "finished",
    "finsihed": "finished",
    "fint": "find",
    "fintasy": "fantasy",
    "finully": "finally",
    "fiot": "fit",
    "firday": "friday",
    "firend": "friend",
    "firends": "friends",
    "firfox": "firefox",
    "firgure": "figure",
    "firmwave": "firmware",
    "firsr": "first",
    "firt": "first",
    "fishs": "fishes",
    "fisionable": "fissionable",
    "fisrt": "first",
    "fisure": "figure",
    "fith": "fifth",
    "fitn": "fit",
    "fitst": "first",
    "fiu": "flu",
    "fixd": "fixed",
    "fixex": "fixed",
    "fiy": "fit",
    "fku": "flu",
    "flacid": "flaccid",
    "flaged": "flagged",
    "flamable": "flammable",
    "flawess": "flawless",
    "flewn": "flown",
    "flexability": "flexibility",
    "flicke": "flickr",
    "flikr": "flickr",
    "fllowing": "following",
    "florescent": "fluorescent",
    "flourescent": "fluorescent",
    "flouride": "fluoride",
    "flourine": "fluorine",
    "flourishment": "flourishing",
    "flouroscopy": "fluoroscopy",
    "flove": "love",
    "flua": "flu",
    "fluck": "fuck",
    "flucking": "fucking",
    "flui": "flu",
    "flul": "flu",
    "fluorish": "flourish",
    "fluroscopy": "fluoroscopy",
    "flut": "flu",
    "fluu": "flu",
    "fluv": "flu",
    "fluw": "flu",
    "fluy": "flu",
    "fmy": "my",
    "fnally": "finally",
    "fnding": "finding",
    "fnew": "new",
    "focking": "fucking",
    "focuse": "focus",
    "fodd": "food",
    "foer": "for",
    "fogot": "forgot",
    "foing": "going",
    "foir": "for",
    "foitness": "fitness",
    "folicle": "follicle",
    "folllow": "follow",
    "followw": "follow",
    "follw": "follow",
    "follwoing": "following",
    "folow": "follow",
    "folowed": "followed",
    "folower": "follower",
    "folowing": "following",
    "fomed": "formed",
    "fomer": "former",
    "fomerly": "formerly",
    "fonally": "finally",
    "fonetic": "phonetic",
    "fontrier": "fontier",
    "foodd": "food",
    "foogle": "google",
    "foood": "food",
    "foootball": "football",
    "foor": "for",
    "foos": "food",
    "footware": "footwear",
    "foound": "found",
    "for-runner": "forerunner",
    "forawrd": "forward",
    "forbad": "forbade",
    "forbiden": "forbidden",
    "forceing": "forcing",
    "forebad": "forbad",
    "forebade": "forbade",
    "forebid": "forbid",
    "forebidden": "forbidden",
    "foreceps": "forceps",
    "forefeit": "forfeit",
    "forefiet": "forfeit",
    "forefieture": "forfeiture",
    "foreget": "forget",
    "forelese": "forlese",
    "forelorn": "forlorn",
    "foresake": "forsake",
    "foresook": "forsook",
    "forevr": "forever",
    "foreward": "foreword",
    "forf": "for",
    "forfiet": "forfeit",
    "forfieture": "forfeiture",
    "forgott": "forgot",
    "forgrt": "forget",
    "forh": "for",
    "forhead": "forehead",
    "foriegn": "foreign",
    "foriegner": "foreigner",
    "formall": "formal",
    "formallize": "formalize",
    "formallized": "formalized",
    "formaly": "formally",
    "formelly": "formerly",
    "formerley": "formerly",
    "formidible": "formidable",
    "formost": "foremost",
    "formware": "firmware",
    "forrmerly": "formerly",
    "forrunner": "forerunner",
    "forsaw": "foresaw",
    "forseeable": "foreseeable",
    "forseen": "foreseen",
    "forshadow": "foreshadow",
    "forsight": "foresight",
    "fortell": "foretell",
    "fortelling": "foretelling",
    "fortunatly": "fortunately",
    "foru": "for",
    "forumla": "formula",
    "forumlate": "formulate",
    "forunner": "forerunner",
    "forver": "forever",
    "forwad": "forward",
    "forword": "forward",
    "forwrad": "forward",
    "forwrard": "forward",
    "fory": "for",
    "fot the": "for the",
    "fotr": "for",
    "foucs": "focus",
    "foudn": "found",
    "fougth": "fought",
    "fouind": "found",
    "foundaries": "foundries",
    "foundary": "foundry",
    "foundd": "found",
    "founf": "found",
    "founfd": "found",
    "fourties": "forties",
    "fourty": "forty",
    "fouth": "fourth",
    "fouund": "found",
    "foward": "forward",
    "fown": "down",
    "fragement": "fragment",
    "francsico": "francisco",
    "franfurt": "frankfurt",
    "franscisco": "francisco",
    "freacking": "freaking",
    "freakn": "freaks",
    "freek": "free",
    "freeked": "freaked",
    "freeking": "freaking",
    "freeks": "freaks",
    "freie": "free",
    "freind": "friend",
    "freindly": "friendly",
    "freinds": "friends",
    "frends": "friends",
    "frequentily": "frequently",
    "fresers": "freshers",
    "frew": "free",
    "frgot": "forgot",
    "fridayy": "friday",
    "frieds": "friends",
    "friendss": "friends",
    "friendx": "friends",
    "friennd": "friend",
    "friens": "friends",
    "friiends": "friends",
    "frinds": "friends",
    "frined": "friend",
    "frineds": "friends",
    "frive": "drive",
    "frnt": "front",
    "frolm": "from",
    "fromat": "format",
    "frome": "from",
    "fromed": "formed",
    "fromerly": "formerly",
    "fromi": "from",
    "froming": "forming",
    "fromn": "from",
    "fromt he": "from the",
    "fromt": "front",
    "fromthe": "from the",
    "fron the": "from the",
    "froniter": "frontier",
    "fronteir": "frontier",
    "frontspiece": "frontispiece",
    "frony": "front",
    "fror": "for",
    "frought": "fraught",
    "frozed": "frozen",
    "frpm": "from",
    "frpom": "from",
    "frree": "free",
    "frshers": "freshers",
    "frst": "first",
    "frtom": "from",
    "fruck": "fuck",
    "fruiton": "fruition",
    "frun": "fun",
    "frunt": "front",
    "frution": "fruition",
    "fter": "after",
    "ftom": "from",
    "ftweeting": "tweeting",
    "fucc": "fuck",
    "fucced": "fucked",
    "fuccin": "fuckin",
    "fuccing": "fucking",
    "fuch": "fuck",
    "fuckd": "fucked",
    "fuckiing": "fucking",
    "fuckimg": "fucking",
    "fuckingg": "fucking",
    "fuckinh": "fucking",
    "fuckinn": "fucking",
    "fuckinq": "fucking",
    "fuckk": "fuck",
    "fuckkng": "fucking",
    "fuckn": "fuckin",
    "fucntion": "function",
    "fucntioning": "functioning",
    "fuction": "fiction",
    "fued": "feud",
    "fuedal": "feudal",
    "fufill": "fulfill",
    "fufilled": "fulfilled",
    "fuguring": "figuring",
    "fukc": "fuck",
    "fuked": "fucked",
    "fuking": "fucking",
    "fukk": "fuck",
    "fukkin": "fuckin",
    "fukn": "fun",
    "fulfiled": "fulfilled",
    "fullfil": "fulfill",
    "fullfill": "fulfill",
    "fullfilled": "fulfilled",
    "fulll": "full",
    "funally": "finally",
    "func": "fun",
    "funcina": "funciona",
    "functionaly": "functionally",
    "fundamentaly": "fundamentally",
    "fundametal": "fundamental",
    "fundametals": "fundamentals",
    "fundation": "foundation",
    "fundemental": "fundamental",
    "funf": "fun",
    "funguses": "fungi",
    "funn": "fun",
    "funnn": "funny",
    "funnuest": "funniest",
    "funtion": "function",
    "funy": "funny",
    "fuoll": "full",
    "fuqk": "fuck",
    "furhter": "further",
    "furhtermore": "furthermore",
    "furnature": "furniture",
    "furtile": "fertile",
    "furuther": "further",
    "fustrate": "frustrate",
    "futeure": "future",
    "futher": "further",
    "futhermore": "furthermore",
    "futness": "fitness",
    "fuul": "full",
    "fuxk": "fuck",
    "fuxking": "fucking",
    "fwel": "feel",
    "fwhich": "which",
    "fwpwebhost": "wpwebhost",
    "fwrd": "fwd",
    "fxck": "fuck",
    "fxcking": "fucking",
    "fyck": "fuck",
    "fysical": "physical",
    "gadgert": "gadget",
    "gading": "gaming",
    "gagdet": "gadget",
    "galatic": "galactic",
    "gald": "glad",
    "galexy": "galaxy",
    "gallary": "gallery",
    "gallaxies": "galaxies",
    "galvinized": "galvanized",
    "galxy": "galaxy",
    "gamez": "game",
    "gamr": "game",
    "ganalytics": "analytics",
    "gandi": "gandhi",
    "ganerate": "generate",
    "ganes": "games",
    "ganhdi": "gandhi",
    "ganster": "gangster",
    "gapps": "apps",
    "garantee": "guarantee",
    "garanteed": "guaranteed",
    "garantees": "guarantees",
    "gardai": "gardaí",
    "gardisil": "gardasil",
    "garisson": "garrison",
    "garnison": "garrison",
    "garrision": "garrison",
    "garrisson": "garrison",
    "gauarana": "guaraná",
    "gaurantee": "guarantee",
    "gauranteed": "guaranteed",
    "gaurantees": "guarantees",
    "gaurdian": "guardian",
    "gaurentee": "guarantee",
    "gaurenteed": "guaranteed",
    "gaurentees": "guarantees",
    "gbaby": "baby",
    "gbig": "big",
    "gbike": "bike",
    "gdamn": "damn",
    "gdocs": "docs",
    "geader": "reader",
    "geath": "death",
    "geetin": "gettin",
    "geeting": "getting",
    "geetting": "getting",
    "geh": "get",
    "genaral": "general",
    "genearl": "general",
    "geneological": "genealogical",
    "geneologies": "genealogies",
    "geneology": "genealogy",
    "generaly": "generally",
    "generatd": "generated",
    "generater": "generator",
    "generatting": "generating",
    "genertion": "generation",
    "genialia": "genitalia",
    "genisis": "genesis",
    "genra": "genera or genre",
    "genreal": "general",
    "genting": "getting",
    "genuis": "genius",
    "geographicial": "geographical",
    "geometrician": "geometer",
    "geometricians": "geometers",
    "gerat": "great",
    "geth": "get",
    "getiing": "getting",
    "geting": "getting",
    "getitng": "getting",
    "getn": "get",
    "getn": "gets",
    "getteing": "getting",
    "gettig": "getting",
    "gettign": "getting",
    "gettihg": "getting",
    "gettiin": "gettin",
    "gettiing": "getting",
    "gettimg": "getting",
    "gettina": "getting",
    "gettinb": "getting",
    "gettingg": "getting",
    "gettinh": "getting",
    "gettinng": "getting",
    "gettinq": "getting",
    "gettins": "getting",
    "gettint": "getting",
    "gettitng": "getting",
    "gettling": "getting",
    "gettn": "gettin",
    "gettng": "getting",
    "gettong": "getting",
    "getttin": "gettin",
    "gettting": "getting",
    "gety": "get",
    "getying": "getting",
    "geuss": "guess",
    "geyt": "get",
    "gflash": "flash",
    "gfor": "for",
    "ggds": "gods",
    "gget": "get",
    "ghave": "have",
    "ghe": "the",
    "ghet": "get",
    "ghot": "got",
    "ghots": "shots",
    "giive": "give",
    "gilmpse": "glimpse",
    "gilr": "girl",
    "giong": "going",
    "giot": "got",
    "girate": "gyrate",
    "girated": "gyrated",
    "girates": "gyrates",
    "girating": "gyrating",
    "giration": "gyration",
    "girlfreind": "girlfriend",
    "girls's": "girls'",
    "girlss": "girls",
    "girst": "first",
    "gistory": "history",
    "giude": "guide",
    "giult": "guilt",
    "giuy": "guy",
    "giva": "give",
    "givaway": "giveaway",
    "givbe": "give",
    "giveing": "giving",
    "givien": "given",
    "givng": "giving",
    "givs": "gives",
    "givw": "give",
    "givz": "give",
    "glaad": "glad",
    "glamourous": "glamorous",
    "glasss": "glass",
    "glight": "flight",
    "glimpes": "glimpse",
    "glod": "god",
    "gmaes": "games",
    "gmaili": "gmail",
    "gmaill": "gmail",
    "gmailz": "gmail",
    "gmaps": "maps",
    "gmsil": "gmail",
    "gnawwed": "gnawed",
    "gnna": "gonna",
    "gnoogle": "google",
    "gnow": "now",
    "godd": "good",
    "godess": "goddess",
    "godesses": "goddesses",
    "godgle": "google",
    "godness": "goodness",
    "goeing": "going",
    "goet": "got",
    "goez": "goes",
    "gogle": "google",
    "gogole": "google",
    "goht": "got",
    "goid": "good",
    "goig": "going",
    "goigle": "google",
    "goign": "going",
    "goiing": "going",
    "goijng": "going",
    "goina": "gonna",
    "goinfg": "going",
    "goingf": "going",
    "goingg": "going",
    "goingo": "going",
    "goinh": "going",
    "goini": "going",
    "goinn": "going",
    "goinng": "going",
    "goint": "going",
    "goldgen": "golden",
    "gollf": "golf",
    "golng": "going",
    "goming": "coming",
    "goming": "going",
    "gomogle": "google",
    "gonig": "going",
    "goning": "going",
    "gonnah": "gonna",
    "gonnna": "gonna",
    "goob": "good",
    "gooble": "google",
    "good riddens": "good riddance",
    "goodi": "good",
    "goodle": "google",
    "goofle": "google",
    "googe": "google",
    "googel": "google",
    "googgle": "google",
    "googke": "google",
    "googlee": "google",
    "googlei": "google",
    "googley": "google",
    "googlle": "google",
    "googlr": "google",
    "googlw": "google",
    "goolge": "google",
    "goolgle": "google",
    "goood": "good",
    "gooogle": "google",
    "goot": "got",
    "goovle": "google",
    "gopod": "good",
    "gopt": "got",
    "goses": "goes",
    "goshh": "gosh",
    "gotda": "gotta",
    "gotn": "got",
    "gotr": "got",
    "gotsa": "gotta",
    "gotst": "gots",
    "gottaa": "gotta",
    "gottah": "gotta",
    "gottal": "gotta",
    "gottan": "gotten",
    "gotting": "getting",
    "gottn": "gotten",
    "gotton": "gotten",
    "gottta": "gotta",
    "gottten": "gotten",
    "goty": "got",
    "gouing": "going",
    "gouvener": "governor",
    "govement": "government",
    "govenment": "government",
    "govenor": "governor",
    "govenrment": "government",
    "goverance": "governance",
    "goverement": "government",
    "goverment": "government",
    "govermental": "governmental",
    "governement": "government",
    "governer": "governor",
    "governmentaly": "governmentally",
    "governmnet": "government",
    "govorment": "government",
    "govormental": "governmental",
    "govornment": "government",
    "gowna": "gonna",
    "gphone": "phone",
    "gpot": "got",
    "gpush": "push",
    "grabed": "grabbed",
    "grabing": "grabbing",
    "gracefull": "graceful",
    "gracesm": "graces",
    "gradualy": "gradually",
    "graet": "great",
    "graffitti": "graffiti",
    "grafitti": "graffiti",
    "gramatically": "grammatically",
    "gramattical": "grammatical",
    "grammaticaly": "grammatically",
    "grammer": "grammar",
    "granchild": "grandchild",
    "granchildren": "grandchildren",
    "grandure": "grandeur",
    "granfather": "grandfather",
    "granmother": "grandmother",
    "granparent": "grandparent",
    "granson": "grandson",
    "grat": "great",
    "gratuitious": "gratuitous",
    "greaat": "great",
    "greader": "reader",
    "grear": "great",
    "greately": "greatly",
    "greatful": "grateful",
    "greatfully": "gratefully",
    "greaty": "great",
    "greif": "grief",
    "grestest": "greatest",
    "gretest": "greatest",
    "greviance": "grievance",
    "gridles": "griddles",
    "groogle": "google",
    "gropu": "group",
    "grug": "drug",
    "grwo": "grow",
    "gsync": "sync",
    "gtalk": "talk",
    "gthe": "the",
    "gtot": "got",
    "gtreat": "great",
    "gtta": "gotta",
    "gttin": "gettin",
    "gtting": "getting",
    "guage": "gauge",
    "guap": "gap",
    "guardasil": "gardasil",
    "guarentee": "guarantee",
    "guarenteed": "guaranteed",
    "guarentees": "guarantees",
    "guees": "guess",
    "guerrila": "guerrilla",
    "guerrilas": "guerrillas",
    "guesss": "guess",
    "guice": "guide",
    "guidence": "guidance",
    "guiford": "guilford",
    "guiode": "guide",
    "guitarrist": "guitarist",
    "guiter": "guitar",
    "guitqr": "guitar",
    "guituar": "guitar",
    "guive": "give",
    "gunanine": "guanine",
    "gurad": "guard",
    "guradian": "guardian",
    "gurantee": "guarantee",
    "guranteed": "guaranteed",
    "gurantees": "guarantees",
    "gutiar": "guitar",
    "guttaral": "guttural",
    "gutteral": "guttural",
    "guyes": "guys",
    "guyz": "guys",
    "gvae": "gave",
    "gve": "give",
    "gvie": "give",
    "gving": "giving",
    "gvoice": "voice",
    "gweet": "tweet",
    "gwip": "grip",
    "gwoogle": "google",
    "gwtting": "getting",
    "gxt": "got",
    "haaha": "haha",
    "haate": "hate",
    "haave": "have",
    "haaz": "haz",
    "habaeus": "habeas",
    "habbit": "habit",
    "habds": "hands",
    "habeus corpus": "habeas corpus",
    "habeus": "habeas",
    "habing": "having",
    "habor": "harbor or harbour",
    "habour": "harbour or harbor",
    "hacve": "have",
    "hadd": "had",
    "haemorrage": "haemorrhage",
    "haev": "have",
    "hafve": "have",
    "hahaa": "haha",
    "hahah": "haha",
    "hahh": "haha",
    "hahha": "haha",
    "hahha": "hahaha",
    "haite": "hate",
    "halarious": "hilarious",
    "hallowen": "halloween",
    "halp": "help",
    "handeled": "handled",
    "handss": "hands",
    "handz": "hands",
    "haning": "hanging",
    "hankerchief": "handkerchief",
    "haopen": "happen",
    "haox": "hoax",
    "hapen": "happen",
    "hapened": "happened",
    "hapening": "happening",
    "hapens": "happens",
    "happeded": "happened",
    "happedned": "happened",
    "happend": "happened",
    "happended": "happened",
    "happending": "happening",
    "happends": "happens",
    "happenedd": "happened",
    "happenned": "happened",
    "happent": "happen",
    "happn": "happen",
    "happned": "happened",
    "happns": "happens",
    "happpened": "happened",
    "happpy": "happy",
    "happyy": "happy",
    "harased": "harassed",
    "harases": "harasses",
    "harasment": "harassment",
    "harasments": "harassments",
    "harassement": "harassment",
    "hardd": "hard",
    "harly": "hardly",
    "harras": "harass",
    "harrased": "harassed",
    "harrases": "harasses",
    "harrasing": "harassing",
    "harrasment": "harassment",
    "harrasments": "harassments",
    "harrassed": "harassed",
    "harrasses": "harassed",
    "harrassing": "harassing",
    "harrassment": "harassment",
    "harrassments": "harassments",
    "hasd": "had",
    "hasing": "having",
    "hasnt": "hasn't",
    "hastag": "hashtag",
    "hastly": "hastily",
    "hasz": "has",
    "hatey": "hates",
    "hatin": "havin",
    "haue": "have",
    "hava": "have",
    "havd": "have",
    "havea": "have",
    "haved": "have",
    "haveu": "have",
    "havey": "have",
    "havibg": "having",
    "haviest": "heaviest",
    "havig": "having",
    "havign": "having",
    "haviing": "having",
    "havina": "having",
    "havingg": "having",
    "havingh": "having",
    "havinh": "having",
    "havinq": "having",
    "havn": "have",
    "havng": "having",
    "havnig": "having",
    "havnt": "havent",
    "havr": "have",
    "havt": "have",
    "havung": "having",
    "havv": "have",
    "havve": "have",
    "havw": "have",
    "havz": "have",
    "hazerdous": "hazardous",
    "hbope": "hope",
    "heaadphones": "headphones",
    "headace": "headache",
    "headd": "head",
    "headn": "head",
    "headquarer": "headquarter",
    "headquartes": "headquarters",
    "headquater": "headquarter",
    "headquatered": "headquartered",
    "headquaters": "headquarters",
    "heae": "hear",
    "healhty": "healthy",
    "healthercare": "healthcare",
    "healty": "healthy",
    "hearding": "hearing",
    "heardly": "hardly",
    "heared": "heard",
    "hearthrob": "heartthrob",
    "heatd": "heard",
    "heathy": "healthy",
    "heatlh": "health",
    "heatlth": "health",
    "heaviliy": "heavily",
    "hecc": "heck",
    "hedghog": "hedgehog",
    "heek": "heck",
    "heey": "hey",
    "heigher": "higher",
    "heirarchial": "hierarchical",
    "heirarchical": "hierarchical",
    "heirarchy": "hierarchy",
    "heiroglyphics": "hieroglyphics",
    "hekk": "heck",
    "hekp": "help",
    "helath": "health",
    "helded": "held",
    "helll": "hell",
    "hellz": "hello",
    "helment": "helmet",
    "helpd": "helps",
    "helpfull": "helpful",
    "helpped": "helped",
    "hels": "help",
    "hemmorhage": "hemorrhage",
    "henious": "heinous",
    "heptathalon": "heptathlon",
    "herad": "heard",
    "heralda": "herald",
    "herer": "here",
    "heridity": "heredity",
    "heroe": "hero",
    "heros": "heroes",
    "hersuit": "hirsute",
    "hersute": "hirsute",
    "hertiage": "heritage",
    "hertzs": "hertz",
    "hesistant": "hesitant",
    "heterogenous": "heterogeneous",
    "heto": "hero",
    "hetting": "getting",
    "hever": "ever",
    "heyy": "hey",
    "hgappens": "happens",
    "hhad": "had",
    "hhave": "have",
    "hhe": "the",
    "hhow": "how",
    "hidding": "hiding",
    "hieght": "height",
    "hieghts": "heights",
    "hierachical": "hierarchical",
    "hierachies": "hierarchies",
    "hierachy": "hierarchy",
    "hierarcical": "hierarchical",
    "hierarcy": "hierarchy",
    "hieroglph": "hieroglyph",
    "hieroglphs": "hieroglyphs",
    "higer": "higher",
    "higest": "highest",
    "highight": "highlight",
    "highky": "highly",
    "highter": "higher",
    "higway": "highway",
    "hillarious": "hilarious",
    "hiltion": "hilton",
    "himb": "him",
    "himselv": "himself",
    "hinderance": "hindrance",
    "hinderence": "hindrance",
    "hindrence": "hindrance",
    "hiphone": "iphone",
    "hipopotamus": "hippopotamus",
    "hirsuit": "hirsute",
    "hirung": "hiring",
    "hismelf": "himself",
    "hispital": "hospital",
    "histocompatability": "histocompatibility",
    "historicians": "historians",
    "histroy": "history",
    "hitchs": "hitches",
    "hiting": "hitting",
    "hitory": "history",
    "hitsingles": "hit singles",
    "hittig": "hitting",
    "hjave": "have",
    "hjust": "just",
    "hlep": "help",
    "hobbiest": "hobbyist",
    "hoem": "home",
    "hoep": "hope",
    "hoing": "going",
    "holdiay": "holiday",
    "holdn": "hold",
    "holf": "hold",
    "hollah": "holla",
    "holliday": "holiday",
    "hollistic": "holistic",
    "hombrew": "homebrew",
    "homeopage": "homepage",
    "homestate": "home state",
    "homne": "home",
    "homocide": "homicide",
    "homogeneize": "homogenize",
    "homogeneized": "homogenized",
    "hompage": "homepage",
    "homw": "home",
    "homwe": "home",
    "honory": "honorary",
    "honost": "honest",
    "hooe": "hope",
    "hooes": "hoes",
    "hooken": "hooked",
    "hooo": "hoo",
    "hoope": "hope",
    "hoow": "how",
    "hopefuly": "hopefully",
    "hopefylly": "hopefully",
    "hopeing": "hoping",
    "hopew": "hope",
    "hopfully": "hopefully",
    "hopig": "hoping",
    "hopiing": "hoping",
    "hopinf": "hoping",
    "hopital": "hospital",
    "hopn": "hope",
    "hopr": "hope",
    "hopsital": "hospital",
    "hopt": "hope",
    "hopw": "how",
    "hopwfully": "hopefully",
    "hoq": "how",
    "horible": "horrible",
    "horrable": "horrible",
    "horriable": "horrible",
    "horrifing": "horrifying",
    "horrile": "horrible",
    "horrrible": "horrible",
    "hosbital": "hospital",
    "hosipital": "hospital",
    "hosited": "hoisted",
    "hospitaized": "hospitalized",
    "hospitalm": "hospital",
    "hospitial": "hospital",
    "hospitible": "hospitable",
    "hospitol": "hospital",
    "hosptal": "hospital",
    "hosptial": "hospital",
    "hosptialized": "hospitalized",
    "hoston": "houston",
    "hostpital": "hospital",
    "hotoshop": "photoshop",
    "hounour": "honour",
    "hourr": "hour",
    "housee": "house",
    "housewifes": "housewives",
    "houshold": "household",
    "houskeeper": "housekeeper",
    "houswife": "housewife",
    "hov": "how",
    "hown": "how",
    "howver": "however",
    "howw": "how",
    "howz": "how",
    "hpe": "hope",
    "hpoe": "hope",
    "hpome": "home",
    "hpw": "how",
    "hqs": "has",
    "hrome": "chrome",
    "hshit": "shit",
    "hsitorians": "historians",
    "hsnd": "hand",
    "hstory": "history",
    "hsve": "have",
    "htat": "that",
    "htey": "they",
    "hthe": "the",
    "htikn": "think",
    "hting": "thing",
    "htink": "think",
    "htis": "this",
    "htought": "thought",
    "huminoid": "humanoid",
    "humoural": "humoral",
    "humurous": "humorous",
    "hundered": "hundred",
    "hurtn": "hurts",
    "hurtz": "hurts",
    "husban": "husband",
    "husts": "hurts",
    "hvae": "have",
    "hvaing": "having",
    "hve": "have",
    "hve": "he",
    "hvent": "havent",
    "hving": "having",
    "hwas": "was",
    "hwihc": "which",
    "hwile": "while",
    "hwo": "how",
    "hwo": "who",
    "hwole": "whole",
    "hydogen": "hydrogen",
    "hydralic": "hydraulic",
    "hydropile": "hydrophile",
    "hydropilic": "hydrophilic",
    "hydropobe": "hydrophobe",
    "hydropobic": "hydrophobic",
    "hygeine": "hygiene",
    "hygene": "hygiene",
    "hygine": "hygiene",
    "hyjack": "hijack",
    "hyjacking": "hijacking",
    "hypocracy": "hypocrisy",
    "hypocrasy": "hypocrisy",
    "hypocricy": "hypocrisy",
    "hypocrit": "hypocrite",
    "hypocrits": "hypocrites",
    "hyprocrite": "hypocrite",
    "hyptonize": "hypnotize",
    "iage": "age",
    "ialarm": "alarm",
    "ialways": "always",
    "iapps": "apps",
    "iberlin": "berlin",
    "ibiker": "ibike",
    "ibricked": "bricked",
    "ibroken": "broken",
    "icable": "cable",
    "icant": "cant",
    "iceburg": "iceberg",
    "iceing": "icing",
    "ichanged": "changed",
    "iconclastic": "iconoclastic",
    "icrease": "increase",
    "idaeidae": "idea",
    "idaes": "ideas",
    "iddea": "idea",
    "idead": "idea",
    "idealogies": "ideologies",
    "idealogy": "ideology",
    "idealy": "ideally",
    "ideia": "idea",
    "idek": "idea",
    "idek": "idk",
    "idenify": "identify",
    "idenity": "identity",
    "identicaly": "identically",
    "identicial": "identical",
    "identifed": "identified",
    "identifers": "identifiers",
    "identifing": "identifying",
    "ideosyncratic": "idiosyncratic",
    "idiodic": "idiotic",
    "idiosyncracy": "idiosyncrasy",
    "idkk": "idk",
    "idont": "dont",
    "idrop": "drop",
    "idropped": "dropped",
    "idunno": "dunno",
    "ieven": "even",
    "ievolution": "evolution",
    "ifeel": "feel",
    "ifelt": "felt",
    "ifit": "fit",
    "iflash": "flash",
    "iforgot": "forgot",
    "ifound": "found",
    "ifriends": "friends",
    "ifrom": "from",
    "ifuckkin": "ifukkin",
    "ifun": "fun",
    "iget": "get",
    "igetting": "getting",
    "igot": "got",
    "iguiide": "iguide",
    "ihad": "had",
    "ihate": "hate",
    "ihave": "have",
    "ihome": "home",
    "ihone": "iphone",
    "ihpone": "iphone",
    "iight": "right",
    "iinstead": "instead",
    "iinternet": "internet",
    "iinto": "into",
    "iinvite": "invite",
    "iiphone": "iphone",
    "iisten": "listen",
    "iive": "ive",
    "ijust": "just",
    "ikeyboard": "keyboard",
    "ilab": "lab",
    "ilegally": "illegally",
    "illegaly": "illegally",
    "illegimacy": "illegitimacy",
    "illegimate": "illegitimate",
    "illegitmate": "illegitimate",
    "illess": "illness",
    "illict": "illicit",
    "illiegal": "illegal",
    "illl": "ill",
    "illn": "ill",
    "illution": "illusion",
    "ilness": "illness",
    "ilogical": "illogical",
    "ilumination": "illumination",
    "iluv": "luv",
    "imagas": "images",
    "imagenary": "imaginary",
    "imagin": "imagine",
    "imagis": "images",
    "imags": "images",
    "imay": "may",
    "imcomplete": "incomplete",
    "imeages": "images",
    "imeant": "meant",
    "imediate": "immediate",
    "imediately": "immediately",
    "imense": "immense",
    "imgaes": "images",
    "imge": "image",
    "imges": "images",
    "imiss": "miss",
    "immagination": "imagination",
    "immediatelly": "immediately",
    "immediatley": "immediately",
    "immediatly": "immediately",
    "immensley": "immensely",
    "immensly": "immensely",
    "immidately": "immediately",
    "immidiately": "immediately",
    "immitate": "imitate",
    "immitated": "imitated",
    "immitating": "imitating",
    "immitation": "imitation",
    "immitator": "imitator",
    "immunosupressant": "immunosuppressant",
    "immuntable": "immutable",
    "immuse": "immune",
    "imobile": "mobile",
    "imoral": "immoral",
    "imortant": "important",
    "impare": "impair",
    "impass": "impasse",
    "impecabbly": "impeccably",
    "impedence": "impedance",
    "imperic": "empiric",
    "imperically": "empirically",
    "implamenting": "implementing",
    "impliment": "implement",
    "implimented": "implemented",
    "imploys": "employs",
    "imporant": "important",
    "imporatnt": "important",
    "importamt": "important",
    "importan": "important",
    "importanct": "important",
    "importnt": "important",
    "impove": "improve",
    "impressario": "impresario",
    "imprioned": "imprisoned",
    "imprisonned": "imprisoned",
    "improvision": "improvisation",
    "improvment": "improvement",
    "improvments": "improvements",
    "imprtant": "important",
    "imprve": "improve",
    "imune": "immune",
    "imvite": "invite",
    "imy": "my",
    "in leiu": "in lieu",
    "inablility": "inability",
    "inaccessable": "inaccessible",
    "inadiquate": "inadequate",
    "inadquate": "inadequate",
    "inadvertant": "inadvertent",
    "inadvertantly": "inadvertently",
    "inages": "images",
    "inagurated": "inaugurated",
    "inaguration": "inauguration",
    "inappropiate": "inappropriate",
    "inapropriate": "inappropriate",
    "inatead": "instead",
    "inaugrate": "inaugurate",
    "inaugure": "inaugurate",
    "inaugures": "inaugurates",
    "inbalance": "imbalance",
    "inbalanced": "imbalanced",
    "inbetween": "between",
    "inboxx": "inbox",
    "incarcirated": "incarcerated",
    "incease": "increase",
    "inceases": "increases",
    "inchs": "inches",
    "incidential": "incidental",
    "incidentially": "incidentally",
    "incidently": "incidentally",
    "incinuate": "insinuate",
    "inclreased": "increased",
    "includ": "include",
    "includeing": "including",
    "includng": "including",
    "incompatabilities": "incompatibilities",
    "incompatability": "incompatibility",
    "incompatable": "incompatible",
    "incompatablities": "incompatibilities",
    "incompatablity": "incompatibility",
    "incompatiblities": "incompatibilities",
    "incompatiblity": "incompatibility",
    "incompetance": "incompetence",
    "incompetant": "incompetent",
    "incomptable": "incompatible",
    "incomptetent": "incompetent",
    "inconsistancy": "inconsistency",
    "inconsistant": "inconsistent",
    "incoroporated": "incorporated",
    "incorperate": "incorporate",
    "incorperation": "incorporation",
    "incorportaed": "incorporated",
    "incorprates": "incorporates",
    "incorruptable": "incorruptible",
    "incramentally": "incrementally",
    "increadible": "incredible",
    "increaes": "increases",
    "incredable": "incredible",
    "increse": "increase",
    "inctroduce": "introduce",
    "inctroduced": "introduced",
    "incuding": "including",
    "incumbancy": "incumbency",
    "incumbant": "incumbent",
    "incunabla": "incunabula",
    "incvite": "invite",
    "indefinately": "indefinitely",
    "indefineable": "undefinable",
    "indefinitly": "indefinitely",
    "indempotent": "idempotent",
    "indentical": "identical",
    "indentification": "identification",
    "indentifying": "identifying",
    "indepedantly": "independently",
    "indepedence": "independence",
    "indepedent": "independent",
    "indepence": "independence",
    "independance": "independence",
    "independant": "independent",
    "independantly": "independently",
    "independece": "independence",
    "independendet": "independent",
    "independient": "independent",
    "indepent": "independent",
    "indepently": "independently",
    "indespensable": "indispensable",
    "indespensible": "indispensable",
    "indictement": "indictment",
    "indigineous": "indigenous",
    "indipendence": "independence",
    "indipendent": "independent",
    "indipendently": "independently",
    "indispensible": "indispensable",
    "indisputible": "indisputable",
    "indisputibly": "indisputably",
    "indite": "indict",
    "individial": "individual",
    "individualy": "individually",
    "indoensia": "indonesia",
    "indonasia": "indonesia",
    "indoneasia": "indonesia",
    "indoneisa": "indonesia",
    "indoneshia": "indonesia",
    "indonesio": "indonesia",
    "indonessia": "indonesia",
    "indonisia": "indonesia",
    "indosnesia": "indonesia",
    "indpendent": "independent",
    "indpendently": "independently",
    "indstry": "industry",
    "indulgue": "indulge",
    "indutrial": "industrial",
    "indviduals": "individuals",
    "inefficienty": "inefficiently",
    "inernet": "internet",
    "inevatible": "inevitable",
    "inevitible": "inevitable",
    "inevititably": "inevitably",
    "infalability": "infallibility",
    "infallable": "infallible",
    "infanty": "infantry",
    "infectede": "infected",
    "infecton": "infection",
    "infectuous": "infectious",
    "infered": "inferred",
    "infilitrate": "infiltrate",
    "infilitrated": "infiltrated",
    "infilitration": "infiltration",
    "infinit": "infinite",
    "infitation": "invitation",
    "inflamation": "inflammation",
    "inflamatory": "inflammatory",
    "inflitrate": "infiltrate",
    "influencial": "influential",
    "influental": "influential",
    "influented": "influenced",
    "infomation": "information",
    "inforamtion": "information",
    "informaiton": "information",
    "informationi": "information",
    "informtion": "information",
    "infr": "info",
    "infrantryman": "infantryman",
    "infrigement": "infringement",
    "infringment": "infringement",
    "infrmed": "informed",
    "infromation": "information",
    "ingenius": "ingenious",
    "ingrediants": "ingredients",
    "ingreediants": "ingredients",
    "inhabitans": "inhabitants",
    "inherantly": "inherently",
    "inheret": "inherit",
    "inheritence": "inheritance",
    "inherrent": "inherent",
    "inicial": "initial",
    "iniciate": "initiate",
    "inisights": "insights",
    "inital": "initial",
    "initally": "initially",
    "initate": "initiate",
    "initation": "initiation",
    "initation": "invitation",
    "initative": "initiative",
    "initator": "initiator",
    "initiaitive": "initiative",
    "initialy": "initially",
    "initiatve": "initiative",
    "initiially": "initially",
    "inititive": "initiative",
    "inivitation": "invitation",
    "inivite": "invite",
    "inivites": "invites",
    "inivtes": "invites",
    "inj": "in",
    "injectiong": "injection",
    "injuiry": "injury",
    "injurys": "injuries",
    "inlcude": "include",
    "inlcuded": "included",
    "inlcuding": "including",
    "inlude": "include",
    "inmigrant": "immigrant",
    "inmigrants": "immigrants",
    "inmigrate": "immigrate",
    "innappropriate": "inappropriate",
    "innaugurate": "inaugurate",
    "innauguration": "inauguration",
    "innfested": "infested",
    "innites": "invites",
    "innoculated": "inoculated",
    "innoculations": "inoculations",
    "innundate": "inundate",
    "innundation": "inundation",
    "innvite": "invite",
    "inocence": "innocence",
    "inocuations": "inoculations",
    "inofficial": "unofficial",
    "inot": "into",
    "inovation": "innovation",
    "inovative": "innovative",
    "inow": "now",
    "inpact": "impact",
    "inpeach": "impeach",
    "inpending": "impending",
    "inpenetrable": "impenetrable",
    "inpiration": "inspiration",
    "inpolite": "impolite",
    "inportant": "important",
    "inpose": "impose",
    "inprisonment": "imprisonment",
    "inprove": "improve",
    "inproving": "improving",
    "inpsired": "inspired",
    "inquierer": "inquirer",
    "inrerested": "interested",
    "inroduce": "introduce",
    "insatlled": "installed",
    "insde": "inside",
    "insectiverous": "insectivorous",
    "insensative": "insensitive",
    "inseperable": "inseparable",
    "insident": "incident",
    "insistance": "insistence",
    "insitution": "institution",
    "insitutions": "institutions",
    "insoluable": "insoluble",
    "insperation": "inspiration",
    "instad": "instead",
    "instade": "instead",
    "instala": "install",
    "instalation": "installation",
    "instatance": "instance",
    "insted": "instead",
    "instend": "instead",
    "institue": "institute",
    "instslled": "installed",
    "instuction": "instruction",
    "instuments": "instruments",
    "instutionalized": "institutionalized",
    "instutions": "intuitions",
    "insufficent": "insufficient",
    "insufficently": "insufficiently",
    "insurence": "insurance",
    "intalled": "installed",
    "intallment": "installment",
    "intallments": "installments",
    "intead": "instead",
    "intefere": "interfere",
    "integreate": "integrate",
    "intelectual": "intellectual",
    "inteligence": "intelligence",
    "inteligent": "intelligent",
    "intenational": "international",
    "intenet": "internet",
    "intented": "intended",
    "intepretation": "interpretation",
    "intepretator": "interpretor",
    "interational": "international",
    "interchangable": "interchangeable",
    "interchangably": "interchangeably",
    "intercontinential": "intercontinental",
    "intercontinetal": "intercontinental",
    "intereactive": "interactive",
    "interegnum": "interregnum",
    "interelated": "interrelated",
    "interenet": "internet",
    "interent": "internet",
    "interersted": "interested",
    "interesed": "interested",
    "intereseted": "interested",
    "interesing": "interesting",
    "interessted": "interested",
    "interestng": "interesting",
    "interestong": "interesting",
    "intereting": "interesting",
    "interfear": "interfere",
    "interfearance": "interference",
    "interfearing": "interfering",
    "interferance": "interference",
    "interfereing": "interfering",
    "intergral": "integral",
    "intergrate": "integrate",
    "intergrated": "integrated",
    "intergrates": "integrates",
    "intergration": "integration",
    "interm": "interim",
    "intermidiary": "intermediary",
    "intermidiate": "intermediate",
    "intermitant": "intermittent",
    "intermitent": "intermittent",
    "intermittant": "intermittent",
    "internaly": "internally",
    "internation": "international",
    "internationaly": "internationally",
    "internationl": "international",
    "internetz": "internet",
    "internrt": "internet",
    "internt": "internet",
    "interogation": "interrogation",
    "interoir": "interior",
    "interor": "interior",
    "interpet": "interpret",
    "interpetation": "interpretation",
    "interpretion": "interpretation",
    "interr": "intern",
    "interract": "interact",
    "interregum": "interregnum",
    "interrested": "interested",
    "interrim": "interim",
    "interrior": "interior",
    "interrsted": "interested",
    "interrugum": "interregnum",
    "interseted": "interested",
    "interseting": "interesting",
    "interst": "interest",
    "intersted": "interested",
    "intersting": "interesting",
    "intertaining": "entertaining",
    "interupt": "interrupt",
    "interupted": "interrupted",
    "interuption": "interruption",
    "intervines": "intervenes",
    "intesity": "intensity",
    "intevene": "intervene",
    "intial": "initial",
    "intially": "initially",
    "intiative": "initiative",
    "intigrate": "integrate",
    "intital": "initial",
    "intitation": "invitation",
    "intite": "invite",
    "intitial": "initial",
    "intoduce": "introduce",
    "intorduce": "introduce",
    "intot he": "into the",
    "intrduced": "introduced",
    "intregal": "integral",
    "intregrate": "integrate",
    "intrernet": "internet",
    "intrest": "interest",
    "intrested": "interested",
    "intrical": "integral",
    "intrim": "interim",
    "introdued": "introduced",
    "introduse": "introduce",
    "introudces": "introduces",
    "intruction": "instruction",
    "intruduced": "introduced",
    "intruducing": "introducing",
    "intrument": "instrument",
    "intrumental": "instrumental",
    "intruments": "instruments",
    "intrusted": "entrusted",
    "inturrupt": "interrupt",
    "intution": "intuition",
    "intutive": "intuitive",
    "intutively": "intuitively",
    "intvite": "invite",
    "inudstry": "industry",
    "invantion": "invention",
    "invarience": "invariance",
    "invarient": "invariant",
    "invatation": "invitation",
    "invatations": "invitations",
    "invate": "invite",
    "invated": "invited",
    "invates": "invites",
    "inveite": "invite",
    "inventer": "inventor",
    "inversly": "inversely",
    "invertabrate": "invertebrate",
    "invertibrate": "invertebrate",
    "invertibrates": "invertebrates",
    "invertion": "inversion",
    "invester": "investor",
    "investingate": "investigate",
    "invetation": "invitation",
    "invete": "invite",
    "inveted": "invited",
    "invetion": "invention",
    "inviatation": "invitation",
    "inviate": "invite",
    "inviation": "invitation",
    "inviations": "invitations",
    "invice": "invite",
    "invide": "invite",
    "invie": "invite",
    "invied": "invited",
    "invies": "invites",
    "inviet": "invite",
    "inviite": "invite",
    "invintation": "invitation",
    "invire": "invite",
    "invires": "invites",
    "invitacion": "invitation",
    "invitaction": "invitation",
    "invitaion": "invitation",
    "invitaition": "invitation",
    "invitaiton": "invitation",
    "invitanion": "invitation",
    "invitantion": "invitation",
    "invitarion": "invitation",
    "invitatiion": "invitation",
    "invitatioin": "invitation",
    "invitationb": "invitation",
    "invitatioon": "invitation",
    "invitaton": "invitation",
    "invitattion": "invitation",
    "invitei": "invite",
    "invitem": "invite",
    "invitez": "invite",
    "invitiation": "invitation",
    "invities": "invites",
    "invitr": "invite",
    "invits": "invites",
    "invitte": "invite",
    "invivte": "invite",
    "invlte": "invite",
    "invo": "into",
    "invole": "involve",
    "involement": "involvement",
    "involment": "involvement",
    "involvedm": "involved",
    "involvment": "involvement",
    "invote": "invite",
    "invovle": "involve",
    "invtation": "invitation",
    "invte": "invite",
    "invtie": "invite",
    "invutation": "invitation",
    "invutes": "invites",
    "invvite": "invite",
    "iny": "in",
    "ionce": "once",
    "iont": "dont",
    "iost": "lost",
    "iother": "other",
    "iout": "out",
    "iove": "love",
    "ioving": "loving",
    "ipcon": "icon",
    "ipdate": "update",
    "ipdod": "ipod",
    "ipgrade": "upgrade",
    "iphine": "iphone",
    "iphne": "iphone",
    "iphobe": "iphone",
    "iphod": "ipod",
    "iphode": "iphone",
    "iphoe": "iphone",
    "iphoen": "iphone",
    "iphoned": "iphone",
    "iphonei": "iphone",
    "iphonel": "iphone",
    "iphonen": "iphone",
    "iphoner": "iphone",
    "iphonex": "iphone",
    "iphoney": "iphone",
    "iphonez": "iphone",
    "iphonr": "iphone",
    "iphons": "iphone",
    "iphpne": "iphone",
    "ipjone": "iphone",
    "ipnone": "iphone",
    "ipnvited": "invited",
    "ipode": "ipod",
    "ipodt": "ipod",
    "ipohne": "iphone",
    "ipohone": "iphone",
    "ipone": "iphone",
    "iportant": "important",
    "ipot": "ipod",
    "ipoud": "ipod",
    "ippd": "ipod",
    "iproblems": "problems",
    "iput": "put",
    "ireal": "real",
    "ireally": "really",
    "irelevent": "irrelevant",
    "iresistable": "irresistible",
    "iresistably": "irresistibly",
    "iresistible": "irresistible",
    "iresistibly": "irresistibly",
    "irestore": "restore",
    "iritable": "irritable",
    "iritate": "irritate",
    "iritated": "irritated",
    "ironicaly": "ironically",
    "ironicly": "ironically",
    "irregardless": "regardless",
    "irrelavent": "irrelevant",
    "irrelevent": "irrelevant",
    "irreplacable": "irreplaceable",
    "irresistable": "irresistible",
    "irresistably": "irresistibly",
    "irrevelant": "irrelevant",
    "irreverant": "irreverent",
    "is stil": "is still",
    "isent": "sent",
    "ishould": "should",
    "isht": "isnt",
    "isnt": "isn't",
    "isntead": "instead",
    "isoftware": "software",
    "issueing": "issuing",
    "issuses": "issues",
    "istalled": "installed",
    "istening": "listening",
    "istore": "store",
    "isz": "is",
    "itablet": "tablet",
    "italk": "talk",
    "itemsn": "items",
    "itenerant": "itinerant",
    "iteself": "itself",
    "ithought": "thought",
    "itinery": "itinerary",
    "itiuch": "itouch",
    "itls": "its",
    "itnernet": "internet",
    "itnroduced": "introduced",
    "itrying": "trying",
    "itslef": "itself",
    "itsself": "itself",
    "itts": "its",
    "itw": "it",
    "itweet": "tweet",
    "itwitter": "twitter",
    "iunior": "junior",
    "iupdated": "updated",
    "iuse": "use",
    "ivitation": "invitation",
    "ivitations": "invitations",
    "ivite": "invite",
    "ivited": "invited",
    "ivnite": "invite",
    "iwanna": "wanna",
    "iwanted": "wanted",
    "iwas": "was",
    "iweb": "web",
    "iwill": "will",
    "iwit": "wit",
    "iwll": "will",
    "iwth": "with",
    "iy": "it",
    "iys": "is",
    "izpod": "ipod",
    "izza": "pizza",
    "jaab": "jab",
    "jabb": "jab",
    "jackon": "jackson",
    "jaibreak": "jailbreak",
    "jaibreaking": "jailbreaking",
    "jaibroken": "jailbroken",
    "jailbareak": "jailbreak",
    "jailbeak": "jailbreak",
    "jailboken": "jailbroken",
    "jailborken": "jailbroken",
    "jailbraek": "jailbreak",
    "jailbrak": "jailbreak",
    "jailbreack": "jailbreak",
    "jailbreaj": "jailbreak",
    "jailbreakd": "jailbreak",
    "jailbrean": "jailbreak",
    "jailbrek": "jailbreak",
    "jailbreking": "jailbreaking",
    "jailbrken": "jailbroken",
    "jailbroked": "jailbroken",
    "jailbrokn": "jailbroken",
    "jailbteak": "jailbreak",
    "jaillbreak": "jailbreak",
    "jaillbroken": "jailbroken",
    "jailreak": "jailbreak",
    "jakrta": "jakarta",
    "jalbreak": "jailbreak",
    "jamesz": "james",
    "jaoan": "japan",
    "japenese": "japanese",
    "jaques": "jacques",
    "jast": "just",
    "jave": "have",
    "jave": "wave",
    "javent": "havent",
    "javing": "having",
    "jbb": "job",
    "jbroke": "broke",
    "jcatch": "catch",
    "jdo": "do",
    "jeapardy": "jeopardy",
    "jelous": "jealous",
    "jeneiro": "janeiro",
    "jersy": "jersey",
    "jewler": "jeweler",
    "jewllery": "jewellery",
    "jgo": "go",
    "jhas": "has",
    "jhate": "hate",
    "jialbroken": "jailbroken",
    "jiust": "just",
    "jjust": "just",
    "jlove": "love",
    "jobb": "job",
    "joinded": "joined",
    "joing": "join",
    "joingng": "joining",
    "joinn": "join",
    "jont": "jon",
    "jope": "hope",
    "jord": "lord",
    "jorunal": "journal",
    "jouin": "join",
    "jouney": "journey",
    "journalistss": "journalists",
    "journied": "journeyed",
    "journies": "journeys",
    "jschool": "school",
    "jstu": "just",
    "jsut": "just",
    "juast": "just",
    "juat": "just",
    "jucie": "juice",
    "juction": "junction",
    "judgd": "judged",
    "judical": "judicial",
    "judisuary": "judiciary",
    "judt": "just",
    "juducial": "judicial",
    "juest": "just",
    "juica": "juice",
    "jujst": "just",
    "junoir": "junior",
    "junt": "just",
    "juntion": "junction",
    "jurisdication": "jurisdiction",
    "juristiction": "jurisdiction",
    "juristictions": "jurisdictions",
    "jusd": "just",
    "jusdt": "just",
    "jusf": "just",
    "jusr": "just",
    "jusrt": "just",
    "juss": "just",
    "jusst": "just",
    "justg": "just",
    "justt": "just",
    "justv": "just",
    "jusut": "just",
    "jusy": "just",
    "jusz": "just",
    "juszt": "just",
    "juust": "just",
    "juvinile": "juvenile",
    "jux": "jus",
    "juzt": "just",
    "jwhy": "why",
    "kalled": "called",
    "kares": "cares",
    "kark": "kart",
    "kases": "cases",
    "kause": "cause",
    "kayne": "kanye",
    "kbnow": "know",
    "kdi": "kid",
    "keeap": "keep",
    "keeep": "keep",
    "keeeps": "keeps",
    "keepm": "keep",
    "keept": "keep",
    "kenw": "knew",
    "kep": "keep",
    "kexp": "keep",
    "keybaord": "keyboard",
    "keybord": "keyboard",
    "keyowrds": "keywords",
    "keywors": "keyword",
    "keywrd": "keyword",
    "keywrod": "keyword",
    "kfox": "fox",
    "kicced": "kicked",
    "kichen": "kitchen",
    "kickd": "kicked",
    "kicken": "kickin",
    "kickn": "kickin",
    "kicthen": "kitchen",
    "kidos": "kids",
    "kiids": "kids",
    "kiinds": "kinds",
    "kik": "kit",
    "kiked": "kicked",
    "killig": "killing",
    "killinq": "killing",
    "killled": "killed",
    "killling": "killing",
    "killng": "killing",
    "killogram": "kilogram",
    "killometer": "kilometer",
    "killometre": "kilometre",
    "killr": "killer",
    "kilss": "kills",
    "kims": "kids",
    "kindaa": "kinda",
    "kindda": "kinda",
    "kindel": "kindle",
    "kindergarden": "kindergarten",
    "kindz": "kinds",
    "kinlde": "kindle",
    "kinle": "kindle",
    "kinna": "kinda",
    "kinoscope": "kinescope",
    "kinow": "know",
    "kirchen": "kitchen",
    "kisss": "kiss",
    "kjust": "just",
    "kkep": "keep",
    "kknew": "knew",
    "klenex": "kleenex",
    "kmow": "know",
    "kmz": "kml",
    "knbow": "know",
    "knd": "kind",
    "kne": "kno",
    "knida": "kinda",
    "knifes": "knives",
    "knit-pick": "nitpick",
    "knitpick": "nitpick",
    "knive": "knife",
    "kniw": "know",
    "knkw": "know",
    "knmow": "know",
    "knmw": "know",
    "knnow": "know",
    "knnw": "know",
    "knoe": "know",
    "knoh": "kno",
    "knoo": "know",
    "knoow": "know",
    "knos": "know",
    "knoticed": "noticed",
    "knowi": "know",
    "knowldge": "knowledge",
    "knowlege": "knowledge",
    "knowlegeable": "knowledgeable",
    "knoww": "know",
    "knu": "kno",
    "knw": "know",
    "knwo": "know",
    "knwos": "knows",
    "knws": "knows",
    "knww": "know",
    "komes": "comes",
    "konw": "know",
    "konws": "knows",
    "kooked": "hooked",
    "kooking": "looking",
    "kooler": "cooler",
    "kould": "would",
    "kow": "know",
    "kphone": "iphone",
    "krib": "crib",
    "kso": "so",
    "ksrt": "kart",
    "kust": "just",
    "kwith": "with",
    "kwno": "know",
    "labratory": "laboratory",
    "labron": "lebron",
    "labtop": "laptop",
    "lackberry": "blackberry",
    "ladden": "laden",
    "lagre": "large",
    "laguage": "language",
    "laguages": "languages",
    "landscapping": "landscaping",
    "languise": "languish",
    "languistic": "linguistic",
    "lanscape": "landscape",
    "lanugage": "language",
    "laptob": "laptop",
    "larg": "large",
    "largley": "largely",
    "largly": "largely",
    "largst": "largest",
    "larnyx": "larynx",
    "larrry": "larry",
    "lastr": "last",
    "lasu": "last",
    "lasy": "last",
    "laszy": "lazy",
    "latancy": "latency",
    "latant": "latent",
    "lateley": "lately",
    "lateraly": "laterally",
    "latern": "lantern",
    "latitiude": "latitude",
    "latitute": "latitude",
    "latley": "lately",
    "lattitude": "latitude",
    "lattrell": "littrell",
    "lauch": "launch",
    "lauched": "launched",
    "lauches": "launches",
    "lauching": "launching",
    "laucnhes": "launches",
    "lauing": "laying",
    "launcd": "launch",
    "launchd": "launched",
    "launchn": "launch",
    "launchs": "launches",
    "launhed": "launched",
    "lavae": "larvae",
    "layed low": "lay low",
    "layed": "laid",
    "layiing": "laying",
    "lazt": "lazy",
    "lazyness": "laziness",
    "lazzy": "lazy",
    "lcuk": "luck",
    "leaave": "leave",
    "leabron": "lebron",
    "leaened": "learned",
    "leage": "league",
    "leakd": "leaked",
    "lealous": "jealous",
    "leared": "learned",
    "learing": "learning",
    "learnnig": "learning",
    "leathal": "lethal",
    "leauge": "league",
    "leavez": "leaves",
    "leavng": "leaving",
    "lebraon": "lebron",
    "ledgend": "legend",
    "ledgendary": "legendary",
    "ledgislate": "legislate",
    "ledgislation": "legislation",
    "ledgislative": "legislative",
    "ledgislator": "legislator",
    "lefted": "left",
    "leftr": "left",
    "leftt": "left",
    "legaly": "legally",
    "legimate": "legitimate",
    "legistlate": "legislate",
    "legistlation": "legislation",
    "legistlative": "legislative",
    "legistlator": "legislator",
    "legitamate": "legitimate",
    "legitmate": "legitimate",
    "legnth": "length",
    "legron": "lebron",
    "leibnitz": "leibniz",
    "lenght": "length",
    "lenghten": "lengthen",
    "lenghty": "lengthy",
    "lenth": "length",
    "lepoard": "leopard",
    "leran": "learn",
    "lerans": "learns",
    "lern": "learn",
    "lesft": "left",
    "leting": "letting",
    "leutenant": "lieutenant",
    "levetate": "levitate",
    "levetated": "levitated",
    "levetates": "levitates",
    "levetating": "levitating",
    "levle": "level",
    "lexion": "lexicon",
    "lgive": "give",
    "liasion": "liaison",
    "liason": "liaison",
    "liasons": "liaisons",
    "libarary": "library",
    "libary": "library",
    "libell": "libel",
    "libguistic": "linguistic",
    "libguistics": "linguistics",
    "libitarianisn": "libertarianism",
    "libraray": "library",
    "libray": "library",
    "lieing": "lying",
    "liek": "like",
    "liekd": "liked",
    "liesure": "leisure",
    "lieuenant": "lieutenant",
    "lieutentant": "lieutenant",
    "lieved": "lived",
    "liftime": "lifetime",
    "lightyear": "light year",
    "lightyears": "light years",
    "liike": "like",
    "liitle": "little",
    "liittle": "little",
    "lije": "like",
    "lik": "link",
    "lika": "like",
    "likd": "like",
    "likedly": "likely",
    "likei": "like",
    "likelyhood": "likelihood",
    "likke": "like",
    "likley": "likely",
    "liks": "like",
    "likw": "like",
    "lile": "like",
    "lillies": "lilies",
    "lilttle": "little",
    "limbugh": "limbaugh",
    "limitied": "limited",
    "limted": "limited",
    "lingustic": "linguistic",
    "linmk": "link",
    "linnaena": "linnaean",
    "liove": "love",
    "lippizaner": "lipizzaner",
    "liquify": "liquefy",
    "liscence": "licence",
    "liscense": "license",
    "lisening": "listening",
    "lisiten": "listen",
    "lisitening": "listening",
    "lisiting": "listing",
    "listeing": "listening",
    "listeni": "listen",
    "listenig": "listening",
    "listenign": "listening",
    "listeniing": "listening",
    "listeninf": "listening",
    "listenting": "listening",
    "listerning": "listening",
    "listien": "listen",
    "listin": "listen",
    "listining": "listening",
    "listneing": "listening",
    "listners": "listeners",
    "listning": "listening",
    "lisztening": "listening",
    "litature": "literature",
    "liten": "listen",
    "literaly": "literally",
    "literell": "littrell",
    "literture": "literature",
    "litle": "little",
    "litlle": "little",
    "littany": "litany",
    "litte": "little",
    "littel": "little",
    "litteral": "literal",
    "litterally": "literally",
    "litterature": "literature",
    "litterell": "littrell",
    "litterll": "littrell",
    "littke": "little",
    "littley": "little",
    "littlw": "little",
    "litttle": "little",
    "liturature": "literature",
    "liuke": "like",
    "livley": "lively",
    "livv": "live",
    "ljust": "just",
    "lke": "like",
    "lkike": "like",
    "llatest": "latest",
    "llet": "let",
    "llike": "like",
    "llink": "link",
    "llisten": "listen",
    "llittrell": "littrell",
    "llke": "like",
    "llnk": "link",
    "llok": "look",
    "llol": "lol",
    "llost": "lost",
    "lmits": "limits",
    "lmost": "almost",
    "lnow": "know",
    "loacl": "local",
    "loacted": "located",
    "localy": "locally",
    "locamotive": "locomotive",
    "lockeroom": "locker room",
    "locl": "local",
    "loction": "location",
    "locve": "love",
    "loev": "love",
    "lofl": "lol",
    "logg": "logo",
    "logicaly": "logically",
    "loiok": "look",
    "loking": "looking",
    "lokked": "looked",
    "lokking": "looking",
    "loks": "looks",
    "lolm": "lol",
    "lonelyness": "loneliness",
    "longg": "long",
    "longitudonal": "longitudinal",
    "lonley": "lonely",
    "lonleyness": "loneliness",
    "lonliness": "loneliness",
    "lonng": "long",
    "lonq": "long",
    "loocking": "looking",
    "loog": "look",
    "loogle": "google",
    "looken": "lookin",
    "lookig": "looking",
    "lookign": "looking",
    "lookiing": "looking",
    "lookind": "looking",
    "lookingg": "looking",
    "lookingn": "looking",
    "lookinq": "looking",
    "lookk": "look",
    "lookn": "looks",
    "lookng": "looking",
    "lookz": "looks",
    "loook": "look",
    "loooking": "looking",
    "loooks": "looks",
    "looong": "loooong",
    "looooong": "loooong",
    "loosing": "losing",
    "loosly": "loosely",
    "loove": "love",
    "looved": "loved",
    "lopve": "love",
    "loseing": "losing",
    "losse": "lose",
    "losser": "loser",
    "losty": "lost",
    "lotes": "lotus",
    "lothain": "lothian",
    "lotharingen": "lothringen",
    "lottle": "little",
    "lounch": "launch",
    "louve": "love",
    "lovem": "love",
    "loven": "love",
    "lovez": "love",
    "lovinh": "loving",
    "lovley": "lovely",
    "lovly": "lovely",
    "lovve": "love",
    "lovvly": "lovely",
    "lovw": "love",
    "loyt": "lot",
    "lozt": "lost",
    "lplay": "play",
    "lsat": "last",
    "lsiten": "listen",
    "lsitening": "listening",
    "lsten": "listen",
    "lthe": "the",
    "lttle": "little",
    "luagh": "laugh",
    "luanch": "launch",
    "luanched": "launched",
    "luch": "lunch",
    "luckilly": "luckily",
    "luckly": "luckily",
    "luckyf": "lucky",
    "luekemia": "leukemia",
    "lukemia": "leukemia",
    "lukid": "likud",
    "lunchs": "lunches",
    "luttrell": "littrell",
    "luve": "love",
    "luved": "loved",
    "luvv": "luv",
    "luxary": "luxury",
    "lve": "love",
    "lveo": "love",
    "lvoe": "love",
    "lytrell": "litrell",
    "maange": "manage",
    "maaps": "maps",
    "maby": "may",
    "mackeral": "mackerel",
    "madee": "made",
    "magasine": "magazine",
    "magent": "magnet",
    "magentic": "magnetic",
    "magestic": "majestic",
    "magicaly": "magically",
    "magincian": "magician",
    "maginitude": "magnitude",
    "magintude": "magnitude",
    "magisine": "magazine",
    "magitude": "magnitude",
    "magizine": "magazine",
    "magnant": "magnate",
    "magnificient": "magnificent",
    "magnitdue": "magnitude",
    "magnitiude": "magnitude",
    "magnitue": "magnitude",
    "magnitutde": "magnitude",
    "magnitute": "magnitude",
    "magolia": "magnolia",
    "maibe": "maybe",
    "mailny": "mainly",
    "mainfest": "manifest",
    "mainia": "mania",
    "mainley": "mainly",
    "maintainance": "maintenance",
    "maintainence": "maintenance",
    "maintaing": "maintaining",
    "maintance": "maintenance",
    "maintanence": "maintenance",
    "maintence": "maintenance",
    "maintenence": "maintenance",
    "maintinaing": "maintaining",
    "maintinance": "maintenance",
    "maintioned": "mentioned",
    "maje": "make",
    "majiscule": "majuscule",
    "majoirty": "majority",
    "majoroty": "majority",
    "makea": "make",
    "makews": "makes",
    "makez": "makes",
    "makiin": "makin",
    "makingg": "making",
    "makinn": "making",
    "makinq": "making",
    "makke": "make",
    "makkng": "making",
    "makn": "make",
    "makn": "makin",
    "makng": "making",
    "makr": "make",
    "makse": "makes",
    "maltesian": "Maltese",
    "mamal": "mammal",
    "mamalian": "mammalian",
    "manaaged": "managed",
    "managament": "management",
    "manageral": "managerial",
    "managment": "management",
    "mandantory": "mandatory",
    "mandetory": "mandatory",
    "manditory": "mandatory",
    "mandotory": "mandatory",
    "maneouvre": "manoeuvre",
    "maneouvred": "manoeuvred",
    "maneouvres": "manoeuvres",
    "maneouvring": "manoeuvring",
    "maneover": "maneuver",
    "maneovre": "manoeuvre",
    "mangement": "management",
    "mangerial": "managerial",
    "manifestion": "manifestation",
    "manisfestations": "manifestations",
    "manoeuverability": "maneuverability",
    "manps": "maps",
    "mantained": "maintained",
    "manua": "mania",
    "manufacturedd": "manufactured",
    "manufature": "manufacture",
    "manufatured": "manufactured",
    "manufaturing": "manufacturing",
    "manuver": "maneuver",
    "manyy": "many",
    "mapas": "maps",
    "mapd": "maps",
    "maped": "mapped",
    "mapps": "maps",
    "marchs": "marches",
    "marekting": "marketing",
    "margain": "margin",
    "mariage": "marriage",
    "maried": "married",
    "mariok": "mario",
    "marioo": "mario",
    "mariyln": "marilyn",
    "marjority": "majority",
    "markes": "marks",
    "marketting": "marketing",
    "marliyn": "marilyn",
    "marmelade": "marmalade",
    "marolyn": "marilyn",
    "marrage": "marriage",
    "marraige": "marriage",
    "marrige": "marriage",
    "marrtyred": "martyred",
    "marryied": "married",
    "marylyn": "marilyn",
    "masive": "massive",
    "masonery": "masonry",
    "masrilyn": "marilyn",
    "massmedia": "mass media",
    "masterbation": "masturbation",
    "mataphysical": "metaphysical",
    "matchs": "matches",
    "materalists": "materialist",
    "mathamatics": "mathematics",
    "mathematican": "mathematician",
    "mathematicas": "mathematics",
    "matheticians": "mathematicians",
    "mathmatically": "mathematically",
    "mathmatician": "mathematician",
    "mathmaticians": "mathematicians",
    "mathmatics": "mathematics",
    "maube": "maybe",
    "maximium": "maximum",
    "maxx": "max",
    "mayb": "may",
    "mayy": "may",
    "mbox": "box",
    "mcbook": "macbook",
    "mccarthyst": "mccarthyist",
    "mchanics": "mechanics",
    "mcuh": "much",
    "mddle": "middle",
    "meaningfull": "meaningful",
    "meaninng": "meaning",
    "meann": "meant",
    "meannt": "meant",
    "meanss": "means",
    "meantion": "mention",
    "mearly": "merely",
    "mecanical": "mechanical",
    "mechandise": "merchandise",
    "mechanisim": "mechanism",
    "mechant": "merchant",
    "medacine": "medicine",
    "medeival": "medieval",
    "medevial": "medieval",
    "mediciney": "mediciny",
    "medicore": "mediocre",
    "medievel": "medieval",
    "mediterainnean": "mediterranean",
    "meeet": "meet",
    "meens": "means",
    "meerkrat": "meerkat",
    "meetp": "meets",
    "melieux": "milieux",
    "membranaphone": "membranophone",
    "memeber": "member",
    "memmory": "memory",
    "menally": "mentally",
    "mentaly": "mentally",
    "mentiones": "mentions",
    "mentionned": "mentioned",
    "meny": "many",
    "mercentile": "mercantile",
    "mercernary": "mercenary",
    "merchent": "merchant",
    "mesage": "message",
    "mesages": "messages",
    "mesaging": "messaging",
    "messagig": "messaging",
    "messahing": "messaging",
    "messaing": "messaging",
    "messanger": "messenger",
    "messanging": "messaging",
    "messasging": "messaging",
    "messd": "messed",
    "messeaging": "messaging",
    "messege": "message",
    "messeges": "messages",
    "messeging": "messaging",
    "messenging": "messaging",
    "messengr": "messenger",
    "messgaing": "messaging",
    "messge": "message",
    "messges": "messages",
    "messging": "messaging",
    "messig": "messing",
    "messiging": "messaging",
    "messnger": "messenger",
    "messsage": "message",
    "messsaging": "messaging",
    "mesting": "meeting",
    "metalic": "metallic",
    "metalurgic": "metallurgic",
    "metalurgical": "metallurgical",
    "metalurgy": "metallurgy",
    "metamorphysis": "metamorphosis",
    "metaphoricial": "metaphorical",
    "meterologist": "meteorologist",
    "meterology": "meteorology",
    "methaphor": "metaphor",
    "methaphors": "metaphors",
    "metion": "mention",
    "metorology": "meteorology",
    "metriod": "metroid",
    "metropolian": "metropolitan",
    "metter": "matter",
    "mewans": "means",
    "mexcan": "mexican",
    "mexicab": "mexican",
    "mfe": "me",
    "mght": "might",
    "mgiht": "might",
    "micahel": "michael",
    "micoscopy": "microscopy",
    "micosoft": "microsoft",
    "midddle": "middle",
    "midle": "middle",
    "midwifes": "midwives",
    "migfht": "might",
    "mighht": "might",
    "mightt": "might",
    "migt": "might",
    "mihgt": "might",
    "miight": "might",
    "miiss": "miss",
    "mileau": "milieu",
    "milennia": "millennia",
    "milennium": "millennium",
    "mileu": "milieu",
    "miliary": "military",
    "miliey": "miley",
    "miligram": "milligram",
    "milion": "million",
    "miliraty": "military",
    "militairy": "military",
    "millenia": "millennia",
    "millenial": "millennial",
    "millenialism": "millennialism",
    "millenium": "millennium",
    "millepede": "millipede",
    "milliion": "million",
    "millionare": "millionaire",
    "millioniare": "millionaire",
    "millionn": "million",
    "millitant": "militant",
    "millitary": "military",
    "milllion": "million",
    "millon": "million",
    "miltary": "military",
    "miminal": "minimal",
    "miminum": "minimum",
    "minature": "miniature",
    "minerial": "mineral",
    "minerologist": "mineralogist",
    "minerology": "mineralogy",
    "minght": "might",
    "minimaly": "minimally",
    "minimium": "minimum",
    "ministery": "ministry",
    "ministy": "ministry",
    "miniture": "miniature",
    "minnimum": "minimum",
    "minsitry": "ministry",
    "minstries": "ministries",
    "minstry": "ministry",
    "mintendo": "nintendo",
    "mintue": "minute",
    "mintues": "minutes",
    "minuite": "minute",
    "minumum": "minimum",
    "minvites": "invites",
    "mioght": "might",
    "miphone": "iphone",
    "miqht": "might",
    "mircosoft": "microsoft",
    "miriad": "myriad",
    "miricle": "miracle",
    "mirrorred": "mirrored",
    "miscelaneous": "miscellaneous",
    "miscellanious": "miscellaneous",
    "miscellanous": "miscellaneous",
    "mischeivous": "mischievous",
    "mischevious": "mischievous",
    "mischievious": "mischievous",
    "misdameanor": "misdemeanor",
    "misdameanors": "misdemeanors",
    "misdemenor": "misdemeanor",
    "misdemenors": "misdemeanors",
    "misfourtunes": "misfortunes",
    "misile": "missile",
    "mising": "missing",
    "mispell": "misspell",
    "mispelled": "misspelled",
    "mispelling": "misspelling",
    "missen": "mizzen",
    "missle": "missile",
    "missn": "miss",
    "missonary": "missionary",
    "misss": "miss",
    "misstaken": "mistaken",
    "missunderstand": "misunderstand",
    "missuse": "misuse",
    "misterious": "mysterious",
    "mistery": "mystery",
    "misteryous": "mysterious",
    "misxtape": "mixtape",
    "mith": "with",
    "mits": "hits",
    "mixted": "mixed",
    "mjc": "mac",
    "mjor": "major",
    "mkae": "make",
    "mkaes": "makes",
    "mkaing": "making",
    "mke": "make",
    "mke": "me",
    "mkea": "make",
    "mkes": "makes",
    "mking": "making",
    "mkm": "mom",
    "mley": "miley",
    "mmario": "mario",
    "mmay": "may",
    "mmss": "mms",
    "mnn": "man",
    "mnoday": "monday",
    "mnths": "months",
    "mny": "my",
    "mobilex": "mobile",
    "mobily": "mobile",
    "moblie": "mobile",
    "moccassins": "moccasins",
    "moday": "today",
    "moderatley": "moderately",
    "moderatly": "moderately",
    "moderm": "modem",
    "modfied": "modified",
    "modifaction": "modification",
    "modifed": "modified",
    "modle": "model",
    "moent": "moment",
    "moeny": "money",
    "moey": "money",
    "moght": "might",
    "mohammedans": "muslims",
    "moil": "mohel",
    "moil": "soil",
    "moives": "movies",
    "mojor": "major",
    "moleclues": "molecules",
    "mollest": "molest",
    "momento": "memento",
    "momment": "moment",
    "momths": "months",
    "momy": "mom",
    "momz": "moms",
    "monastry": "monastery",
    "monent": "moment",
    "monestaries": "monasteries",
    "monickers": "monikers",
    "moniter": "monitor",
    "monolite": "monolithic",
    "monoploy": "monopoly",
    "monoply": "monopoly",
    "monst": "most",
    "montains": "mountains",
    "montanous": "mountainous",
    "monthes": "months",
    "monthi": "month",
    "monthz": "months",
    "monts": "months",
    "montypic": "monotypic",
    "moohie": "mophie",
    "moorning": "morning",
    "mophine": "mophie",
    "mophio": "mophie",
    "mopre": "more",
    "morgage": "mortgage",
    "morining": "morning",
    "mornig": "morning",
    "mornign": "morning",
    "mornng": "morning",
    "mornting": "morning",
    "mororola": "motorola",
    "morphie": "mophie",
    "morre": "more",
    "morring": "morning",
    "morrning": "morning",
    "morroccan": "moroccan",
    "morrocco": "morocco",
    "morroco": "morocco",
    "mortage": "mortgage",
    "mortor": "motor",
    "moster": "monster",
    "mosture": "moisture",
    "motiviated": "motivated",
    "motorolla": "motorola",
    "mountanous": "mountainous",
    "mounth": "month",
    "mounths": "months",
    "mountian": "mountain",
    "movei": "movie",
    "moveing": "moving",
    "moviee": "movie",
    "moviess": "movies",
    "moviez": "movie",
    "movment": "movement",
    "mozillia": "mozilla",
    "mozt": "most",
    "mozzilla": "mozilla",
    "mprovements": "improvements",
    "mroe": "more",
    "mroning": "morning",
    "mske": "make",
    "msot": "most",
    "mspace": "myspace",
    "mthe": "the",
    "mty": "my",
    "mucg": "much",
    "muchh": "much",
    "mucht": "much",
    "mucuous": "mucous",
    "muder": "murder",
    "muderer": "murderer",
    "mudering": "murdering",
    "mudic": "music",
    "mueseum": "museum",
    "mught": "might",
    "muhammadan": "muslim",
    "muic": "music",
    "muich": "much",
    "muisc": "music",
    "mulitplayer": "multiplayer",
    "mulitple": "multiple",
    "mulitply": "multiply",
    "multicultralism": "multiculturalism",
    "multipled": "multiplied",
    "multiplers": "multipliers",
    "multiplyed": "multiplied",
    "multitaking": "multitasking",
    "munbers": "numbers",
    "muncipalities": "municipalities",
    "muncipality": "municipality",
    "municipalites": "municipalities",
    "municipalties": "municipalities",
    "municipalty": "municipality",
    "municipaly": "municipality",
    "munnicipality": "municipality",
    "musch": "much",
    "muscial": "musical",
    "muscician": "musician",
    "muscicians": "musicians",
    "musem": "museum",
    "musicaly": "musically",
    "musican": "musician",
    "musicial": "musical",
    "musik": "music",
    "musin": "music",
    "musrt": "must",
    "musseum": "museum",
    "musuem": "museum",
    "mutiliated": "mutilated",
    "mutiple": "multiple",
    "mutiplication": "multiplication",
    "mutiply": "multiply",
    "muuch": "much",
    "muusic": "music",
    "mweb": "web",
    "myabe": "maybe",
    "myapace": "myspace",
    "mybe": "maybe",
    "mye": "my",
    "myelf": "myself",
    "myi": "my",
    "mypantene": "mypantone",
    "myraid": "myriad",
    "mysace": "myspace",
    "mysef": "myself",
    "myselg": "myself",
    "myslef": "myself",
    "mysogynist": "misogynist",
    "mysogynistic": "misogynistic",
    "mysogyny": "misogyny",
    "mysterous": "mysterious",
    "mystry": "mystery",
    "myt": "my",
    "myy": "my",
    "nabout": "about",
    "nacent": "nascent",
    "naieve": "naive",
    "nakes": "makes",
    "naking": "making",
    "namerica": "america",
    "namez": "name",
    "nanchuk": "nunchuk",
    "napp": "nap",
    "narate": "narrate",
    "narative": "narrative",
    "narow": "narrow",
    "nascient": "nascent",
    "nasel": "nasal",
    "natched": "watched",
    "nathional": "national",
    "natinal": "national",
    "nationalites": "nationalities",
    "nationaly": "nationally",
    "natrual": "natural",
    "natual": "natural",
    "natuarlly": "naturally",
    "natuional": "national",
    "naturaly": "naturally",
    "naturely": "naturally",
    "naturual": "natural",
    "naturually": "naturally",
    "navagation": "navigation",
    "naviagation": "navigation",
    "ncase": "case",
    "ndian": "indian",
    "ndont": "dont",
    "neally": "really",
    "nearbye": "nearby",
    "nearch": "search",
    "neccesarily": "necessarily",
    "neccesary": "necessary",
    "neccessarily": "necessarily",
    "neccessary": "necessary",
    "neccessities": "necessities",
    "necesarily": "necessarily",
    "necesary": "necessary",
    "necessiate": "necessitate",
    "nect": "next",
    "nedd": "need",
    "neddles": "needles",
    "nedxt": "next",
    "neec": "need",
    "needa": "needs",
    "needc": "need",
    "needd": "need",
    "neededc": "needed",
    "needet": "needed",
    "needz": "needs",
    "neeed": "need",
    "neeeds": "needs",
    "neeeed": "needed",
    "neen": "need",
    "neew": "new",
    "negativley": "negatively",
    "negativly": "negatively",
    "negitive": "negative",
    "negitivity": "negativity",
    "neglible": "negligible",
    "negligable": "negligible",
    "negociate": "negotiate",
    "negociation": "negotiation",
    "negociations": "negotiations",
    "negotation": "negotiation",
    "negotiater": "negotiator",
    "negtive": "negative",
    "neigborhood": "neighborhood",
    "neigbourhood": "neighbourhood",
    "neing": "being",
    "nelw": "new",
    "nember": "number",
    "nentendo": "nintendo",
    "neolitic": "neolithic",
    "nervs": "nerves",
    "nessacary": "necessary",
    "nessasarily": "necessarily",
    "nessecary": "necessary",
    "nestin": "nesting",
    "nesxt": "next",
    "netfilx": "netflix",
    "netnewsware": "netnewswire",
    "netnewwire": "netnewswire",
    "netwoking": "networking",
    "netwoorking": "networking",
    "netwroking": "networking",
    "neuclear": "nuclear",
    "neveer": "never",
    "neverr": "never",
    "neverthless": "nevertheless",
    "nevewr": "never",
    "nevrr": "never",
    "neweast": "newest",
    "newely": "newly",
    "neweswt": "newest",
    "newletter": "newsletter",
    "newletters": "newsletters",
    "newnewswire": "netnewswire",
    "newphew": "nephew",
    "newq": "new",
    "newsa": "news",
    "newss": "news",
    "newst": "news",
    "newu": "news",
    "neww": "new",
    "neww": "news",
    "newws": "news",
    "newy": "new",
    "nexgt": "next",
    "nexto": "next",
    "nexy": "next",
    "nget": "get",
    "nght": "night",
    "nicce": "nice",
    "nich": "nice",
    "nici": "nice",
    "nickk": "nick",
    "nickle": "nickel",
    "nicname": "nickname",
    "nieghbor": "neighbor",
    "nieghbour": "neighbour",
    "niether": "neither",
    "nighmare": "nightmare",
    "nightfa;;": "nightfall",
    "nightime": "nighttime",
    "nightt": "night",
    "nigth": "night",
    "niight": "night",
    "nikia": "nokia",
    "nindendo": "nintendo",
    "ninendo": "nintendo",
    "ninetendo": "nintendo",
    "nineth": "ninth",
    "ninetndo": "nintendo",
    "ninitendo": "nintendo",
    "nintedno": "nintendo",
    "nintedo": "nintendo",
    "ninteen": "nineteen",
    "ninteenth": "nineteenth",
    "nintenbo": "nintendo",
    "nintendi": "nintendo",
    "nintendio": "nintendo",
    "nintendoo": "nintendo",
    "nintendow": "nintendo",
    "ninteno": "nintendo",
    "nintentdo": "nintendo",
    "nintento": "nintendo",
    "nintey": "ninety",
    "ninties": "1990s",
    "ninties": "nineties",
    "nintindo": "nintendo",
    "nintnedo": "nintendo",
    "ninty": "ninety",
    "niot": "not",
    "nitendo": "nintendo",
    "nivites": "invites",
    "njoy": "enjoy",
    "nkew": "new",
    "nkow": "know",
    "nkwo": "know",
    "nlog": "blog",
    "nlove": "love",
    "nly": "only",
    "nmae": "name",
    "nmeed": "need",
    "nmot": "not",
    "nmy": "my",
    "nned": "need",
    "nneed": "need",
    "nnew": "new",
    "nnot": "not",
    "nnow": "now",
    "noew": "new",
    "nomencalture": "nomenclature",
    "noncombatents": "noncombatants",
    "nonsence": "nonsense",
    "nontheless": "nonetheless",
    "noone": "no one",
    "nopt": "not",
    "nopw": "now",
    "noraml": "normal",
    "norbal": "normal",
    "norhern": "northern",
    "normail": "normal",
    "normaly": "normally",
    "nornal": "normal",
    "northen": "northern",
    "northereastern": "northeastern",
    "nortoriety": "notoriety",
    "nortorious": "notorious",
    "notabley": "notably",
    "notariety": "notoriety",
    "noteable": "notable",
    "noteably": "notably",
    "noteriety": "notoriety",
    "notewothy": "noteworthy",
    "notfier": "notifier",
    "noth": "north",
    "nothern": "northern",
    "nothig": "nothing",
    "nothign": "nothing",
    "nothinq": "nothing",
    "nothng": "nothing",
    "noticable": "noticeable",
    "noticably": "noticeably",
    "noticeing": "noticing",
    "noticible": "noticeable",
    "notifcation": "notification",
    "notifcations": "notifications",
    "notifer": "notifier",
    "notiications": "notifications",
    "notiiced": "noticed",
    "notorius": "notorious",
    "notting": "nothing",
    "notwhithstanding": "notwithstanding",
    "nout": "not",
    "noveau": "nouveau",
    "nowdays": "nowadays",
    "nowe": "now",
    "noww": "now",
    "noyification": "notification",
    "npwhere": "nowhere",
    "nrews": "news",
    "nso": "no",
    "nstead": "instead",
    "nter": "enter",
    "nternet": "internet",
    "nto": "not",
    "ntop": "top",
    "nubmer": "number",
    "nucular": "nuclear",
    "nuculear": "nuclear",
    "nuerological": "neurological",
    "nuerotic": "neurotic",
    "nuerotransmitter": "neurotransmitter",
    "nuetral": "neutral",
    "nuetrality": "neutrality",
    "nuetralize": "neutralize",
    "nuisanse": "nuisance",
    "numberous": "numerous",
    "numer": "number",
    "nuncuck": "nunchuck",
    "nup": "up",
    "nusance": "nuisance",
    "nust": "just",
    "nuthing": "nothing",
    "nutrality": "neutrality",
    "nutritent": "nutrient",
    "nutritents": "nutrients",
    "nuturing": "nurturing",
    "nvention": "invention",
    "nver": "never",
    "nvitation": "invitation",
    "nvite": "invite",
    "nvites": "invites",
    "nvo": "no",
    "nyce": "nice",
    "nyone": "anyone",
    "oabama": "obama",
    "oalm": "palm",
    "oand": "and",
    "oarange": "orange",
    "obamao": "obama",
    "obcene": "obscene",
    "obcenity": "obscenity",
    "obediance": "obedience",
    "obediant": "obedient",
    "obervation": "observation",
    "obessed": "obsessed",
    "obession": "obsession",
    "objetive": "objective",
    "obligued": "obliged",
    "oboma": "obama",
    "observence": "observance",
    "observor": "observer",
    "obsesssed": "obsessed",
    "obsolecence": "obsolescence",
    "obsolecense": "obsolescence",
    "obsolesence": "obsolescence",
    "obsolesense": "obsolescence",
    "obssesed": "obsessed",
    "obssessed": "obsessed",
    "obssession": "obsession",
    "obssessive": "obsessive",
    "obstacal": "obstacle",
    "obstancles": "obstacles",
    "obsticle": "obstacle",
    "obstruced": "obstructed",
    "obtion": "option",
    "ocasion": "occasion",
    "ocasional": "occasional",
    "ocasionally": "occasionally",
    "ocasionaly": "occasionally",
    "ocasioned": "occasioned",
    "ocasions": "occasions",
    "ocassion": "occasion",
    "ocassional": "occasional",
    "ocassionally": "occasionally",
    "ocassionaly": "occasionally",
    "ocassioned": "occasioned",
    "ocassions": "occasions",
    "occaison": "occasion",
    "occaisonally": "occasionally",
    "occasionaly": "occasionally",
    "occasonal": "occasional",
    "occassion": "occasion",
    "occassional": "occasional",
    "occassionally": "occasionally",
    "occassionaly": "occasionally",
    "occassioned": "occasioned",
    "occassions": "occasions",
    "occationally": "occasionally",
    "occour": "occur",
    "occurance": "occurrence",
    "occurances": "occurrences",
    "occured": "occurred",
    "occurence": "occurrence",
    "occurences": "occurrences",
    "occuring": "occurring",
    "occurr": "occur",
    "occurrance": "occurrence",
    "occurrances": "occurrences",
    "ochochinco": "ochocinco",
    "ocial": "social",
    "ocme": "come",
    "ocnvite": "convite",
    "octohedra": "octahedra",
    "octohedral": "octahedral",
    "octohedron": "octahedron",
    "octover": "october",
    "octuber": "october",
    "ocuntries": "countries",
    "ocuntry": "country",
    "ocupied": "occupied",
    "ocupy": "occupy",
    "ocurr": "occur",
    "ocurrance": "occurrence",
    "ocurred": "occurred",
    "ocurrence": "occurrence",
    "ocurring": "occurring",
    "ocurrs": "occurs",
    "oddites": "oddities",
    "odered": "ordered",
    "offce": "office",
    "offcers": "officers",
    "offcial": "official",
    "offcially": "officially",
    "offcier": "officer",
    "offereing": "offering",
    "offereings": "offerings",
    "offf": "off",
    "officailly": "officially",
    "offical": "official",
    "offically": "officially",
    "officals": "officials",
    "officaly": "officially",
    "officiaal": "official",
    "officialy": "officially",
    "officialy": "officials",
    "officically": "officially",
    "officilly": "officially",
    "officle": "office",
    "offivial": "official",
    "offred": "offered",
    "offshot": "offshoot",
    "oficial": "official",
    "oficially": "officially",
    "ofp": "of",
    "oftenly": "often",
    "oftern": "often",
    "oget": "get",
    "ogh": "oh",
    "ohey": "hey",
    "ohk": "ok",
    "ohmg": "omg",
    "ohne": "one",
    "ohone": "phone",
    "oing": "going",
    "oinkmemt": "oinkment",
    "okia": "nokia",
    "olaying": "playing",
    "olny": "only",
    "olso": "also",
    "omgg": "omg",
    "omgz": "omg",
    "oming": "coming",
    "omision": "omission",
    "omited": "omitted",
    "omiting": "omitting",
    "omitt": "omit",
    "omlette": "omelette",
    "ommision": "omission",
    "ommit": "omit",
    "ommited": "omitted",
    "ommiting": "omitting",
    "ommitted": "omitted",
    "ommitting": "omitting",
    "omniverous": "omnivorous",
    "omniverously": "omnivorously",
    "omre": "more",
    "onb": "on",
    "onee": "one",
    "oness": "ones",
    "onh": "on",
    "onl": "one",
    "onlly": "only",
    "onlt": "only",
    "onlu": "only",
    "onlyl": "only",
    "onmy": "only",
    "onnly": "only",
    "ontil": "until",
    "onver": "over",
    "onw": "own",
    "onwers": "owners",
    "ony": "only",
    "onyl": "only",
    "oout": "out",
    "oow": "now",
    "oparate": "operate",
    "opctober": "october",
    "openess": "openness",
    "openion": "opinion",
    "openned": "opened",
    "operater": "operator",
    "opertion": "operation",
    "opertunity": "opportunity",
    "opinate": "opine",
    "opinionn": "opinion",
    "opinon": "opinion",
    "opinons": "opinions",
    "opionion": "opinion",
    "opne": "one",
    "opnion": "option",
    "oponent": "opponent",
    "oportunity": "opportunity",
    "opose": "oppose",
    "oposite": "opposite",
    "oposition": "opposition",
    "oppen": "open",
    "oppened": "opened",
    "oppening": "opening",
    "oppenly": "openly",
    "opperate": "operate",
    "opperating": "operating",
    "opperation": "operation",
    "oppinion": "opinion",
    "oppisite": "opposite",
    "opponant": "opponent",
    "opponet": "opponent",
    "oppononent": "opponent",
    "opportuinity": "opportunity",
    "opportunites": "opportunities",
    "opportunty": "opportunity",
    "oppositition": "opposition",
    "oppossed": "opposed",
    "oppotunity": "opportunity",
    "oppourtunity": "opportunity",
    "opprotunity": "opportunity",
    "oppsoed": "opposed",
    "opress": "oppress",
    "opression": "oppression",
    "opressive": "oppressive",
    "opthalmic": "ophthalmic",
    "opthalmologist": "ophthalmologist",
    "opthalmology": "ophthalmology",
    "opthamologist": "ophthalmologist",
    "opther": "other",
    "opthomologist": "ophthalmologist",
    "opthomology": "ophthalmology",
    "optimzed": "optimized",
    "optimzer": "optimizer",
    "optmizations": "optimizations",
    "optmizer": "optimizer",
    "optomism": "optimism",
    "optomist": "optimist",
    "optomistic": "optimistic",
    "optomized": "optimized",
    "oragnge": "orange",
    "oranage": "orange",
    "orchestera": "orchestra",
    "orchesteral": "orchestral",
    "orded": "ordered",
    "orgainisation": "organisation",
    "orgainise": "organise",
    "orgainization": "organization",
    "orgainize": "organize",
    "organiation": "organization",
    "organim": "organism",
    "organistion": "organisation",
    "organiztion": "organization",
    "orginal": "original",
    "orginally": "originally",
    "orginate": "originate",
    "orginise": "organise",
    "orginization": "organization",
    "orginize": "organise",
    "orginize": "organize",
    "oridinarily": "ordinarily",
    "oriention": "orientation",
    "origanal": "original",
    "origanaly": "originally",
    "originaly": "originally",
    "originial": "original",
    "originially": "originally",
    "originiate": "originate",
    "originnal": "original",
    "originnally": "originally",
    "origional": "original",
    "orignal": "original",
    "orignally": "originally",
    "orignate": "originate",
    "orignial": "original",
    "orignially": "originally",
    "origonal": "original",
    "oriinal": "original",
    "ornage": "orange",
    "orthagonal": "orthogonal",
    "orthagonally": "orthogonally",
    "orthgonal": "orthogonal",
    "orthogonaly": "orthogonally",
    "otehr": "other",
    "oter": "other",
    "othe": "the",
    "othere": "other",
    "otheres": "others",
    "otimizer": "optimizer",
    "otld": "told",
    "ottaman": "Ottoman",
    "otuch": "touch",
    "oublisher": "publisher",
    "oubreaks": "outbreaks",
    "ouevre": "oeuvre",
    "ouf": "of",
    "oug": "out",
    "ouh": "out",
    "ourt": "out",
    "oustanding": "outstanding",
    "oustide": "outside",
    "outbreakk": "outbreak",
    "outbreat": "outbreak",
    "outragous": "outrageous",
    "outreaks": "outbreaks",
    "outswll": "outsell",
    "outt": "out",
    "outter": "outer",
    "outtta": "outta",
    "outweighted": "outweighed",
    "ouut": "out",
    "ouutbreak": "outbreak",
    "ouy": "out",
    "ouyt": "out",
    "ovah": "ova",
    "ovar": "over",
    "overan": "overran",
    "overated": "overrated",
    "overe": "over",
    "overeach": "overreach",
    "overide": "override",
    "overode": "overrode",
    "overshaddowed": "overshadowed",
    "overthere": "over there",
    "overule": "overrule",
    "overun": "overrun",
    "overwelming": "overwhelming",
    "overwheliming": "overwhelming",
    "oveture": "overture",
    "ovfer": "over",
    "ovner": "owner",
    "owh": "oh",
    "ownrs": "owners",
    "ownz": "owns",
    "owrk": "work",
    "owrking": "working",
    "owudl": "would",
    "owuld": "would",
    "oxigen": "oxygen",
    "oximoron": "oxymoron",
    "oxyen": "oxygen",
    "oyt": "out",
    "p0enis": "penis",
    "paarking": "parking",
    "pacfic": "pacific",
    "pacifc": "pacific",
    "pademic": "pandemic",
    "pagez": "pages",
    "paide": "paid",
    "paim": "pain",
    "paitently": "patiently",
    "paitents": "patients",
    "paitience": "patience",
    "pake": "make",
    "pake": "take",
    "palce": "place",
    "paleolitic": "paleolithic",
    "paliament": "parliament",
    "paliamentarian": "parliamentarian",
    "pallete": "palette",
    "pallm": "palm",
    "palyed": "played",
    "palyer": "player",
    "palying": "playing",
    "pamdemic": "pandemic",
    "pamflet": "pamphlet",
    "pamplet": "pamphlet",
    "panal": "panel",
    "panarama": "panorama",
    "panicing": "panicking",
    "paniking": "panicking",
    "pantomine": "pantomime",
    "paparazzis": "paparazzi",
    "paperr": "paper",
    "paralel": "parallel",
    "paralell": "parallel",
    "paralelly": "parallelly",
    "paralely": "parallelly",
    "parallell": "parallel",
    "parallely": "parallelly",
    "paranoraml": "paranormal",
    "paranthesis": "parenthesis",
    "paraphenalia": "paraphernalia",
    "parellels": "parallels",
    "parinoia": "paranoia",
    "parisitic": "parasitic",
    "parituclar": "particular",
    "parliment": "parliament",
    "parntership": "partnership",
    "parrakeets": "parakeets",
    "parralel": "parallel",
    "parrallel": "parallel",
    "parrallell": "parallel",
    "parrallelly": "parallelly",
    "parrallely": "parallelly",
    "parrt": "part",
    "partecipate": "participate",
    "partership": "partnership",
    "partialy": "partially",
    "particpant": "participant",
    "particpated": "participated",
    "particually": "particularly",
    "particualr": "particular",
    "particuarly": "particularly",
    "particularily": "particularly",
    "particulary": "particularly",
    "partipate": "participate",
    "partisipate": "participate",
    "pary": "party",
    "pased": "passed",
    "pasenger": "passenger",
    "pasengers": "passengers",
    "passanger": "passenger",
    "passerbys": "passersby",
    "passtime": "pastime",
    "pastorial": "pastoral",
    "pasttime": "pastime",
    "pastural": "pastoral",
    "pasturize": "pasteurize",
    "paticular": "particular",
    "patiencly": "patiently",
    "patnership": "partnership",
    "pattent": "patent",
    "pattented": "patented",
    "pavillion": "pavilion",
    "payd": "paid",
    "payed": "paid",
    "payler": "player",
    "pazific": "pacific",
    "pbest": "best",
    "pblisher": "publisher",
    "pbulisher": "publisher",
    "pckage": "package",
    "peacefuland": "peaceful and",
    "peachs": "peaches",
    "peageant": "pageant",
    "peaple": "people",
    "peaples": "peoples",
    "peasent": "peasant",
    "pecause": "because",
    "pecent": "percent",
    "pecentage": "percentage",
    "pecular": "peculiar",
    "pecularity": "peculiarity",
    "pecularly": "peculiarly",
    "peculiarites": "peculiarities",
    "peculure": "peculiar",
    "pedestrain": "pedestrian",
    "peform": "perform",
    "peformance": "performance",
    "peformed": "performed",
    "peice": "piece",
    "peice": "price",
    "peiple": "people",
    "pelase": "please",
    "penatly": "penalty",
    "pendemic": "pandemic",
    "penerator": "penetrator",
    "peninnsula": "peninsula",
    "penisula": "peninsula",
    "penisular": "peninsular",
    "penninsula": "peninsula",
    "penninsular": "peninsular",
    "pennisula": "peninsula",
    "pensinsula": "peninsula",
    "pensinula": "peninsula",
    "pensle": "pencil",
    "peole": "people",
    "peom": "poem",
    "peoms": "poems",
    "peope": "people",
    "peopel": "people",
    "peopele": "people",
    "peopels": "peoples",
    "peoplea": "people",
    "peoplr": "people",
    "peoplt": "people",
    "peoplw": "people",
    "peopole": "people",
    "peotry": "poetry",
    "peoud": "proud",
    "peparing": "preparing",
    "pepole": "people",
    "perade": "parade",
    "percautions": "precautions",
    "percepted": "perceived",
    "percieve": "perceive",
    "percieved": "perceived",
    "perculiar": "peculiar",
    "perenially": "perennially",
    "pereparing": "preparing",
    "perfer": "prefer",
    "perfet": "perfect",
    "perfom": "perform",
    "perfomance": "performance",
    "perfomers": "performers",
    "perfoming": "performing",
    "performence": "performance",
    "perhasp": "perhaps",
    "perheaps": "perhaps",
    "perhpas": "perhaps",
    "peripathetic": "peripatetic",
    "peristent": "persistent",
    "perjery": "perjury",
    "perjorative": "pejorative",
    "permanant": "permanent",
    "permenant": "permanent",
    "permenantly": "permanently",
    "permissable": "permissible",
    "permited": "permitted",
    "permiting": "permitting",
    "permitt": "permit",
    "perogative": "prerogative",
    "peronal": "personal",
    "perosn": "person",
    "perosnality": "personality",
    "perpare": "prepare",
    "perpared": "prepared",
    "perpertrated": "perpetrated",
    "perphas": "perhaps",
    "perpindicular": "perpendicular",
    "persan": "person",
    "persaude": "persuade",
    "perserverence": "perseverance",
    "perseverence": "perseverance",
    "persistance": "persistence",
    "persistant": "persistent",
    "personaly": "personally",
    "personell": "personnel",
    "personn": "person",
    "personnell": "personnel",
    "persuded": "persuaded",
    "persue": "pursue",
    "persued": "pursued",
    "persuing": "pursuing",
    "persuit": "pursuit",
    "persuits": "pursuits",
    "pertubation": "perturbation",
    "pertubations": "perturbations",
    "perview": "purview",
    "pespi": "pepsi",
    "pessiary": "pessary",
    "petetion": "petition",
    "peuple": "people",
    "peurto rico": "Puerto Rico",
    "pevent": "prevent",
    "peview": "review",
    "pgae": "page",
    "pgot": "got",
    "phanton": "phantom",
    "phenomenom": "phenomenon",
    "phenomenonal": "phenomenal",
    "phenomenonly": "phenomenally",
    "phenominal": "phenomenal",
    "phenomonenon": "phenomenon",
    "phenomonon": "phenomenon",
    "phenonmena": "phenomena",
    "philantrophist": "philanthropist",
    "philantrophy": "philanthropy",
    "philantropist": "philanthropist",
    "philantropy": "philanthropy",
    "philipines": "philippines",
    "philisopher": "philosopher",
    "philisophical": "philosophical",
    "philisophy": "philosophy",
    "phillosophically": "philosophically",
    "philospher": "philosopher",
    "philosphies": "philosophies",
    "philosphy": "philosophy",
    "phne": "phone",
    "phoe": "phone",
    "phoen": "phone",
    "phond": "phone",
    "phongraph": "phonograph",
    "phonje": "phone",
    "phont": "phone",
    "phoone": "phone",
    "photgraph": "photograph",
    "photochop": "photoshop",
    "photohop": "photoshop",
    "photoshopp": "photoshop",
    "photoshot": "photoshop",
    "photoshp": "photoshop",
    "photosop": "photoshop",
    "photshop": "photoshop",
    "phtotoshop": "photoshop",
    "phusical": "physical",
    "phyiscal": "physical",
    "phylosophical": "philosophical",
    "physicaly": "physically",
    "physican": "physician",
    "physicial": "physical",
    "piacked": "picked",
    "pibg": "ping",
    "piblisher": "publisher",
    "pich": "pitch",
    "pickinp": "picking",
    "picolo": "piccolo",
    "picss": "pics",
    "pictre": "picture",
    "pictres": "pictures",
    "pictue": "picture",
    "picturee": "picture",
    "picure": "picture",
    "picutre": "picture",
    "picutres": "pictures",
    "picuture": "picture",
    "pieace": "piece",
    "piecw": "piece",
    "piefort": "piedfort",
    "pigggy": "piggy",
    "piggly": "piggy",
    "piint": "point",
    "piks": "pics",
    "pikture": "picture",
    "pilgramage": "pilgrimage",
    "pilgrimmage": "pilgrimage",
    "pilgrimmages": "pilgrimages",
    "piligrimage": "pilgrimage",
    "pinapple": "pineapple",
    "pind": "ping",
    "pinnaple": "pineapple",
    "pinoneered": "pioneered",
    "pionering": "pioneering",
    "piont": "point",
    "piratei": "pirate",
    "pisisng": "pissing",
    "pissess": "pisses",
    "pissinq": "pissing",
    "pissn": "piss",
    "pisssing": "pissing",
    "pistures": "pictures",
    "pitchs": "pitches",
    "pitcture": "picture",
    "pitures": "pictures",
    "pivtures": "pictures",
    "pixs": "pics",
    "pkay": "play",
    "pkaying": "playing",
    "plaay": "play",
    "plaayed": "played",
    "plaaying": "playing",
    "placeing": "placing",
    "plaese": "please",
    "plagarism": "plagiarism",
    "plagarist": "plagiarist",
    "plagarize": "plagiarize",
    "plah": "play",
    "plaing": "playing",
    "plam": "play",
    "planation": "plantation",
    "planed": "planned",
    "plannning": "planning",
    "plantiff": "plaintiff",
    "plase": "please",
    "plateu": "plateau",
    "platforn": "platform",
    "platfrom": "platform",
    "plauge": "plague",
    "plausable": "plausible",
    "playibg": "playing",
    "playign": "playing",
    "playiin": "playin",
    "playiing": "playing",
    "playimg": "playing",
    "playinf": "playing",
    "playingg": "playing",
    "playinh": "playing",
    "playinn": "playing",
    "playinng": "playing",
    "playinq": "playing",
    "playling": "playing",
    "playn": "play",
    "playng": "playing",
    "playnig": "playing",
    "playoing": "playing",
    "playong": "playing",
    "playright": "playwright",
    "playwrite": "playwright",
    "playwrites": "playwrights",
    "playy": "play",
    "playyed": "played",
    "pleaase": "please",
    "pleae": "please",
    "pleasent": "pleasant",
    "pleasnat": "pleasant",
    "pleasse": "please",
    "pleaze": "please",
    "pleazse": "please",
    "plebicite": "plebiscite",
    "pleease": "please",
    "plesant": "pleasant",
    "plese": "please",
    "plethura": "plethora",
    "plez": "plz",
    "plist": "list",
    "pliz": "plz",
    "pllenty": "plenty",
    "plone": "phone",
    "plrase": "please",
    "plsce": "place",
    "plsying": "playing",
    "pludge": "plunge",
    "pluged": "plugged",
    "pluss": "plus",
    "pluz": "plz",
    "plya": "play",
    "plyin": "playin",
    "plzz": "plz",
    "pmaybe": "maybe",
    "pngs": "pigs",
    "pnly": "only",
    "pnumonia": "pneumonia",
    "poblem": "problem",
    "poenis": "penis",
    "poeoples": "peoples",
    "poeple": "people",
    "poety": "poetry",
    "poisening": "poisoning",
    "poisin": "poison",
    "poisining": "poisoning",
    "polical": "political",
    "polinate": "pollinate",
    "polination": "pollination",
    "polinator": "pollinator",
    "polinators": "pollinators",
    "politian": "politician",
    "politican": "politician",
    "politicans": "politicians",
    "politition": "politician",
    "poltical": "political",
    "polute": "pollute",
    "poluted": "polluted",
    "polutes": "pollutes",
    "poluting": "polluting",
    "polution": "pollution",
    "polyphonyic": "polyphonic",
    "polysaccaride": "polysaccharide",
    "polysaccharid": "polysaccharide",
    "pomegranite": "pomegranate",
    "pomotion": "promotion",
    "poosible": "possible",
    "popolar": "popular",
    "poportional": "proportional",
    "popoulation": "population",
    "populaion": "population",
    "populair": "popular",
    "popularaty": "popularity",
    "populare": "popular",
    "populer": "popular",
    "popupar": "popular",
    "porportion": "proportion",
    "porshan": "portion",
    "porshon": "portion",
    "portait": "portrait",
    "portayed": "portrayed",
    "portble": "portable",
    "portect": "protect",
    "portraing": "portraying",
    "portuguease": "portuguese",
    "portugues": "Portuguese",
    "posative": "positive",
    "posess": "possess",
    "posessed": "possessed",
    "posesses": "possesses",
    "posessing": "possessing",
    "posession": "possession",
    "posessions": "possessions",
    "posibility": "possibility",
    "posible": "possible",
    "posibly": "possibly",
    "posion": "poison",
    "posistion": "position",
    "positivee": "positive",
    "positve": "positive",
    "possable": "possible",
    "possably": "possibly",
    "possbile": "possible",
    "possble": "possible",
    "posseses": "possesses",
    "possesing": "possessing",
    "possesion": "possession",
    "possessess": "possesses",
    "possiable": "possible",
    "possibe": "possible",
    "possibel": "possible",
    "possibile": "possible",
    "possibilty": "possibility",
    "possiblility": "possibility",
    "possiblilty": "possibility",
    "possiblities": "possibilities",
    "possiblity": "possibility",
    "possiblr": "possible",
    "possilbe": "possible",
    "possile": "possible",
    "possition": "position",
    "posssible": "possible",
    "postg": "post",
    "posthomous": "posthumous",
    "postiive": "positive",
    "postion": "position",
    "postitive": "positive",
    "postive": "positive",
    "postively": "positively",
    "postoned": "postponed",
    "potatos": "potatoes",
    "potencial": "potential",
    "potentialy": "potentially",
    "potentional": "potential",
    "potenyial": "potential",
    "potrait": "portrait",
    "potray": "portray",
    "potrayed": "portrayed",
    "poulations": "populations",
    "pouplar": "popular",
    "pourpose": "purpose",
    "poverful": "powerful",
    "poweful": "powerful",
    "powerd": "powered",
    "powerfull": "powerful",
    "powrful": "powerful",
    "ppiggy": "piggy",
    "pplaying": "playing",
    "pple": "ppl",
    "pplz": "ppl",
    "ppssible": "possible",
    "ppublisher": "publisher",
    "praay": "pray",
    "practial": "practical",
    "practially": "practically",
    "practicaly": "practically",
    "practicioner": "practitioner",
    "practicioners": "practitioners",
    "practicly": "practically",
    "practioner": "practitioner",
    "practioners": "practitioners",
    "prairy": "prairie",
    "prarie": "prairie",
    "praries": "prairies",
    "prary": "pray",
    "pratice": "practice",
    "prayy": "pray",
    "prblems": "problems",
    "pre-Colombian": "pre-Columbian",
    "pre-existant": "preexistent",
    "preample": "preamble",
    "preapred": "prepared",
    "precedessor": "predecessor",
    "preceed": "precede",
    "preceeded": "preceded",
    "preceeding": "preceding",
    "preceeds": "precedes",
    "preceive": "perceive",
    "precentage": "percentage",
    "precice": "precise",
    "precidence": "precedence",
    "precint": "precinct",
    "precisly": "precisely",
    "precurser": "precursor",
    "precvent": "prevent",
    "predecesors": "predecessors",
    "predicatble": "predictable",
    "predicitons": "predictions",
    "predicitve": "predictive",
    "predident": "president",
    "predomiantly": "predominately",
    "preety": "pretty",
    "prefection": "perfection",
    "prefered": "preferred",
    "prefering": "preferring",
    "preferrable": "preferable",
    "preferrably": "preferably",
    "preffer": "prefer",
    "preffered": "preferred",
    "pregancies": "pregnancies",
    "pregancy": "pregnancy",
    "pregant": "pregnant",
    "pregnacy": "pregnancy",
    "preiod": "period",
    "preist": "priest",
    "preita": "prieta",
    "preivew": "preview",
    "prejorative": "pejorative",
    "preliferation": "proliferation",
    "premanent": "permanent",
    "premeire": "premiere",
    "premeired": "premiered",
    "premesis": "premises",
    "premillenial": "premillennial",
    "preminence": "preeminence",
    "premission": "permission",
    "prengancy": "pregnancy",
    "preocupation": "preoccupation",
    "prepair": "prepare",
    "prepaired": "prepared",
    "prepapred": "prepared",
    "preparez": "prepares",
    "prepartion": "preparation",
    "prepatory": "preparatory",
    "preperation": "preparation",
    "preperations": "preparations",
    "preperatory": "preparatory",
    "prepered": "prepared",
    "preping": "prepping",
    "preriod": "period",
    "prescence": "presence",
    "presdent": "president",
    "presedential": "presidential",
    "presenation": "presentation",
    "presense": "presence",
    "presentaion": "presentation",
    "presentor": "presenter",
    "presidenital": "presidential",
    "presidental": "presidential",
    "presitgious": "prestigious",
    "preson": "person",
    "prespective": "perspective",
    "prestigeous": "prestigious",
    "prestigous": "prestigious",
    "presumabely": "presumably",
    "presumeably": "presumably",
    "presumibly": "presumably",
    "presure": "pressure",
    "presurize": "pressurize",
    "pretect": "protect",
    "pretection": "protection",
    "pretent": "prevent",
    "prettty": "pretty",
    "pretweet": "retweet",
    "prety": "pretty",
    "prevailance": "prevalence",
    "prevale": "prevail",
    "prevalnt": "prevalent",
    "prevelance": "prevalence",
    "prevelant": "prevalent",
    "prevenative": "preventative",
    "preventataive": "preventative",
    "preventation": "prevention",
    "preverse": "perverse",
    "prevetative": "preventative",
    "prevew": "preview",
    "previus": "previous",
    "previvous": "previous",
    "prevntion": "prevention",
    "prevous": "previous",
    "priata": "prieta",
    "pricem": "price",
    "pricipal": "principal",
    "priciple": "principle",
    "prics": "price",
    "priestood": "priesthood",
    "prietta": "prieta",
    "primarially": "primarily",
    "primarly": "primarily",
    "primative": "primitive",
    "primatively": "primitively",
    "primatives": "primitives",
    "primordal": "primordial",
    "primordeal": "primordial",
    "principaly": "principality",
    "principial": "principal",
    "principlaity": "principality",
    "principly": "principally",
    "prinicipal": "principal",
    "prision": "prison",
    "privalege": "privilege",
    "privaleges": "privileges",
    "privatley": "privately",
    "privatly": "privately",
    "priveledges": "privileges",
    "privelege": "privilege",
    "priveleged": "privileged",
    "priveleges": "privileges",
    "privelidge": "privilege",
    "privelige": "privilege",
    "priveliged": "privileged",
    "priveliges": "privileges",
    "privelleges": "privileges",
    "privilage": "privilege",
    "priviledge": "privilege",
    "priviledges": "privileges",
    "privledge": "privilege",
    "privte": "private",
    "proaganda": "propaganda",
    "probabaly": "probably",
    "probabilaty": "probability",
    "probablistic": "probabilistic",
    "probablly": "probably",
    "probaby": "probably",
    "probalibity": "probability",
    "probally": "probably",
    "probaly": "probably",
    "probbably": "probably",
    "probelm": "problem",
    "probelms": "problems",
    "probibly": "probably",
    "problably": "probably",
    "problemas": "problems",
    "problens": "problems",
    "problesm": "problems",
    "problums": "problems",
    "proboably": "probably",
    "probobly": "probably",
    "proccess": "process",
    "proccessing": "processing",
    "proce": "price",
    "procedger": "procedure",
    "procedings": "proceedings",
    "proceedure": "procedure",
    "proces": "process",
    "processer": "processor",
    "proclaimation": "proclamation",
    "proclame": "proclaim",
    "proclamed": "proclaimed",
    "proclaming": "proclaiming",
    "proclomation": "proclamation",
    "proctector": "protector",
    "prodcution": "production",
    "profect": "project",
    "profesional": "professional",
    "profesor": "professor",
    "professer": "professor",
    "professionaly": "professionally",
    "proffesed": "professed",
    "proffesion": "profession",
    "proffesional": "professional",
    "proffesor": "professor",
    "profilic": "prolific",
    "proft": "profit",
    "progessed": "progressed",
    "progidy": "prodigy",
    "programable": "programmable",
    "prohabition": "prohibition",
    "projcector": "projector",
    "projekt": "project",
    "prologomena": "prolegomena",
    "promese": "promise",
    "prominance": "prominence",
    "prominant": "prominent",
    "prominantly": "prominently",
    "prominate": "prominent",
    "promiscous": "promiscuous",
    "promixity": "proximity",
    "promotted": "promoted",
    "pronomial": "pronominal",
    "pronouced": "pronounced",
    "pronounched": "pronounced",
    "pronounciation": "pronunciation",
    "proove": "prove",
    "prooved": "proved",
    "propably": "probably",
    "propect": "prospect",
    "propeled": "propelled",
    "propeling": "propelling",
    "propell": "propel",
    "propery": "property",
    "propganda": "propaganda",
    "prophacy": "prophecy",
    "propietary": "proprietary",
    "prople": "people",
    "propmted": "prompted",
    "propoganda": "propaganda",
    "propogate": "propagate",
    "propogates": "propagates",
    "propogation": "propagation",
    "propogator": "propagator",
    "propostion": "proposition",
    "propotion": "proportion",
    "propotional": "proportional",
    "propotions": "proportions",
    "propper": "proper",
    "propperly": "properly",
    "proprietory": "proprietary",
    "proseletyzing": "proselytizing",
    "prostest": "protest",
    "protaganist": "protagonist",
    "protaganists": "protagonists",
    "protech": "protect",
    "protecter": "protector",
    "protien": "protein",
    "protocal": "protocol",
    "protoganist": "protagonist",
    "protos": "photos",
    "protoshop": "photoshop",
    "protrait": "portrait",
    "protray": "portray",
    "protrayal": "portrayal",
    "protrayed": "portrayed",
    "protruberance": "protuberance",
    "protruberances": "protuberances",
    "prouncements": "pronouncements",
    "pround": "proud",
    "prounounced": "pronounced",
    "provacative": "provocative",
    "provded": "provided",
    "provicial": "provincial",
    "providor": "provider",
    "provin": "proven",
    "provinicial": "provincial",
    "provisiosn": "provision",
    "provisonal": "provisional",
    "proximty": "proximity",
    "prqy": "pray",
    "prtty": "pretty",
    "prvent": "prevent",
    "prventative": "preventative",
    "pseudononymous": "pseudonymous",
    "pseudonyn": "pseudonym",
    "pstbuy": "pdtbuy",
    "psuedo": "pseudo",
    "psunami": "tsunami",
    "psychidelic": "psychedelic",
    "psychodelic": "psychedelic",
    "psycology": "psychology",
    "psyhic": "psychic",
    "psymptoms": "symptoms",
    "ptoblems": "problems",
    "ptwo": "two",
    "pubilsher": "publisher",
    "pubisher": "publisher",
    "publiaher": "publisher",
    "publically": "publicly",
    "publicaly": "publicly",
    "publicher": "publisher",
    "publihser": "publisher",
    "publik": "public",
    "publisehr": "publisher",
    "publiser": "publisher",
    "publisger": "publisher",
    "publisheed": "published",
    "publisherr": "publisher",
    "publishher": "publisher",
    "publishor": "publisher",
    "publishre": "publisher",
    "publissher": "publisher",
    "publlisher": "publisher",
    "publsiher": "publisher",
    "publusher": "publisher",
    "puchase": "purchase",
    "puchasing": "purchasing",
    "pulisher": "publisher",
    "pumkin": "pumpkin",
    "punchs": "punches",
    "pupl": "pulp",
    "puplisher": "publisher",
    "pupular": "popular",
    "purcahse": "purchase",
    "purchace": "purchase",
    "purchaces": "purchases",
    "purchuse": "purchase",
    "purhase": "purchase",
    "puritannical": "puritanical",
    "purposedly": "purposely",
    "purpotedly": "purportedly",
    "pursuade": "persuade",
    "pursuaded": "persuaded",
    "pursuades": "persuades",
    "pususading": "persuading",
    "puting": "putting",
    "putn": "put",
    "puzzier": "puzzler",
    "pwanage": "pwnage",
    "pwange": "pwnage",
    "pwe": "we",
    "pwease": "please",
    "pwebhost": "wpwebhost",
    "pwer": "power",
    "pwners": "owners",
    "pwnge": "pwnage",
    "pwoer": "power",
    "pwople": "people",
    "pyschedelic": "psychedelic",
    "pyschic": "psychic",
    "pyscho": "psycho",
    "pyschological": "psychological",
    "pyschology": "psychology",
    "pyschosomatic": "psychosomatic",
    "pyscic": "psychic",
    "qame": "game",
    "qames": "games",
    "qare": "are",
    "qave": "gave",
    "qave": "have",
    "qcommercial": "commercial",
    "qe": "e",
    "qet": "get",
    "qet": "set",
    "qettin": "gettin",
    "qetting": "getting",
    "qii": "wii",
    "qirl": "girl",
    "qith": "with",
    "qive": "give",
    "qlad": "glad",
    "qn": "in",
    "qoin": "goin",
    "qoite": "quite",
    "qonna": "gonna",
    "qood": "good",
    "qore": "more",
    "qot": "got",
    "qot": "not",
    "qotta": "gotta",
    "qoutation": "quotation",
    "qoute": "quote",
    "qry": "try",
    "qtweet": "tweet",
    "qtwitter": "twitter",
    "quadrapedal": "quadrupedal",
    "quadrapole": "quadrupole",
    "quadriped": "quadruped",
    "quadripedalism": "quadrupedalism",
    "quadropedal": "quadrupedal",
    "quailty": "quality",
    "qualifaction": "qualification",
    "qualifer": "qualifier",
    "qualifers": "qualifiers",
    "qualifiing": "qualifying",
    "qualifyng": "qualifying",
    "quanity": "quantity",
    "quantative": "quantitative",
    "quantaty": "quantity",
    "quantitiy": "quantity",
    "quarantaine": "quarantine",
    "quarell": "quarrel",
    "quarentine": "quarantine",
    "quartely": "quarterly",
    "quaterback": "quarterback",
    "quaterly": "quarterly",
    "quatermaster": "quartermaster",
    "queastion": "question",
    "queeen": "queen",
    "quesitions": "questions",
    "quesitons": "questions",
    "quess": "guess",
    "questionned": "questioned",
    "questoin": "question",
    "queston": "question",
    "questonable": "questionable",
    "questtion": "question",
    "quetion": "question",
    "quicklyu": "quickly",
    "quietely": "quietly",
    "quik": "quick",
    "quikly": "quickly",
    "quinessential": "quintessential",
    "quinquireme": "quinquereme",
    "quitar": "guitar",
    "quitted": "quit",
    "quizes": "quizzes",
    "qwhy": "why",
    "rabids": "rabbids",
    "rabinnical": "rabbinical",
    "racaus": "raucous",
    "racibg": "racing",
    "radiactive": "radioactive",
    "radient": "radiant",
    "radify": "ratify",
    "radiou": "radio",
    "rady": "ready",
    "raelly": "really",
    "raesort": "resort",
    "raint": "rain",
    "rality": "reality",
    "rankngs": "rankings",
    "ranslate": "translate",
    "ranyone": "anyone",
    "raod": "road",
    "rapple": "apple",
    "rarified": "rarefied",
    "rasied": "raised",
    "rathen": "rather",
    "raymain": "rayman",
    "rcord": "record",
    "rdropbox": "dropbox",
    "rdying": "dying",
    "re-realeased": "re-released",
    "reaader": "reader",
    "reaading": "reading",
    "reaally": "really",
    "reaaly": "really",
    "reacation": "reaction",
    "reaccurring": "recurring",
    "reachs": "reaches",
    "reacing": "reaching",
    "reacll": "recall",
    "reactived": "reactivated",
    "readdy": "ready",
    "readeer": "reader",
    "readinq": "reading",
    "readly": "readily",
    "readmition": "readmission",
    "readr": "reader",
    "readyy": "ready",
    "reaeder": "reader",
    "realease": "release",
    "realeased": "released",
    "realeasing": "releasing",
    "realey": "really",
    "realite": "reality",
    "realitvely": "relatively",
    "realizd": "realized",
    "realizied": "realized",
    "reallity": "reality",
    "reallky": "really",
    "reallly": "really",
    "reallt": "really",
    "reallx": "really",
    "reallyt": "really",
    "reallyy": "really",
    "realsitic": "realistic",
    "realt": "real",
    "realted": "related",
    "realting": "relating",
    "realtion": "relation",
    "realtions": "relations",
    "realtive": "relative",
    "realy": "really",
    "realyl": "really",
    "realyy": "really",
    "realzied": "realized",
    "reamain": "remain",
    "reamin": "remain",
    "reaon": "reason",
    "reaosn": "reason",
    "reasd": "read",
    "reasearch": "research",
    "reaser": "reader",
    "reasion": "reason",
    "reasln": "reason",
    "reasn": "reason",
    "reasoon": "reason",
    "reasses": "reassess",
    "reasson": "reason",
    "reat": "rest",
    "reate": "create",
    "rebiulding": "rebuilding",
    "rebllions": "rebellions",
    "rebounce": "rebound",
    "rebuttle": "rebuttal",
    "recapcha": "recaptcha",
    "recapctha": "recaptcha",
    "recaptacha": "recaptcha",
    "recasted": "recast",
    "reccent": "recent",
    "reccieve": "recieve",
    "reccomend": "recommend",
    "reccomendations": "recommendations",
    "reccomended": "recommended",
    "reccomending": "recommending",
    "reccommend": "recommend",
    "reccommendations": "recommendations",
    "reccommended": "recommended",
    "reccommending": "recommending",
    "reccuring": "recurring",
    "receeded": "receded",
    "receeding": "receding",
    "receieved": "received",
    "receivedfrom": "received from",
    "recentley": "recently",
    "recepient": "recipient",
    "recepients": "recipients",
    "recesion": "recession",
    "recesssion": "recession",
    "recevied": "received",
    "receving": "receiving",
    "rechargable": "rechargeable",
    "reched": "reached",
    "recide": "reside",
    "recided": "resided",
    "recident": "resident",
    "recidents": "residents",
    "reciding": "residing",
    "reciecve": "recieve",
    "reciepe": "recipe",
    "reciepents": "recipients",
    "reciept": "receipt",
    "recieve": "receive",
    "recieved": "received",
    "reciever": "receiver",
    "recievers": "receivers",
    "recieves": "receives",
    "recieving": "receiving",
    "recipent": "recipient",
    "recipiant": "recipient",
    "recipiants": "recipients",
    "recipies": "recipes",
    "recive": "receive",
    "recived": "received",
    "reciver": "recover",
    "recivership": "receivership",
    "recocer": "recover",
    "recogise": "recognise",
    "recogize": "recognize",
    "recoiless": "recoilless",
    "recomend": "recommend",
    "recomendation": "recommendation",
    "recomendations": "recommendations",
    "recomended": "recommended",
    "recomending": "recommending",
    "recomends": "recommends",
    "recommand": "recommend",
    "recommandations": "recommendations",
    "recommedations": "recommendations",
    "recomment": "recommend",
    "recommnd": "recommend",
    "recommnedations": "recommendations",
    "recommondations": "recommendations",
    "recommrnd": "recommend",
    "recompence": "recompense",
    "reconaissance": "reconnaissance",
    "reconcilation": "reconciliation",
    "recongize": "recognize",
    "reconize": "recognize",
    "reconized": "recognized",
    "reconnaisance": "reconnaissance",
    "reconnaissence": "reconnaissance",
    "recontructed": "reconstructed",
    "recordproducer": "record producer",
    "recoreded": "recorded",
    "recouperate": "recuperate",
    "recoverd": "recovered",
    "recoverimg": "recovering",
    "recoveringg": "recovering",
    "recoverying": "recovering",
    "recovvering": "recovering",
    "recquired": "required",
    "recrational": "recreational",
    "recrod": "record",
    "recruted": "recruited",
    "recuiting": "recruiting",
    "recuring": "recurring",
    "recurrance": "recurrence",
    "recuvering": "recovering",
    "reday": "ready",
    "redevelopement": "redevelopment",
    "rediculous": "ridiculous",
    "redue": "reduce",
    "redundent": "redundant",
    "redy": "ready",
    "reead": "read",
    "reeally": "really",
    "reeboot": "reboot",
    "reedeming": "redeeming",
    "reenforced": "reinforced",
    "refect": "reflect",
    "refedendum": "referendum",
    "referal": "referral",
    "referance": "reference",
    "referece": "reference",
    "refereces": "references",
    "refered": "referred",
    "referemce": "reference",
    "referemces": "references",
    "referencs": "references",
    "referenece": "reference",
    "refereneced": "referenced",
    "refereneces": "references",
    "referes": "refers",
    "referiang": "referring",
    "refering": "referring",
    "refernce": "reference",
    "refernce": "references",
    "refernces": "references",
    "refernece": "reference",
    "referr": "refer",
    "referrence": "reference",
    "referrences": "references",
    "referrring": "referring",
    "referrs": "refers",
    "reffered": "referred",
    "refference": "reference",
    "reffering": "referring",
    "refferr": "refer",
    "reforce": "reinforce",
    "refrence": "reference",
    "refrences": "references",
    "refrers": "refers",
    "refridgeration": "refrigeration",
    "refridgerator": "refrigerator",
    "refrom": "reform",
    "refromist": "reformist",
    "refue": "refuse",
    "refular": "regular",
    "refusla": "refusal",
    "regardes": "regards",
    "reggular": "regular",
    "regioster": "register",
    "registeration": "registration",
    "registerd": "registered",
    "registery": "registry",
    "regluar": "regular",
    "regualar": "regular",
    "regualr": "regular",
    "reguarding": "regarding",
    "reguarly": "regularly",
    "regulaion": "regulation",
    "regulaotrs": "regulators",
    "regularily": "regularly",
    "regulart": "regular",
    "regulary": "regularly",
    "rehersal": "rehearsal",
    "reherse": "rehearse",
    "reially": "really",
    "reicarnation": "reincarnation",
    "reigining": "reigning",
    "reinact": "reenact",
    "reinds": "reminds",
    "rejcted": "rejected",
    "reknown": "renown",
    "reknowned": "renowned",
    "rela": "real",
    "relagated": "relegated",
    "relagation": "relegation",
    "relaized": "realized",
    "relalised": "realised",
    "relaly": "really",
    "relase": "release",
    "relased": "released",
    "relatiopnship": "relationship",
    "relativley": "relatively",
    "relativly": "relatively",
    "relavent": "relevant",
    "releast": "release",
    "releave": "relieve",
    "relected": "reelected",
    "releif": "relief",
    "releive": "relieve",
    "releived": "relieved",
    "releiver": "reliever",
    "relese": "release",
    "releses": "releases",
    "reletive": "relative",
    "relevence": "relevance",
    "relevent": "relevant",
    "reley": "rely",
    "reliablity": "reliability",
    "relience": "reliance",
    "relient": "reliant",
    "religeous": "religious",
    "religon": "religion",
    "religous": "religious",
    "religously": "religiously",
    "relinqushment": "relinquishment",
    "relised": "realised",
    "relitavely": "relatively",
    "relitively": "relatively",
    "relize": "realize",
    "relized": "realized",
    "relm": "realm",
    "relpacement": "replacement",
    "remaing": "remaining",
    "remainging": "remaining",
    "remanants": "remnants",
    "remaning": "remaining",
    "rember": "remember",
    "remeber": "remember",
    "remebered": "remembered",
    "remeidy": "remedy",
    "rememberable": "memorable",
    "rememberance": "remembrance",
    "remembr": "remember",
    "remembrence": "remembrance",
    "rememeber": "remember",
    "rememvbered": "remembered",
    "remenant": "remnant",
    "remenicent": "reminiscent",
    "remian": "remain",
    "reminent": "remnant",
    "reminescent": "reminiscent",
    "reminicent": "reminiscent",
    "reminiding": "reminding",
    "reminscent": "reminiscent",
    "reminsicent": "reminiscent",
    "remiond": "remind",
    "remmber": "remember",
    "remore": "remote",
    "remotly": "remotely",
    "rendevous": "rendezvous",
    "rendezous": "rendezvous",
    "renedered": "rende",
    "renewl": "renewal",
    "reninds": "reminds",
    "rennovate": "renovate",
    "rennovated": "renovated",
    "rennovating": "renovating",
    "rennovation": "renovation",
    "renound": "renowned",
    "renouned": "renowned",
    "renowed": "renowned",
    "rentors": "renters",
    "reoccurrence": "recurrence",
    "reomved": "removed",
    "reorganision": "reorganisation",
    "repalace": "replace",
    "repayed": "repaid",
    "repblic": "republic",
    "repblican": "republican",
    "repblicans": "republicans",
    "repblics": "republics",
    "repeatly": "repeatedly",
    "repected": "respected",
    "repectively": "respectively",
    "repeition": "repetition",
    "repeled": "repelled",
    "repell": "repel",
    "repentence": "repentance",
    "repentent": "repentant",
    "repertoir": "repertoire",
    "repeteadly": "repeatedly",
    "repetion": "repetition",
    "repetive": "repetitive",
    "repetoire": "repertoire",
    "repid": "rapid",
    "repitition": "repetition",
    "replaceing": "replacing",
    "replacemant": "replacement",
    "replecement": "replacement",
    "reponse": "response",
    "reponsible": "responsible",
    "reportably": "reportedly",
    "reportadly": "reportedly",
    "reportd": "reported",
    "reporteda": "reported",
    "reportng": "reporting",
    "represantative": "representative",
    "represenative": "representative",
    "representate": "represent",
    "representitive": "representative",
    "representive": "representative",
    "representives": "representatives",
    "reproducable": "reproducible",
    "reprtoire": "repertoire",
    "reprts": "reports",
    "repsectively": "respectively",
    "repsonse": "response",
    "reptition": "repetition",
    "repubic": "republic",
    "repubican": "republican",
    "repubicans": "republicans",
    "repubics": "republics",
    "republi": "republic",
    "republian": "republican",
    "republians": "republicans",
    "republis": "republics",
    "repulic": "republic",
    "repulican": "republican",
    "repulicans": "republicans",
    "repulics": "republics",
    "reputatin": "reputation",
    "reqadies": "readies",
    "requast": "request",
    "requestd": "requested",
    "requestet": "requested",
    "requiered": "required",
    "requirment": "requirement",
    "reqular": "regular",
    "requred": "required",
    "resataurant": "restaurant",
    "resaurant": "restaurant",
    "rescure": "rescue",
    "rescuse": "rescue",
    "resembelance": "resemblance",
    "resembes": "resembles",
    "resemblence": "resemblance",
    "reserach": "research",
    "resest": "reset",
    "reseult": "result",
    "resevoir": "reservoir",
    "residance": "residence",
    "residant": "resident",
    "residental": "residential",
    "resignement": "resignment",
    "resistable": "resistible",
    "resistence": "resistance",
    "resistent": "resistant",
    "reslease": "release",
    "reslts": "results",
    "reson": "reason",
    "resored": "restored",
    "resorta": "resort",
    "resotre": "restore",
    "resoure": "resource",
    "resourse": "resource",
    "respectivley": "respectively",
    "respectivly": "respectively",
    "resperatory": "respiratory",
    "respitatory": "respiratory",
    "responce": "response",
    "responibilities": "responsibilities",
    "responibility": "responsibility",
    "responisble": "responsible",
    "responnsibilty": "responsibility",
    "responsability": "responsibility",
    "responsed": "responded",
    "responsibile": "responsible",
    "responsibilites": "responsibilities",
    "responsibilty": "responsibility",
    "responsiblities": "responsibilities",
    "responsiblity": "responsibility",
    "resport": "resort",
    "resposibility": "responsibility",
    "resposible": "responsible",
    "resquest": "request",
    "resrt": "resort",
    "ressemblance": "resemblance",
    "ressemble": "resemble",
    "ressembled": "resembled",
    "ressemblence": "resemblance",
    "ressembling": "resembling",
    "resson": "reason",
    "resssurecting": "resurrecting",
    "ressurect": "resurrect",
    "ressurected": "resurrected",
    "ressurection": "resurrection",
    "ressurrection": "resurrection",
    "restarant": "restaurant",
    "restarants": "restaurants",
    "restaraunt": "restaurant",
    "restaraunteur": "restaurateur",
    "restaraunteurs": "restaurateurs",
    "restaraunts": "restaurants",
    "restauranteurs": "restaurateurs",
    "restauration": "restoration",
    "restauraunt": "restaurant",
    "resteraunt": "restaurant",
    "resteraunts": "restaurants",
    "resticted": "restricted",
    "restorant": "restaurant",
    "restoreing": "restoring",
    "restration": "restoration",
    "restuarant": "restaurant",
    "resturant": "restaurant",
    "resturants": "restaurants",
    "resturaunt": "restaurant",
    "resturaunts": "restaurants",
    "resurect": "resurrect",
    "resurecting": "resurrecting",
    "resurgance": "resurgence",
    "resutls": "results",
    "resuts": "results",
    "retailation": "retaliation",
    "retalitated": "retaliated",
    "retalitation": "retaliation",
    "rething": "rethink",
    "rethoric": "rhetoric",
    "retoring": "restoring",
    "retreive": "retrieve",
    "retreived": "retrieve",
    "retrive": "retrieve",
    "retruning": "returning",
    "retured": "returned",
    "returing": "returning",
    "returnd": "returned",
    "retweting": "retweeting",
    "reular": "regular",
    "reults": "results",
    "revaluated": "reevaluated",
    "reveived": "received",
    "reveiw": "review",
    "revelant": "relevant",
    "reveral": "reversal",
    "reverance": "reverence",
    "reverand": "reverend",
    "reverese": "reverse",
    "reversable": "reversible",
    "revew": "review",
    "revieew": "review",
    "revolotion": "revolution",
    "revoloution": "revolution",
    "revolutionar": "revolutionary",
    "revovering": "recovering",
    "rewiew": "review",
    "rewitten": "rewritten",
    "rewriet": "rewrite",
    "rference": "reference",
    "rferences": "references",
    "rght": "right",
    "rhan": "than",
    "rhapsdy": "rhapsody",
    "rhit": "hit",
    "rhought": "thought",
    "rhymme": "rhyme",
    "rhythem": "rhythm",
    "rhythim": "rhythm",
    "rhythym": "rhythm",
    "rhytm": "rhythm",
    "rhytmic": "rhythmic",
    "richtor": "richter",
    "ricter": "richter",
    "ricther": "richter",
    "riden": "ridden",
    "riden": "ride",
    "riends": "friends",
    "rightous": "righteous",
    "rightt": "right",
    "rigntones": "ringtones",
    "rigourous": "rigorous",
    "rigt": "right",
    "rigth": "right",
    "riight": "right",
    "riite": "rite",
    "ringone": "ringtone",
    "ringotones": "ringtones",
    "ringtines": "ringtones",
    "ringtonea": "ringtones",
    "ringtunes": "ringtones",
    "rininging": "ringing",
    "riqht": "right",
    "riting": "writing",
    "rivarly": "rivalry",
    "rjust": "just",
    "rlz": "plz",
    "rmaps": "maps",
    "rmember": "remember",
    "roasd": "road",
    "rochocinco": "ochocinco",
    "rocj": "rock",
    "rockbank": "rockband",
    "rocketsu": "rockets",
    "rockk": "rock",
    "rockss": "rocks",
    "rockt": "rocks",
    "rococco": "rococo",
    "rocord": "record",
    "romatic": "romantic",
    "rongtone": "ringtone",
    "roomate": "roommate",
    "rooom": "room",
    "rougly": "roughly",
    "rouncd": "round",
    "rounf": "round",
    "royalites": "royalties",
    "royalities": "royalties",
    "royality": "royalty",
    "rreader": "reader",
    "rtbots": "robots",
    "rthe": "the",
    "rtweet": "retweet",
    "rty": "rt",
    "rubert": "rupert",
    "rucuperate": "recuperate",
    "rudimentatry": "rudimentary",
    "rugular": "regular",
    "rulle": "rule",
    "rulles": "rules",
    "runing": "running",
    "runining": "running",
    "runnig": "running",
    "runnng": "running",
    "runnning": "running",
    "runnung": "running",
    "rurns": "turns",
    "rushs": "rushes",
    "russina": "Russian",
    "rweally": "really",
    "rwite": "write",
    "ryt": "rt",
    "rythem": "rhythm",
    "rythim": "rhythm",
    "rythm": "rhythm",
    "rythmic": "rhythmic",
    "rythum": "rhythm",
    "rythym": "rhythm",
    "rythyms": "rhythms",
    "sabatical": "sabbatical",
    "sacared": "scared",
    "sacrafice": "sacrifice",
    "sacreligious": "sacrilegious",
    "sacrifical": "sacrificial",
    "safarai": "safari",
    "safegaurd": "safeguard",
    "safley": "safely",
    "saftey": "safety",
    "safty": "safety",
    "sahot": "shot",
    "saidd": "said",
    "saiid": "said",
    "saince": "since",
    "saleman": "salesman",
    "saleries": "salaries",
    "salery": "salary",
    "samao": "samoa",
    "samoha": "samoa",
    "samona": "samoa",
    "samoo": "samoa",
    "samual": "samuel",
    "sanatizer": "sanitizer",
    "sanctionning": "sanctioning",
    "sancutary": "sanctuary",
    "sandox": "sandbox",
    "sandwhich": "sandwich",
    "sanitizeer": "sanitizer",
    "sanitzer": "sanitizer",
    "santioned": "sanctioned",
    "santitizer": "sanitizer",
    "santizer": "sanitizer",
    "santuary": "sanctuary",
    "sanyjay": "sanjay",
    "sargant": "sergeant",
    "sargeant": "sergeant",
    "sarted": "started",
    "sarting": "starting",
    "sasonal": "seasonal",
    "sasve": "save",
    "satalite": "satellite",
    "satarize": "satirize",
    "satelite": "satellite",
    "satelites": "satellites",
    "satisfactority": "satisfactorily",
    "satric": "satiric",
    "satrical": "satirical",
    "satrically": "satirically",
    "sattelite": "satellite",
    "sattelites": "satellites",
    "saught": "sought",
    "saveing": "saving",
    "savy": "savvy",
    "sawg": "swag",
    "saxaphone": "saxophone",
    "sayi": "say",
    "sayig": "saying",
    "sayimg": "saying",
    "sayss": "says",
    "sayy": "says",
    "sayz": "says",
    "sbould": "should",
    "sbrin": "brin",
    "scaared": "scared",
    "scaleable": "scalable",
    "scandanavia": "Scandinavia",
    "scaned": "scanned",
    "scaner": "scanner",
    "scaredd": "scared",
    "scarep": "scared",
    "scaricity": "scarcity",
    "scavanged": "scavenged",
    "sceen": "screen",
    "scenerio": "scenario",
    "schedual": "schedule",
    "scheduel": "schedule",
    "schhol": "school",
    "schhool": "school",
    "schillr": "schiller",
    "schimdt": "schmidt",
    "scholarhip": "scholarship",
    "schooll": "school",
    "schoool": "school",
    "schould": "should",
    "scientfic": "scientific",
    "scientifc": "scientific",
    "scientis": "scientist",
    "scik": "sick",
    "scince": "science",
    "scince": "since",
    "scinece": "science",
    "scirpt": "script",
    "sckool": "school",
    "scmidt": "schmidt",
    "scoll": "scroll",
    "scool": "school",
    "screan": "screen",
    "screeenshot": "screenshot",
    "screem": "screen",
    "screenr": "screen",
    "screenshopt": "screenshot",
    "screenwrighter": "screenwriter",
    "screne": "screen",
    "scrutinity": "scrutiny",
    "sculpter": "sculptor",
    "scupture": "sculpture",
    "scuptures": "sculptures",
    "scured": "scared",
    "sdiewiki": "sidewiki",
    "sdore": "sore",
    "seaaon": "season",
    "seaasonal": "seasonal",
    "seach": "search",
    "seached": "searched",
    "seaches": "searches",
    "seacrh": "search",
    "seamingly": "seemingly",
    "seaon": "season",
    "seaonal": "seasonal",
    "seaoson": "season",
    "searach": "search",
    "searcg": "search",
    "searchd": "search",
    "searchingg": "searching",
    "searchs": "searches",
    "searcjed": "searched",
    "searck": "search",
    "searh": "search",
    "searhing": "searching",
    "searies": "series",
    "seasame": "sesame",
    "seaseon": "season",
    "seasion": "season",
    "seasme": "sesame",
    "seasn": "season",
    "seasnal": "seasonal",
    "seasoal": "seasonal",
    "seasom": "season",
    "seasonall": "seasonal",
    "seasonaly": "seasonally",
    "seasonl": "seasonal",
    "seasrch": "search",
    "seasson": "season",
    "seaszon": "season",
    "seccesion": "secession",
    "secod": "second",
    "secondry": "secondary",
    "secong": "second",
    "secound": "second",
    "secratary": "secretary",
    "secrect": "secret",
    "secretery": "secretary",
    "secundary": "secondary",
    "securites": "securities",
    "sedantary": "sedentary",
    "sedatative": "sedative",
    "sedereal": "sidereal",
    "sedning": "sending",
    "seear": "swear",
    "seee": "see",
    "seeems": "seems",
    "seeen": "seen",
    "seeiing": "seeing",
    "seeked": "sought",
    "seens": "seems",
    "seeoms": "seems",
    "seeu": "see",
    "segementation": "segmentation",
    "seguoys": "segues",
    "seige": "siege",
    "seing": "being",
    "seing": "seeing",
    "seinor": "senior",
    "seires": "series",
    "seirious": "serious",
    "sejt": "sent",
    "selction": "selection",
    "seldomly": "seldom",
    "selebes": "celebes",
    "seling": "selling",
    "sellign": "selling",
    "sellingq": "selling",
    "sellling": "selling",
    "selln": "sell",
    "sellnig": "selling",
    "semblence": "semblance",
    "semoa": "samoa",
    "semptoms": "symptoms",
    "senarios": "scenarios",
    "senc": "send",
    "sendd": "send",
    "sendig": "sending",
    "sendn": "send",
    "sendng": "sending",
    "sendt": "sent",
    "sendy": "send",
    "senoir": "senior",
    "senstive": "sensitive",
    "sensure": "censure",
    "sentance": "sentence",
    "seoing": "seeing",
    "separatley": "separately",
    "seper": "super",
    "seperable": "separable",
    "seperate": "separate",
    "seperated": "separated",
    "seperately": "separately",
    "seperates": "separates",
    "seperating": "separating",
    "seperation": "separation",
    "seperatism": "separatism",
    "seperatist": "separatist",
    "sepina": "subpoena",
    "sequencial": "sequential",
    "serach": "search",
    "seraches": "searches",
    "seraching": "searching",
    "serch": "search",
    "serched": "searched",
    "serches": "searches",
    "serems": "seems",
    "sergent": "sergeant",
    "sergy": "sergey",
    "serieses": "series",
    "seriogs": "serious",
    "seriosly": "seriously",
    "seriosuly": "seriously",
    "serivce": "service",
    "servival": "survival",
    "servived": "survived",
    "seson": "season",
    "sesonal": "seasonal",
    "sessages": "messages",
    "settelement": "settlement",
    "setteler": "settler",
    "settelment": "settlement",
    "settelments": "settlements",
    "settlment": "settlement",
    "setttings": "settings",
    "setuff": "stuff",
    "severeal": "several",
    "severley": "severely",
    "severly": "severely",
    "sevice": "service",
    "sevral": "several",
    "sewine": "swine",
    "sflu": "flu",
    "shaby": "shabby",
    "shadasloo": "shadaloo",
    "shaddow": "shadow",
    "shadoloo": "shadaloo",
    "sheck": "check",
    "shedual": "schedule",
    "shedule": "schedule",
    "sheild": "shield",
    "sherif": "sheriff",
    "shetchbook": "sketchbook",
    "shiat": "shit",
    "shiet": "shit",
    "shiit": "shit",
    "shince": "since",
    "shineing": "shining",
    "shiney": "shiny",
    "shiped": "shipped",
    "shiping": "shipping",
    "shitt": "shit",
    "shitz": "shit",
    "shoild": "should",
    "sholud": "should",
    "sholuld": "should",
    "shoping": "shopping",
    "shopkeeepers": "shopkeepers",
    "shorly": "shortly",
    "shortwhile": "short while",
    "shost": "shot",
    "shotage": "shortage",
    "shotd": "shots",
    "shotr": "shot",
    "shotsa": "shots",
    "shoty": "shot",
    "shotz": "shot",
    "shoudl": "should",
    "shoudln": "should",
    "shouid": "should",
    "shoukd": "should",
    "shoukld": "should",
    "shoula": "shoulda",
    "shouldd": "should",
    "shouldda": "shoulda",
    "shouldnt": "should not",
    "shouldv": "should",
    "shoulf": "should",
    "shoulg": "should",
    "shouold": "should",
    "shouw": "show",
    "shre": "share",
    "shreak": "shriek",
    "shrewed": "shrewd",
    "shrinked": "shrunk",
    "shrome": "chrome",
    "shrt": "short",
    "shrtage": "shortage",
    "shtt": "shot",
    "shuff": "stuff",
    "shuffel": "shuffle",
    "shuold": "should",
    "shwine": "swine",
    "shwo": "show",
    "shxt": "shot",
    "shyt": "shot",
    "sicc": "sick",
    "sicka": "sick",
    "sickk": "sick",
    "sicne": "since",
    "sideral": "sidereal",
    "siderwiki": "sidewiki",
    "sidewicki": "sidewiki",
    "sidewike": "sidewiki",
    "sidewikik": "sidewiki",
    "sidewikki": "sidewiki",
    "sidwiki": "sidewiki",
    "siesmic": "seismic",
    "siezure": "seizure",
    "siezures": "seizures",
    "sigend": "signed",
    "sighn": "sign",
    "sighned": "signed",
    "siginificant": "significant",
    "signd": "sign",
    "signd": "signed",
    "signficant": "significant",
    "signficiant": "significant",
    "signfies": "signifies",
    "signifantly": "significantly",
    "significently": "significantly",
    "signifigant": "significant",
    "signifigantly": "significantly",
    "signitories": "signatories",
    "signitory": "signatory",
    "signiture": "signature",
    "signt": "sign",
    "signu": "sign",
    "siick": "sick",
    "siiting": "sitting",
    "sikewiki": "sidewiki",
    "sikk": "sick",
    "silimar": "similar",
    "simiar": "similar",
    "similair": "similar",
    "similarily": "similarly",
    "similiar": "similar",
    "similiarity": "similarity",
    "similiarly": "similarly",
    "simillar": "similar",
    "simliar": "similar",
    "simmilar": "similar",
    "simmilarly": "similarly",
    "simpletweet": "simplytweet",
    "simpley": "simply",
    "simplier": "simpler",
    "simpliest": "simplest",
    "simptom": "symptom",
    "simptoms": "symptoms",
    "simultanous": "simultaneous",
    "simultanously": "simultaneously",
    "sincerley": "sincerely",
    "single-handily": "single-handedly",
    "singlepayer": "isinglepayer",
    "singsog": "singsong",
    "sinple": "simple",
    "sinuse": "sinus",
    "sirus": "virus",
    "sissors": "scissors",
    "siter": "sister",
    "sitewiki": "sidewiki",
    "sitiing": "sitting",
    "sitll": "still",
    "sitn": "site",
    "sittig": "sitting",
    "sittiing": "sitting",
    "sittng": "sitting",
    "sittting": "sitting",
    "siwne": "swine",
    "sixk": "sick",
    "siy": "sky",
    "sjould": "should",
    "skateing": "skating",
    "skecth": "sketch",
    "sketcuup": "sketchup",
    "skiied": "skied",
    "skiier": "skier",
    "skpye": "skype",
    "slaugterhouses": "slaughterhouses",
    "sleeep": "sleep",
    "sleepng": "sleeping",
    "slighly": "slightly",
    "slippy": "slippery",
    "sllep": "sleep",
    "slove": "love",
    "sloww": "slow",
    "slowy": "slowly",
    "slwine": "swine",
    "smae": "same",
    "smah": "smash",
    "smaill": "small",
    "smaking": "making",
    "smaler": "smaller",
    "smealting": "smelting",
    "smeone": "someone",
    "smewhere": "somewhere",
    "smim": "slim",
    "smll": "small",
    "smmer": "summer",
    "smoe": "some",
    "smrtphone": "smartphone",
    "sneding": "sending",
    "sneeezed": "sneezed",
    "sneeks": "sneaks",
    "snese": "sneeze",
    "snorkle": "snorkel",
    "snoy": "snow",
    "snta": "santa",
    "snyc": "sync",
    "snycing": "syncing",
    "socalism": "socialism",
    "socities": "societies",
    "soem": "some",
    "soemone": "someone",
    "soemthing": "something",
    "sofaa": "sofa",
    "sofware": "software",
    "sohuld": "should",
    "sohw": "show",
    "soild": "solid",
    "soilders": "soldiers",
    "solatary": "solitary",
    "soley": "solely",
    "soliders": "soldiers",
    "solidier": "soldier",
    "soliliquy": "soliloquy",
    "sollid": "solid",
    "sollution": "solution",
    "soluable": "soluble",
    "somebdy": "somebody",
    "somebidy": "somebody",
    "somehting": "something",
    "somemone": "someone",
    "somene": "someone",
    "somenone": "someone",
    "someoe": "someone",
    "someoen": "someone",
    "someome": "someone",
    "somes": "comes",
    "somet": "some",
    "somethig": "something",
    "somethign": "something",
    "somethingg": "something",
    "somethinng": "something",
    "somethinq": "something",
    "somethng": "something",
    "somm": "some",
    "somngs": "songs",
    "somoa": "samoa",
    "somoan": "samoan",
    "somone": "someone",
    "somtimes": "sometimes",
    "somwhere": "somewhere",
    "sonce": "since",
    "sonds": "sounds",
    "soneone": "someone",
    "songwritter": "songwriter",
    "songz": "songs",
    "soninc": "sonic",
    "sont": "dont",
    "soom": "soon",
    "soome": "some",
    "soons": "soon",
    "soood": "sooo",
    "soooi": "sooo",
    "sooon": "soon",
    "sooool": "soooo",
    "soore": "sore",
    "soory": "sorry",
    "sophicated": "sophisticated",
    "sophmore": "sophomore",
    "soprry": "sorry",
    "sorce": "sore",
    "sorceror": "sorcerer",
    "sorrounding": "surrounding",
    "sotre": "store",
    "sotry": "story",
    "souch": "such",
    "soudn": "sound",
    "soudns": "sounds",
    "souind": "sound",
    "sould": "would",
    "souly": "solely",
    "soundtack": "soundtrack",
    "soundz": "sounds",
    "sountrack": "soundtrack",
    "sounz": "sound",
    "sourh": "south",
    "sourth": "south",
    "sourthern": "southern",
    "southheast": "southeast",
    "souvenier": "souvenir",
    "souveniers": "souvenirs",
    "soveits": "soviets",
    "sovereignity": "sovereignty",
    "soverign": "sovereign",
    "soverignity": "sovereignty",
    "soverignty": "sovereignty",
    "sownloaded": "downloaded",
    "spagetti": "spaghetti",
    "spainiard": "Spaniard",
    "spainish": "Spanish",
    "spaish": "spanish",
    "sparcely": "sparsely",
    "sparsley": "sparsely",
    "sparsly": "sparsely",
    "spart": "part",
    "speach": "speech",
    "speachless": "speechless",
    "speacial": "special",
    "speack": "speak",
    "spead": "spread",
    "speading": "spreading",
    "speaka": "speak",
    "speakk": "speak",
    "specator": "spectator",
    "specfic": "specific",
    "spech": "speech",
    "specialites": "specialities",
    "specialtes": "specialties",
    "speciemen": "specimen",
    "specificaly": "specifically",
    "specifiying": "specifying",
    "speciman": "specimen",
    "spectauclar": "spectacular",
    "spectaulars": "spectaculars",
    "spectometry": "spectrometry",
    "spectum": "spectrum",
    "speechs": "speeches",
    "speeker": "speaker",
    "speen": "speed",
    "speical": "special",
    "speices": "species",
    "speling": "spelling",
    "spended": "spent",
    "spendour": "splendour",
    "spermatazoa": "spermatozoa",
    "spermatazoon": "spermatozoon",
    "spermatozoan": "spermatozoon",
    "spftware": "software",
    "spilts": "splits",
    "splited": "split",
    "spliting": "splitting",
    "spmething": "something",
    "spoace": "space",
    "spoarts": "sports",
    "spokeman": "spokesman",
    "spokemen": "spokesmen",
    "spokeperson": "spokesperson",
    "spokewoman": "spokeswoman",
    "sponser": "sponsor",
    "sponsered": "sponsored",
    "spontanious": "spontaneous",
    "spontanous": "spontaneous",
    "sponzored": "sponsored",
    "spoonfulls": "spoonfuls",
    "spoorts": "sports",
    "sporatic": "sporadic",
    "sporify": "spotify",
    "sporst": "sports",
    "sportss": "sports",
    "sportys": "sports",
    "sportz": "sports",
    "spoted": "spotted",
    "spouce": "spouse",
    "sppeches": "speeches",
    "sppose": "suppose",
    "spprts": "sports",
    "spreaded": "spread",
    "spreadint": "spreading",
    "spreadn": "spread",
    "spreaing": "spreading",
    "sprech": "speech",
    "spred": "spread",
    "spreeding": "spreading",
    "sprial": "spiral",
    "spriritual": "spiritual",
    "spritual": "spiritual",
    "sprot": "sport",
    "sprots": "sports",
    "spunoff": "spun off",
    "sqaud": "squad",
    "sqaure": "square",
    "sqine": "swine",
    "squard": "squared",
    "sranding": "standing",
    "sreading": "spreading",
    "sreads": "spreads",
    "sreen": "screen",
    "sreet": "street",
    "srory": "story",
    "srry": "sorry",
    "srtikes": "strikes",
    "sruck": "struck",
    "ssearch": "search",
    "ssee": "see",
    "ssend": "send",
    "ssooo": "sooo",
    "ssounds": "sounds",
    "sstill": "still",
    "sstupid": "stupid",
    "sswine": "swine",
    "staart": "start",
    "stabalize": "stabilize",
    "stabalizer": "stabilizer",
    "stabed": "stabbed",
    "stabilty": "stability",
    "stablility": "stability",
    "stablity": "stability",
    "stady": "stay",
    "staet": "start",
    "stagnet": "stagnant",
    "stainlees": "stainless",
    "staion": "station",
    "stallwart": "stalwart",
    "standardz": "standards",
    "standars": "standards",
    "standart": "standard",
    "stange": "strange",
    "starb": "start",
    "starbukcs": "starbucks",
    "startbucks": "starbucks",
    "startd": "started",
    "startegic": "strategic",
    "startegies": "strategies",
    "startegy": "strategy",
    "starthing": "starting",
    "startign": "starting",
    "startinq": "starting",
    "startn": "start",
    "startng": "starting",
    "startt": "start",
    "starz": "start",
    "stastical": "statistical",
    "statbucks": "starbucks",
    "stategic": "strategic",
    "stateman": "statesman",
    "statememts": "statements",
    "statment": "statement",
    "statuatory": "statutory",
    "staty": "stay",
    "stayes": "stays",
    "stayn": "stay",
    "stcks": "sticks",
    "stdents": "students",
    "stdney": "sydney",
    "steet": "street",
    "steets": "streets",
    "steetview": "streetview",
    "stemed": "stemmed",
    "steped": "stepped",
    "steriod": "steroid",
    "steriods": "steroids",
    "sterotypes": "stereotypes",
    "sthere": "there",
    "sthing": "thing",
    "stiil": "still",
    "stiill": "still",
    "stilk": "still",
    "stilll": "still",
    "stils": "still",
    "stilus": "stylus",
    "stingent": "stringent",
    "stinked": "stunk",
    "stipidest": "stupidest",
    "stiring": "stirring",
    "stirkes": "strikes",
    "stirrs": "stirs",
    "stll": "still",
    "stlupid": "stupid",
    "stlye": "style",
    "stngs": "songs",
    "stoach": "stomach",
    "stomace": "stomach",
    "stomache": "stomach",
    "stomah": "stomach",
    "stomch": "stomach",
    "stomich": "stomach",
    "stommach": "stomach",
    "stomuch": "stomach",
    "stong": "strong",
    "stopp": "stop",
    "stopre": "store",
    "stopry": "story",
    "storeis": "stories",
    "storise": "stories",
    "storn": "storm",
    "stornegst": "strongest",
    "storng": "strong",
    "stoumach": "stomach",
    "stoyr": "story",
    "stpo": "stop",
    "stps": "steps",
    "stradegies": "strategies",
    "stradegy": "strategy",
    "straght": "straight",
    "stran": "strain",
    "strangly": "strangely",
    "straon": "strain",
    "stratagically": "strategically",
    "stratedgy": "strategy",
    "stread": "spread",
    "streading": "spreading",
    "streap": "strep",
    "streeet": "street",
    "streemlining": "streamlining",
    "streetsview": "streetview",
    "streetveiw": "streetview",
    "streeview": "streetview",
    "stregth": "strength",
    "strenghen": "strengthen",
    "strenghened": "strengthened",
    "strenghening": "strengthening",
    "strenght": "strength",
    "strenghten": "strengthen",
    "strenghtened": "strengthened",
    "strenghtening": "strengthening",
    "strengtened": "strengthened",
    "strenous": "strenuous",
    "strepp": "strep",
    "strept": "strep",
    "stret": "street",
    "stretet": "street",
    "stricly": "strictly",
    "strictist": "strictest",
    "stright": "straight",
    "strikely": "strikingly",
    "strnad": "strand",
    "strng": "strong",
    "strore": "store",
    "strret": "street",
    "strt": "start",
    "strucks": "struck",
    "structer": "structure",
    "structual": "structural",
    "structue": "structure",
    "structuraly": "structurally",
    "strugging": "struggling",
    "struggleing": "struggling",
    "strugling": "struggling",
    "stste": "state",
    "sttill": "still",
    "sttlement": "settlement",
    "stubborness": "stubbornness",
    "stuch": "stuck",
    "stucked": "stuck",
    "stucture": "structure",
    "stuctured": "structured",
    "studdy": "study",
    "studends": "students",
    "studing": "studying",
    "studioi": "studio",
    "studyy": "study",
    "stuf": "stuff",
    "stuggle": "struggle",
    "stuggling": "struggling",
    "stumach": "stomach",
    "stupud": "stupid",
    "sturcture": "structure",
    "stuuf": "stuff",
    "stya": "stay",
    "subcatagories": "subcategories",
    "subcatagory": "subcategory",
    "subceptible": "susceptible",
    "subconsiously": "subconsciously",
    "subcribe": "subscribe",
    "subesquent": "subsequent",
    "subjudgation": "subjugation",
    "submachne": "submachine",
    "submision": "submission",
    "submited": "submitted",
    "submiting": "submitting",
    "submitt": "submit",
    "subpecies": "subspecies",
    "subquent": "subsequent",
    "subsdiary": "subsidiary",
    "subsidary": "subsidiary",
    "subsidesu": "subsides",
    "subsiduary": "subsidiary",
    "subsitute": "substitute",
    "subsquent": "subsequent",
    "subsquently": "subsequently",
    "substace": "substance",
    "substain": "sustain",
    "substancial": "substantial",
    "substanial": "substantial",
    "substantually": "substantially",
    "substatial": "substantial",
    "substituded": "substituted",
    "substitue": "substitute",
    "substract": "subtract",
    "substracted": "subtracted",
    "substracting": "subtracting",
    "substraction": "subtraction",
    "substracts": "subtracts",
    "subtances": "substances",
    "subterranian": "subterranean",
    "subtley": "subtly",
    "suburburban": "suburban",
    "succceeded": "succeeded",
    "succcesses": "successes",
    "succedded": "succeeded",
    "succeded": "succeeded",
    "succeds": "succeeds",
    "succeedes": "succeeds",
    "succeptibility": "susceptibility",
    "succeptible": "susceptible",
    "succes": "success",
    "succesful": "successful",
    "succesfull": "successful",
    "succesfully": "successfully",
    "succesfuly": "successfully",
    "succesion": "succession",
    "succesive": "successive",
    "succesor": "successor",
    "successer": "successor",
    "successfull": "successful",
    "successully": "successfully",
    "succombed": "succumbed",
    "succsess": "success",
    "succsessfull": "successful",
    "succum": "succumb",
    "succumed": "succumbed",
    "suceed": "succeed",
    "suceeded": "succeeded",
    "suceeding": "succeeding",
    "suceeds": "succeeds",
    "suceptibility": "susceptibility",
    "suceptible": "susceptible",
    "sucesful": "successful",
    "sucesfully": "successfully",
    "sucesfuly": "successfully",
    "sucesion": "succession",
    "sucess": "success",
    "sucesses": "successes",
    "sucessful": "successful",
    "sucessfull": "successful",
    "sucessfully": "successfully",
    "sucessfuly": "successfully",
    "sucession": "succession",
    "sucessive": "successive",
    "sucessor": "successor",
    "sucessot": "successor",
    "suchh": "such",
    "sucide": "suicide",
    "sucidegirls": "suicidegirls",
    "sucidial": "suicidal",
    "suckas": "sucks",
    "sucksd": "sucks",
    "suckss": "sucks",
    "suckz": "sucks",
    "sucsessor": "successor",
    "suddendly": "suddenly",
    "suddon": "sudden",
    "sudent": "student",
    "sudents": "students",
    "sudgest": "suggest",
    "suea": "sues",
    "sueing": "suing",
    "suface": "surface",
    "sufering": "suffering",
    "suffcient": "sufficient",
    "suffciently": "sufficiently",
    "sufferage": "suffrage",
    "sufferng": "suffering",
    "sufferred": "suffered",
    "sufferring": "suffering",
    "sufficant": "sufficient",
    "sufficent": "sufficient",
    "sufficently": "sufficiently",
    "sufficiant": "sufficient",
    "suffle": "shuffle",
    "sufing": "surfing",
    "sugah": "sugar",
    "sugest": "suggest",
    "suggestiong": "suggestions",
    "sugget": "suggest",
    "suggst": "suggest",
    "suiciidegirls": "suicidegirls",
    "suject": "subject",
    "sumary": "summary",
    "sumatrai": "sumatra",
    "sumbitted": "submitted",
    "sumoa": "samoa",
    "sumptoms": "symptoms",
    "sumptous": "sumptuous",
    "sumtra": "sumatra",
    "sunch": "lunch",
    "sundtrack": "soundtrack",
    "sunglases": "sunglasses",
    "sunmitted": "submitted",
    "suop": "soup",
    "suoppose": "suppose",
    "supass": "surpass",
    "suped": "super",
    "superceeded": "superseded",
    "supercession": "supersession",
    "supercessionism": "supersessionism",
    "superfical": "superficial",
    "supergluded": "superglued",
    "superintendant": "superintendent",
    "supermacy": "supremacy",
    "supervisior": "supervisor",
    "suphisticated": "sophisticated",
    "supid": "stupid",
    "suplant": "supplant",
    "suplement": "supplement",
    "suplemental": "supplemental",
    "suplied": "supplied",
    "suplimented": "supplemented",
    "suply": "supply",
    "supose": "suppose",
    "suposed": "supposed",
    "suposedly": "supposedly",
    "suposes": "supposes",
    "suposing": "supposing",
    "supperior": "superior",
    "supplament": "supplement",
    "supplamented": "supplemented",
    "suppliementing": "supplementing",
    "suppliment": "supplement",
    "supplyed": "supplied",
    "suppoed": "supposed",
    "supportn": "support",
    "supporty": "support",
    "supposingly": "supposedly",
    "suppossed": "supposed",
    "suppost": "suppose",
    "supposted": "supposed",
    "suppot": "support",
    "suppposed": "supposed",
    "suppresion": "suppression",
    "suppsed": "supposed",
    "suppy": "supply",
    "suprassing": "surpassing",
    "supremist": "supremacist",
    "supress": "suppress",
    "supressed": "suppressed",
    "supresses": "suppresses",
    "supressing": "suppressing",
    "suprise": "surprise",
    "suprised": "surprised",
    "suprising": "surprising",
    "suprisingly": "surprisingly",
    "suprize": "surprise",
    "suprized": "surprised",
    "suprizing": "surprising",
    "suprizingly": "surprisingly",
    "supsended": "suspended",
    "suqks": "sucks",
    "surelly": "surely",
    "surender": "surrender",
    "surfce": "surface",
    "surffering": "suffering",
    "suring": "surfing",
    "suround": "surround",
    "surounded": "surrounded",
    "surounding": "surrounding",
    "suroundings": "surroundings",
    "surounds": "surrounds",
    "surpased": "surpassed",
    "surperb": "superb",
    "surpirsed": "surprised",
    "surpised": "surprised",
    "surplant": "supplant",
    "surplanted": "supplanted",
    "surpose": "suppose",
    "surposed": "supposed",
    "surpress": "suppress",
    "surpressed": "suppressed",
    "surprisef": "surprised",
    "surprize": "surprise",
    "surprized": "surprised",
    "surprizing": "surprising",
    "surprizingly": "surprisingly",
    "surrepetitious": "surreptitious",
    "surrepetitiously": "surreptitiously",
    "surreptious": "surreptitious",
    "surreptiously": "surreptitiously",
    "surronded": "surrounded",
    "surroud": "surround",
    "surrouded": "surrounded",
    "surrouding": "surrounding",
    "surrundering": "surrendering",
    "surveilence": "surveillance",
    "surveill": "surveil",
    "surveyer": "surveyor",
    "survice": "service",
    "survied": "survived",
    "survivd": "survived",
    "surviver": "survivor",
    "survivers": "survivors",
    "survivied": "survived",
    "survivng": "surviving",
    "survuved": "survived",
    "susbcribe": "subscribe",
    "susceptability": "susceptibility",
    "susceptable": "susceptible",
    "susected": "suspected",
    "suseptable": "susceptible",
    "suseptible": "susceptible",
    "susequent": "subsequent",
    "suspention": "suspension",
    "sustance": "substance",
    "suz": "cuz",
    "suzerainity": "suzerainty",
    "sved": "saved",
    "svine": "swine",
    "swaer": "swear",
    "swaers": "swears",
    "swagga": "swagg",
    "swaggg": "swagg",
    "swaped": "swapped",
    "swar": "swear",
    "sweept": "swept",
    "swein": "swin",
    "sweine": "swine",
    "swepth": "swept",
    "swgg": "swag",
    "swhine": "swine",
    "swian": "swin",
    "swibe": "swine",
    "swich": "switch",
    "swiched": "switched",
    "swicthed": "switched",
    "swicthing": "switching",
    "swien": "swine",
    "swiene": "swine",
    "swife": "swine",
    "swiine": "swine",
    "swime": "swine",
    "swiming": "swimming",
    "swina": "swine",
    "swinbe": "swine",
    "swince": "swine",
    "swind": "swine",
    "swinde": "swine",
    "swiner": "swine",
    "swiney": "swine",
    "swinf": "swine",
    "swinfe": "swine",
    "swinie": "swine",
    "swinle": "swine",
    "swinne": "swine",
    "swinr": "swine",
    "swint": "swine",
    "swinw": "swine",
    "swinwe": "swine",
    "swiny": "swine",
    "switchn": "switch",
    "switchs": "switches",
    "swithed": "switched",
    "swithing": "switching",
    "switter": "twitter",
    "switvched": "switched",
    "swkine": "swine",
    "swn": "own",
    "swne": "swine",
    "swnine": "swine",
    "swored": "swore",
    "swotch": "switch",
    "swqne": "swine",
    "swtch": "switch",
    "swtich": "switch",
    "swtiched": "switched",
    "swune": "swine",
    "swwine": "swine",
    "swyne": "swine",
    "syas": "says",
    "sycks": "sucks",
    "sycning": "syncing",
    "symetric": "symmetric",
    "symetrical": "symmetrical",
    "symetrically": "symmetrically",
    "symetry": "symmetry",
    "symettric": "symmetric",
    "symmetral": "symmetric",
    "symmetricaly": "symmetrically",
    "sympoms": "symptoms",
    "sympotoms": "symptoms",
    "sympthoms": "symptoms",
    "symptomms": "symptoms",
    "symptomns": "symptoms",
    "symptomss": "symptoms",
    "symptomsu": "symptoms",
    "symptomz": "symptoms",
    "symptonms": "symptoms",
    "symptons": "symptoms",
    "sympyoms": "symptoms",
    "symtom": "symptom",
    "symtoms": "symptoms",
    "symtpoms": "symptoms",
    "symttoms": "symptoms",
    "synagouge": "synagogue",
    "syncd": "sync",
    "syncd": "syncs",
    "synce": "sync",
    "synces": "syncs",
    "synchophant": "sycophant",
    "synchotron": "synchrotron",
    "syncophant": "sycophant",
    "syncronization": "synchronization",
    "synicing": "syncing",
    "synonomous": "synonymous",
    "synonymns": "synonyms",
    "synphony": "symphony",
    "syphyllis": "syphilis",
    "sypmtoms": "symptoms",
    "sypnosis": "synopsis",
    "syptom": "symptom",
    "syptoms": "symptoms",
    "syrap": "syrup",
    "sysmatically": "systematically",
    "sysmptom": "symptom",
    "sysmptoms": "symptoms",
    "systen": "system",
    "systm": "system",
    "sysytem": "system",
    "sytem": "system",
    "sytle": "style",
    "taalked": "talked",
    "tabacco": "tobacco",
    "tabblet": "tablet",
    "tableclothes": "tablecloths",
    "tablewear": "tableware",
    "tacticaly": "tactically",
    "tactict": "tactic",
    "tactitian": "tactician",
    "tahn": "than",
    "taht": "that",
    "tailight": "taillight",
    "takd": "take",
    "takig": "taking",
    "takiing": "taking",
    "takinng": "taking",
    "takinq": "taking",
    "takking": "talking",
    "takling": "talking",
    "takn": "take",
    "takn": "taken",
    "takng": "taking",
    "takoing": "taking",
    "talekd": "talked",
    "taliking": "talking",
    "taling": "talking",
    "talkg": "talk",
    "talkign": "talking",
    "talkiing": "talking",
    "talkimg": "talking",
    "talkingg": "talking",
    "talkinq": "talking",
    "talkk": "talk",
    "talkn": "talk",
    "tallk": "talk",
    "tallking": "talking",
    "tandum": "tandem",
    "targetted": "targeted",
    "targetting": "targeting",
    "tarif": "tariff",
    "tarrif": "tariff",
    "tarriff": "tariff",
    "tast": "taste",
    "tath": "that",
    "tatics": "tactics",
    "tatoo": "tattoo",
    "tatsunoku": "tatsunoko",
    "tattooes": "tattoos",
    "taunami": "tsunami",
    "taxanomic": "taxonomic",
    "taxanomy": "taxonomy",
    "tbat": "that",
    "tbe": "the",
    "tdoing": "doing",
    "teaccher": "teacher",
    "teached": "taught",
    "teacherr": "teacher",
    "teachr": "teacher",
    "teachs": "teaches",
    "teady": "ready",
    "teaffic": "traffic",
    "teamate": "teammate",
    "teamates": "teammates",
    "teamd": "teams",
    "teather": "tether",
    "teather": "weather",
    "teathering": "tethering",
    "techical": "technical",
    "techician": "technician",
    "techicians": "technicians",
    "techincal": "technical",
    "techiniques": "techniques",
    "technicaly": "technically",
    "technican": "technician",
    "technitian": "technician",
    "technnology": "technology",
    "technolgy": "technology",
    "teecher": "teacher",
    "teeetdeck": "tweetdeck",
    "teengae": "teenage",
    "teetdeck": "tweetdeck",
    "teeting": "tweeting",
    "teh": "the",
    "tehe": "the",
    "tehn": "then",
    "tehy": "they",
    "teitter": "twitter",
    "tekus": "telus",
    "telcom": "telecom",
    "telelevision": "television",
    "televison": "television",
    "televize": "televise",
    "televsion": "television",
    "tellimg": "telling",
    "telll": "tell",
    "telll": "tells",
    "telln": "tell",
    "telln": "tells",
    "telphony": "telephony",
    "temerature": "temperature",
    "tempalte": "template",
    "tempaltes": "templates",
    "temparate": "temperate",
    "temperarily": "temporarily",
    "temperment": "temperament",
    "tempermental": "temperamental",
    "tempertaure": "temperature",
    "temperture": "temperature",
    "temporarely": "temporarily",
    "temprary": "temporary",
    "temprature": "temperature",
    "temtped": "tempted",
    "tenacle": "tentacle",
    "tenacles": "tentacles",
    "tenament": "tenement",
    "tendacy": "tendency",
    "tendancies": "tendencies",
    "tendancy": "tendency",
    "tenis": "tennis",
    "tennament": "tenement",
    "tennement": "tenement",
    "tennisplayer": "tennis player",
    "tenticle": "tentacle",
    "tepmorarily": "temporarily",
    "terible": "terrible",
    "teriible": "terrible",
    "teritory": "territory",
    "terminaly": "terminally",
    "terresterial": "terrestrial",
    "terrestial": "terrestrial",
    "terriories": "territories",
    "terriory": "territory",
    "territores": "territories",
    "territorist": "terrorist",
    "territority": "territory",
    "territoy": "territory",
    "terroist": "terrorist",
    "terthering": "tethering",
    "tesing": "testing",
    "testamonial": "testimonial",
    "testamony": "testimony",
    "testical": "testicle",
    "testiclular": "testicular",
    "testign": "testing",
    "testiment": "testament",
    "testimont": "testament",
    "testingy": "testing",
    "testomony": "testimony",
    "testsed": "tested",
    "testung": "testing",
    "tesy": "test",
    "teuls": "telus",
    "teweet": "tweet",
    "tewplates": "templates",
    "texing": "texting",
    "textes": "texts",
    "teying": "trying",
    "tghe": "the",
    "tghinking": "thinking",
    "tgink": "think",
    "tgis": "this",
    "thaanks": "thanks",
    "thaat": "that",
    "thab": "than",
    "thae": "the",
    "thaink": "think",
    "thaknk": "thank",
    "thaks": "thanks",
    "thanbk": "thank",
    "thankd": "thanks",
    "thankgs": "thanks",
    "thankk": "thank",
    "thankss": "thanks",
    "thankx": "thanks",
    "thankz": "thanks",
    "thanl": "thank",
    "thann": "than",
    "thanq": "than",
    "thans": "thanks",
    "thansk": "thanks",
    "thanxs": "thanks",
    "thaqt": "that",
    "thara": "thera",
    "thast": "that",
    "thati": "that",
    "thatl": "that",
    "thatn": "that",
    "thatnks": "thanks",
    "thatsz": "thats",
    "thatv": "that",
    "thaty": "that",
    "thatz": "thats",
    "thax": "thx",
    "thaz": "that",
    "theat": "that",
    "theather": "theater",
    "theb": "then",
    "theee": "these",
    "theee": "three",
    "theere": "there",
    "theese": "these",
    "theey": "they",
    "thei": "the",
    "theif": "thief",
    "theit": "their",
    "theives": "thieves",
    "themez": "themes",
    "themm": "them",
    "themselfs": "themselves",
    "themsleves": "themselves",
    "themslves": "themselves",
    "theng": "then",
    "thenk": "thank",
    "thenks": "thanks",
    "thenn": "then",
    "theologan": "theologian",
    "theose": "those",
    "ther": "they",
    "therafter": "thereafter",
    "theral": "thera",
    "theraphy": "therapy",
    "therby": "thereby",
    "therei": "there",
    "therer": "there",
    "theri": "their",
    "thero": "thera",
    "theroretical": "theoretical",
    "theroy": "theory",
    "theru": "thera",
    "theru": "there",
    "therw": "there",
    "therwise": "otherwise",
    "thery": "theory",
    "therz": "there",
    "thes": "they",
    "thesee": "these",
    "thet": "they",
    "thethering": "tethering",
    "thetre": "there",
    "theu": "they",
    "thewre": "there",
    "theyre": "they're",
    "theyt": "they",
    "theze": "these",
    "thgat": "that",
    "thge": "the",
    "thgt": "that",
    "thhank": "thank",
    "thhat": "that",
    "thhe": "the",
    "thhink": "think",
    "thhs": "this",
    "thibg": "thing",
    "thibk": "think",
    "thickend": "thickened",
    "thier": "their",
    "thign": "thing",
    "thigns": "things",
    "thigsn": "things",
    "thihg": "thing",
    "thiings": "things",
    "thiink": "think",
    "thiinking": "thinking",
    "thiking": "thinking",
    "thikn": "think",
    "thikngs": "things",
    "thikns": "thinks",
    "thimk": "think",
    "thinbk": "think",
    "thingd": "things",
    "thingg": "thing",
    "thingi": "thing",
    "thingking": "thinking",
    "thingz": "things",
    "thinka": "think",
    "thinka": "thinks",
    "thinkg": "think",
    "thinki": "think",
    "thinkingg": "thinking",
    "thinkinn": "thinking",
    "thinkinq": "thinking",
    "thinkk": "think",
    "thinkking": "thinking",
    "thinkn": "thinkin",
    "thinkng": "thinking",
    "thinkong": "thinking",
    "thinkr": "think",
    "thinkss": "thinks",
    "thinkz": "think",
    "thinl": "think",
    "thinng": "thing",
    "thinos": "things",
    "thinq": "thing",
    "thinq": "think",
    "thisb": "this",
    "thise": "those",
    "thisnk": "think",
    "thisx": "this",
    "thiught": "thought",
    "thiunk": "think",
    "thiw": "this",
    "thje": "the",
    "thjis": "this",
    "thks": "this",
    "thn": "then",
    "thna": "than",
    "thnaks": "thanks",
    "thne": "then",
    "thng": "thing",
    "thngs": "things",
    "thnig": "thing",
    "thnigs": "things",
    "thnik": "think",
    "thnkin": "thinkin",
    "thnking": "thinking",
    "thnks": "thanks",
    "thnks": "thinks",
    "thoat": "throat",
    "thoe": "the",
    "thoery": "theory",
    "thoes": "those",
    "thoese": "those",
    "thoguht": "thought",
    "thois": "this",
    "thoiught": "thought",
    "thonk": "think",
    "thoose": "those",
    "thoroat": "throat",
    "thorogh": "thorough",
    "thoroghbred": "thoroughbred",
    "thoroughbread": "thoroughbred",
    "thoseb": "those",
    "thoses": "those",
    "thoughht": "thought",
    "thoughout": "throughout",
    "thoughti": "thought",
    "thougt": "thought",
    "thougth": "thought",
    "thougths": "thoughts",
    "thougts": "thoughts",
    "thouhgt": "thought",
    "thouht": "thought",
    "thouigh": "though",
    "thounsands": "thousands",
    "thouqht": "thought",
    "thourht": "thought",
    "thouroughly": "thoroughly",
    "thousadns": "thousands",
    "thouse": "those",
    "thousnad": "thousand",
    "thqat": "that",
    "threa": "thera",
    "threatend": "threatened",
    "threath": "threat",
    "threatning": "threatening",
    "threee": "three",
    "threshhold": "threshold",
    "threshould": "threshold",
    "thrid": "third",
    "thridly": "thirdly",
    "throad": "throat",
    "throatd": "throat",
    "throath": "throat",
    "throrough": "thorough",
    "throughly": "thoroughly",
    "throught": "through",
    "throughtout": "throughout",
    "througout": "throughout",
    "throut": "throat",
    "throuth": "through",
    "thru": "through",
    "thsi": "this",
    "thsoe": "those",
    "thta": "that",
    "thte": "the",
    "thts": "this",
    "thught": "thought",
    "thwe": "the",
    "thwy": "they",
    "thxs": "this",
    "thyat": "that",
    "thye": "the",
    "thying": "trying",
    "thyng": "thing",
    "thynk": "think",
    "tiday": "today",
    "tierd": "tired",
    "tiggered": "triggered",
    "tihkn": "think",
    "tihng": "thing",
    "tihnk": "think",
    "tihs": "this",
    "tiime": "time",
    "timf": "time",
    "timme": "time",
    "timne": "time",
    "tinsy": "tiny",
    "tipical": "typical",
    "tipps": "tips",
    "tipz": "tips",
    "titterific": "twitterific",
    "tiwtter": "twitter",
    "tjat": "that",
    "tje": "the",
    "tjhe": "the",
    "tjink": "think",
    "tjis": "this",
    "tjpanishad": "upanishad",
    "tkae": "take",
    "tkaes": "takes",
    "tkaing": "taking",
    "tke": "take",
    "tkes": "takes",
    "tkx": "thx",
    "tlak": "talk",
    "tlaking": "talking",
    "tlels": "tells",
    "tlist": "list",
    "tlked": "talked",
    "tlkin": "talkin",
    "tlking": "talking",
    "tmorrow": "tomorrow",
    "tnink": "think",
    "tnot": "not",
    "toaday": "today",
    "toally": "totally",
    "tobbaco": "tobacco",
    "todaay": "today",
    "todat": "today",
    "todays": "today's",
    "todayy": "today",
    "todday": "today",
    "todl": "told",
    "todsay": "today",
    "todya": "today",
    "toghether": "together",
    "togther": "together",
    "toke": "took",
    "toldd": "told",
    "tolerence": "tolerance",
    "tolerent": "tolerant",
    "toliet": "toilet",
    "tols": "told",
    "tomarrow": "tomorrow",
    "tomatos": "tomatoes",
    "tomerrow": "tomorrow",
    "tommorow": "tomorrow",
    "tommorrow": "tomorrow",
    "tomoorow": "tomorrow",
    "tomorow": "tomorrow",
    "tomorroww": "tomorrow",
    "tomorrrow": "tomorrow",
    "tomorrwo": "tomorrow",
    "tomrorow": "tomorrow",
    "tongiht": "tonight",
    "tonz": "tons",
    "toobar": "toolbar",
    "tooblar": "toolbar",
    "tooday": "today",
    "tookit": "toolkit",
    "tookover": "took over",
    "tooks": "took",
    "toolabr": "toolbar",
    "tooless": "toolless",
    "tooo": "too",
    "toook": "took",
    "toooo": "soooo",
    "topicsi": "topics",
    "topoic": "topic",
    "toriod": "toroid",
    "toriodal": "toroidal",
    "tormenters": "tormentors",
    "tornadoe": "tornado",
    "tornament": "tournament",
    "torpeados": "torpedoes",
    "torpedos": "torpedoes",
    "tortise ": "tortoise",
    "tortise": "tortoise",
    "totallyy": "totally",
    "totaly": "totally",
    "tothe": "to the",
    "tottally": "totally",
    "touble": "trouble",
    "toubles": "troubles",
    "tought": "thought",
    "toughts": "thoughts",
    "touh": "tour",
    "tounge": "tongue",
    "tourmanent": "tournament",
    "touvh": "touch",
    "towords": "towards",
    "toworrow": "tomorrow",
    "towrad": "toward",
    "toyko": "tokyo",
    "toyus": "toys",
    "tpld": "told",
    "tqake": "take",
    "traanslator": "translator",
    "trabsfer": "transfer",
    "trackera": "tracker",
    "tradgedy": "tragedy",
    "tradicional": "traditional",
    "tradionally": "traditionally",
    "traditionaly": "traditionally",
    "traditionnal": "traditional",
    "traditition": "tradition",
    "traditon": "tradition",
    "traditonal": "traditional",
    "tradtionally": "traditionally",
    "trafficed": "trafficked",
    "trafficing": "trafficking",
    "trafic": "traffic",
    "trafific": "traffic",
    "trailor": "trailer",
    "traing": "training",
    "traingle": "triangle",
    "trak": "track",
    "trancend": "transcend",
    "trancended": "transcended",
    "trancendent": "transcendent",
    "trancendental": "transcendental",
    "trancending": "transcending",
    "tranding": "trending",
    "trandsmap": "trendsmap",
    "tranfer": "transfer",
    "tranform": "transform",
    "tranformed": "transformed",
    "tranlate": "translate",
    "tranlator": "translator",
    "transalte": "translate",
    "transcendance": "transcendence",
    "transcendant": "transcendent",
    "transcendentational": "transcendental",
    "transcept": "transept",
    "transelate": "translate",
    "transend": "transcend",
    "transending": "transcending",
    "transesxuals": "transsexuals",
    "transfered": "transferred",
    "transfering": "transferring",
    "transferr": "transfer",
    "transfor": "transfer",
    "transformaton": "transformation",
    "transister": "transistor",
    "transistion": "transition",
    "translage": "translate",
    "translater": "translator",
    "translaters": "translators",
    "translete": "translate",
    "transluscent": "translucent",
    "transmision": "transmission",
    "transmissable": "transmissible",
    "transmited": "transmitted",
    "transmiter": "transmitter",
    "transmiting": "transmitting",
    "transmitt": "transmit",
    "transporation": "transportation",
    "traslate": "translate",
    "tratment": "treatment",
    "travl": "travel",
    "treament": "treatment",
    "treatmernt": "treatment",
    "treatn": "treat",
    "treding": "trending",
    "tredning": "trending",
    "tremelo": "tremolo",
    "tremelos": "tremolos",
    "trendig": "trending",
    "trendign": "trending",
    "trendind": "trending",
    "trendinq": "trending",
    "trenging": "trending",
    "trening": "trending",
    "treshold": "threshold",
    "tresle": "trestle",
    "tresspass": "trespass",
    "trhe": "the",
    "trhew": "threw",
    "trhough": "through",
    "trhying": "trying",
    "triathalon": "triathlon",
    "triguered": "triggered",
    "triology": "trilogy",
    "triying": "trying",
    "trnaslate": "translate",
    "troling": "trolling",
    "troubel": "trouble",
    "troup": "troupe",
    "trrrible": "terrible",
    "trthering": "tethering",
    "truely": "truly",
    "truley": "truly",
    "truning": "turning",
    "truns": "runs",
    "trustworthyness": "trustworthiness",
    "tryd": "try",
    "tryen": "tryin",
    "tryign": "trying",
    "tryijng": "trying",
    "tryina": "tryna",
    "tryingg": "trying",
    "tryinh": "trying",
    "tryinng": "trying",
    "tryinq": "trying",
    "tryint": "trying",
    "tryke": "trike",
    "tryn": "try",
    "tryng": "trying",
    "trynin": "tryin",
    "trys": "tries",
    "tryying": "trying",
    "tsken": "taken",
    "tsnami": "tsunami",
    "tsnunami": "tsunami",
    "tsuanami": "tsunami",
    "tsuanmi": "tsunami",
    "tsumami": "tsunami",
    "tsuname": "tsunami",
    "tsunmai": "tsunami",
    "tthere": "there",
    "tthink": "think",
    "tthis": "this",
    "ttied": "tried",
    "tto": "to",
    "ttried": "tried",
    "ttrying": "trying",
    "ttweet": "tweet",
    "tuen": "turn",
    "tumultous": "tumultuous",
    "tunr": "turn",
    "tuped": "typed",
    "turm": "turn",
    "turnes": "turns",
    "tusnami": "tsunami",
    "tust": "trust",
    "tutning": "turning",
    "tuturial": "tutorial",
    "twatter": "twitter",
    "twattering": "twittering",
    "tweat": "tweet",
    "tweating": "tweeting",
    "tweats": "tweets",
    "tweeddeck": "tweetdeck",
    "tweedeck": "tweetdeck",
    "tweeet": "tweet",
    "tweeeting": "tweeting",
    "tweeing": "tweeting",
    "tweeite": "tweetie",
    "tweekdeck": "tweetdeck",
    "tweeks": "weeks",
    "tweetd": "tweet",
    "tweetd": "tweeted",
    "tweetddeck": "tweetdeck",
    "tweetdecl": "tweetdeck",
    "tweetdeek": "tweetdeck",
    "tweetdesk": "tweetdeck",
    "tweetdexk": "tweetdeck",
    "tweete": "tweetie",
    "tweeteck": "tweetdeck",
    "tweething": "tweeting",
    "tweeti": "tweet",
    "tweetibng": "tweeting",
    "tweetimg": "tweeting",
    "tweetin": "tweetie",
    "tweetinfg": "tweeting",
    "tweetmeant": "tweetment",
    "tweetn": "tweet",
    "tweetong": "tweeting",
    "tweettdeck": "tweetdeck",
    "tweetue": "tweetie",
    "tweetung": "tweeting",
    "tweew": "tweet",
    "twelth": "twelfth",
    "twentys": "twenties",
    "twet": "tweet",
    "twetdeck": "tweetdeck",
    "tweting": "tweeting",
    "twett": "tweet",
    "twetterific": "twitterific",
    "twettie": "tweetie",
    "twetting": "tweeting",
    "twetty": "tweety",
    "twhen": "when",
    "twii": "wii",
    "twiiter": "twitter",
    "twiitter": "twitter",
    "twitboy": "twitbot",
    "twitear": "twittear",
    "twiter": "twitter",
    "twiterific": "twitterific",
    "twitering": "twittering",
    "twittar": "twitter",
    "twittear": "twitter",
    "twittendo": "twitteando",
    "twitteo": "twitter",
    "twitterando": "twitteando",
    "twitterfic": "twitterific",
    "twitteri": "twitter",
    "twitterifuc": "twitterific",
    "twitteriic": "twitterific",
    "twitteriric": "twitterific",
    "twittern": "twitter",
    "twitterr": "twitter",
    "twitterrffic": "twitterrific",
    "twitterriffic": "twitterrific",
    "twittert": "twitter",
    "twitterz": "twitter",
    "twittet": "twitter",
    "twittr": "twitter",
    "twittre": "twitter",
    "twittter": "twitter",
    "twon": "town",
    "twottering": "twittering",
    "twought": "thought",
    "twoughts": "thoughts",
    "twpo": "two",
    "twrtter": "twitter",
    "twtter": "twitter",
    "twwet": "tweet",
    "twwets": "tweets",
    "twwitter": "twitter",
    "txts": "texts",
    "tyelenol": "tylenol",
    "tyenol": "tylenol",
    "tyeped": "typed",
    "tyhat": "that",
    "tyhe": "the",
    "tyhe": "they",
    "tyhphoon": "typhoon",
    "tyll": "till",
    "tylonol": "tylenol",
    "tyoe": "type",
    "typcial": "typical",
    "typd": "typed",
    "typicaly": "typically",
    "typingg": "typing",
    "typoon": "typhoon",
    "typr": "type",
    "tyranies": "tyrannies",
    "tyrany": "tyranny",
    "tyring": "trying",
    "tyrranies": "tyrannies",
    "tyrrany": "tyranny",
    "tyype": "type",
    "tzeet": "tweet",
    "ubar": "bar",
    "ubiquitious": "ubiquitous",
    "ublic": "public",
    "ublisher": "publisher",
    "udated": "updated",
    "udating": "updating",
    "udge": "judge",
    "udpate": "update",
    "uers": "users",
    "uget": "get",
    "uggh": "ugh",
    "ugot": "got",
    "ugrade": "upgrade",
    "ugraded": "upgraded",
    "uhat": "that",
    "uhave": "have",
    "uing": "using",
    "uise": "use",
    "ulimatum": "ultimatum",
    "ulitimate": "ultimate",
    "ulitmate": "ultimate",
    "ulocked": "unlocked",
    "ulrimate": "ultimate",
    "ultimatim": "ultimatum",
    "ultimatium": "ultimatum",
    "ultimatley": "ultimately",
    "ultimatly": "ultimately",
    "ultimely": "ultimately",
    "ultimitely": "ultimately",
    "ultmate": "ultimate",
    "unabatted": "unabated",
    "unacompanied": "unaccompanied",
    "unactivity": "inactivity",
    "unahppy": "unhappy",
    "uname": "name",
    "unaminous": "unanimous",
    "unanymous": "unanimous",
    "unathorised": "unauthorised",
    "unavailible": "unavailable",
    "unavalable": "unavailable",
    "unavaliable": "unavailable",
    "unavalible": "unavailable",
    "unballance": "unbalance",
    "unbeknowst": "unbeknownst",
    "unbeleivable": "unbelievable",
    "uncertainity": "uncertainty",
    "uncertian": "uncertain",
    "unchallengable": "unchallengeable",
    "unchangable": "unchangeable",
    "unclock": "unlock",
    "uncompetive": "uncompetitive",
    "unconcious": "unconscious",
    "unconciousness": "unconsciousness",
    "unconfortability": "discomfort",
    "unconscience": "unconscious",
    "uncontitutional": "unconstitutional",
    "unconvential": "unconventional",
    "unconventionaly": "unconventionally",
    "undaer": "under",
    "undecideable": "undecidable",
    "underated": "underrated",
    "underdstand": "understand",
    "undergound": "underground",
    "underming": "undermining",
    "undersrand": "understand",
    "understnad": "understand",
    "understnd": "understand",
    "understoon": "understood",
    "undertand": "understand",
    "undertsand": "understand",
    "undesireable": "undesirable",
    "undestand": "understand",
    "undestructible": "indestructible",
    "undetecable": "undetectable",
    "undewr": "under",
    "undoubtely": "undoubtedly",
    "undreground": "underground",
    "uneccesary": "unnecessary",
    "unecessary": "unnecessary",
    "uneeded": "unneeded",
    "uneffected": "unaffected",
    "unequalities": "inequalities",
    "unequaly": "unequally",
    "unexplicable": "inexplicable",
    "unfamilar": "unfamiliar",
    "unfinnished": "unfinished",
    "unforetunately": "unfortunately",
    "unforgetable": "unforgettable",
    "unforgiveable": "unforgivable",
    "unforseen": "unforeseen",
    "unfortunatley": "unfortunately",
    "unfortunatly": "unfortunately",
    "unfourtunately": "unfortunately",
    "ungle": "tungle",
    "unhumane": "inhumane",
    "unifed": "unified",
    "unifrom": "uniform",
    "unihabited": "uninhabited",
    "unilateraly": "unilaterally",
    "unilatreal": "unilateral",
    "unilatreally": "unilaterally",
    "unindentified": "unidentified",
    "uninterruped": "uninterrupted",
    "uninterupted": "uninterrupted",
    "univeral": "universal",
    "univeristies": "universities",
    "univeristy": "university",
    "univerities": "universities",
    "univerity": "university",
    "universaly": "universally",
    "universitaries": "universities",
    "universitary": "university",
    "universites": "universities",
    "universties": "universities",
    "universtiy": "university",
    "universty": "university",
    "univesities": "universities",
    "univesity": "university",
    "unkown": "unknown",
    "unlcoked": "unlocked",
    "unleashng": "unleashing",
    "unlikey": "unlikely",
    "unlikley": "unlikely",
    "unloack": "unlock",
    "unlocced": "unlocked",
    "unloced": "unlocked",
    "unlockd": "unlocked",
    "unlockedb": "unlocked",
    "unlok": "unlock",
    "unloked": "unlocked",
    "unlook": "unlock",
    "unmistakeably": "unmistakably",
    "unneccesarily": "unnecessarily",
    "unneccesary": "unnecessary",
    "unneccessarily": "unnecessarily",
    "unneccessary": "unnecessary",
    "unnecesarily": "unnecessarily",
    "unnecesary": "unnecessary",
    "unnemployment": "unemployment",
    "unock": "unlock",
    "unocked": "unlocked",
    "unoffical": "unofficial",
    "unofficialy": "unofficially",
    "unoperational": "nonoperational",
    "unorthadox": "unorthodox",
    "unoticeable": "unnoticeable",
    "unpdates": "updates",
    "unperiodic": "aperiodic",
    "unplease": "displease",
    "unplesant": "unpleasant",
    "unprecendented": "unprecedented",
    "unprecidented": "unprecedented",
    "unpresidented": "unprecedented",
    "unprobable": "improbable",
    "unrepentent": "unrepentant",
    "unrepetant": "unrepentant",
    "unrepetent": "unrepentant",
    "unstead": "instead",
    "unsual": "unusual",
    "unsubstanciated": "unsubstantiated",
    "unsuccesful": "unsuccessful",
    "unsuccesfully": "unsuccessfully",
    "unsuccessfull": "unsuccessful",
    "unsucesful": "unsuccessful",
    "unsucesfuly": "unsuccessfully",
    "unsucessful": "unsuccessful",
    "unsucessfull": "unsuccessful",
    "unsucessfully": "unsuccessfully",
    "unsuprised": "unsurprised",
    "unsuprising": "unsurprising",
    "unsuprisingly": "unsurprisingly",
    "unsuprized": "unsurprised",
    "unsuprizing": "unsurprising",
    "unsuprizingly": "unsurprisingly",
    "unsurprized": "unsurprised",
    "unsurprizing": "unsurprising",
    "unsurprizingly": "unsurprisingly",
    "untill": "until",
    "untranslateable": "untranslatable",
    "unuseable": "unusable",
    "unusuable": "unusable",
    "unusualy": "unusually",
    "unvelied": "unveiled",
    "unversity": "university",
    "unviel": "unveil",
    "unvieled": "unveiled",
    "unviersities": "universities",
    "unviersity": "university",
    "unvitation": "invitation",
    "unvite": "invite",
    "unwarrented": "unwarranted",
    "unweildly": "unwieldy",
    "unwieldly": "unwieldy",
    "uou": "you",
    "upadate": "update",
    "upadating": "updating",
    "upadte": "update",
    "upcomming": "upcoming",
    "updataing": "updating",
    "updatd": "updated",
    "updatde": "update",
    "updatedd": "updated",
    "updatewd": "updated",
    "updatig": "updating",
    "updatinn": "updating",
    "updatinq": "updating",
    "updatn": "update",
    "updatred": "updated",
    "updatung": "updating",
    "updatwe": "update",
    "updaye": "update",
    "updgrade": "upgrade",
    "updload": "upload",
    "updte": "update",
    "upfates": "updates",
    "upgade": "upgrade",
    "upgaded": "upgraded",
    "upgarde": "upgrade",
    "upgarding": "upgrading",
    "upgradded": "upgraded",
    "upgraged": "upgraded",
    "upgrated": "upgraded",
    "upgrde": "upgrade",
    "upgrded": "upgraded",
    "upgreded": "upgraded",
    "upholded": "upheld",
    "uphone": "iphone",
    "uping": "using",
    "uploed": "upload",
    "upoad": "upload",
    "upoaded": "uploaded",
    "upolad": "upload",
    "upposed": "supposed",
    "uptate": "update",
    "uptated": "updated",
    "upthe": "up the",
    "upto": "up to",
    "upy": "up",
    "urbanapoon": "urbanspoon",
    "urequested": "requested",
    "usally": "usually",
    "useage": "usage",
    "useally": "usually",
    "useers": "users",
    "useflu": "useful",
    "usefull": "useful",
    "usefullness": "usefulness",
    "usefuly": "usefully",
    "useing": "using",
    "uselss": "useless",
    "usem": "use",
    "userd": "users",
    "useres": "users",
    "userful": "useful",
    "userz": "users",
    "usey": "use",
    "usig": "using",
    "usiing": "using",
    "usimg": "using",
    "usinga": "using",
    "usingg": "using",
    "usinng": "using",
    "usinq": "using",
    "usning": "using",
    "usre": "sure",
    "usses": "uses",
    "ussues": "issues",
    "usualy": "usually",
    "usued": "used",
    "usuers": "users",
    "usully": "usually",
    "usurpate": "usurp",
    "ususal": "usual",
    "ususally": "usually",
    "utell": "tell",
    "utilites": "utilities",
    "uugh": "ugh",
    "uve": "ive",
    "vaacine": "vaccine",
    "vaccaination": "vaccination",
    "vaccanations": "vaccinations",
    "vacccine": "vaccine",
    "vacccines": "vaccines",
    "vaccfine": "vaccine",
    "vaccianted": "vaccinated",
    "vaccicnation": "vaccination",
    "vaccinaded": "vaccinated",
    "vaccinatons": "vaccinations",
    "vaccince": "vaccine",
    "vaccined": "vaccines",
    "vaccinep": "vaccine",
    "vacciness": "vaccines",
    "vaccinez": "vaccine",
    "vaccins": "vaccines",
    "vaccintion": "vaccination",
    "vaccnation": "vaccination",
    "vaccne": "vaccine",
    "vaccum": "vacuum",
    "vaccume": "vacuum",
    "vacency": "vacancy",
    "vacent": "vacant",
    "vaciine": "vaccine",
    "vacinate": "vaccinate",
    "vacinated": "vaccinated",
    "vacination": "vaccination",
    "vacine": "vaccine",
    "vacines": "vaccines",
    "vacinity": "vicinity",
    "vack": "back",
    "vacsine": "vaccine",
    "vacvine": "vaccine",
    "vaguaries": "vagaries",
    "vaieties": "varieties",
    "vailidty": "validity",
    "vairous": "various",
    "valetta": "valletta",
    "valient": "valiant",
    "valler": "valley",
    "valuble": "valuable",
    "valueable": "valuable",
    "vanna": "wanna",
    "vannish": "vanish",
    "vanuato": "vanuatu",
    "varable": "variable",
    "varations": "variations",
    "vareity": "variety",
    "variaty": "variety",
    "varible": "variable",
    "varience": "variance",
    "varient": "variant",
    "varietes": "varieties",
    "variey": "variety",
    "varifiable": "verifiable",
    "varification": "verification",
    "varing": "varying",
    "variosly": "variously",
    "varisty": "varsity",
    "varities": "varieties",
    "varity": "variety",
    "varous": "various",
    "varys": "varies",
    "vasall": "vassal",
    "vasalls": "vassals",
    "vascine": "vaccine",
    "vasodialation": "vasodilation",
    "vasodialator": "vasodilator",
    "vaunatu": "vanuatu",
    "vavccination": "vaccination",
    "vaxine": "vacine",
    "vay": "pay",
    "vcant": "cant",
    "vdeos": "videos",
    "vdo": "do",
    "vechicle": "vehicle",
    "vector-born": "vector-borne",
    "vefore": "before",
    "vegatarian": "vegetarian",
    "vegeterian": "vegetarian",
    "vegitable": "vegetable",
    "vegitables": "vegetables",
    "vegitarian": "vegetarian",
    "vegtable": "vegetable",
    "vehichle": "vehicle",
    "vehicule": "vehicle",
    "veign": "vein",
    "veiw": "view",
    "vell": "well",
    "venacular": "vernacular",
    "venemous": "venomous",
    "vengance": "vengeance",
    "vengence": "vengeance",
    "verbaly": "verbally",
    "verfication": "verification",
    "verifed": "verified",
    "verifing": "verifying",
    "verion": "version",
    "verison": "version",
    "verisons": "versions",
    "verizion": "verizon",
    "vermillion": "vermilion",
    "versiion": "version",
    "versimilitude": "verisimilitude",
    "versitilaty": "versatility",
    "versitile": "versatile",
    "versitlity": "versatility",
    "versjon": "version",
    "verson": "version",
    "vertabra": "vertebra",
    "vertabrate": "vertebrate",
    "veryone": "everyone",
    "veryt": "very",
    "verzion": "verizon",
    "vesion": "version",
    "veted": "vetted",
    "veted": "voted",
    "veteren": "veteran",
    "vetinarian": "veterinarian",
    "vetinary": "veterinary",
    "vetran": "veteran",
    "vetween": "between",
    "vew": "view",
    "vey": "very",
    "veyr": "very",
    "vgood": "good",
    "vhrome": "chrome",
    "viaa": "via",
    "vicintity": "vicinity",
    "vicinty": "vicinity",
    "vicitms": "victims",
    "victem": "victim",
    "victems": "victims",
    "victimcs": "victims",
    "victin": "victim",
    "viction": "fiction",
    "victoms": "victims",
    "victums": "victims",
    "videeo": "video",
    "videl": "video",
    "videoo": "video",
    "videot": "video",
    "vidio": "video",
    "vidjeos": "videos",
    "vidoe": "video",
    "vidoes": "videos",
    "viedo": "video",
    "vieww": "view",
    "vifeo": "video",
    "vigilence": "vigilance",
    "vigilent": "vigilant",
    "vigourous": "vigorous",
    "vilage": "village",
    "vilager": "villager",
    "villian": "villain",
    "villianous": "villainous",
    "villification": "vilification",
    "villify": "vilify",
    "vincinity": "vicinity",
    "vinegrette": "vinaigrette",
    "vioce": "voice",
    "violance": "violence",
    "violatd": "violated",
    "violentce": "violence",
    "virsus": "virus",
    "virtualy": "virtually",
    "virtural": "virtual",
    "viruse": "virus",
    "virutal": "virtual",
    "virutally": "virtually",
    "visability": "visibility",
    "visable": "visible",
    "visably": "visibly",
    "visist": "visit",
    "visonary": "visionary",
    "vist": "visit",
    "vistation": "visitation",
    "visting": "visiting",
    "vistit": "visit",
    "vistors": "visitors",
    "visualy": "visually",
    "vitimin": "vitamin",
    "vitories": "victories",
    "vius": "virus",
    "vknow": "know",
    "vlick": "click",
    "vmail": "gmail",
    "vmail": "mail",
    "vneed": "need",
    "vocie": "voice",
    "vodafine": "vodafone",
    "vodfone": "vodafone",
    "voer": "over",
    "vogage": "vonage",
    "voicd": "voice",
    "voicemall": "voicemail",
    "voilence": "violence",
    "voilent": "violent",
    "voive": "voice",
    "volcanoe": "volcano",
    "voleyball": "volleyball",
    "volkswagon": "volkswagen",
    "vollyball": "volleyball",
    "volontary": "voluntary",
    "volonteer": "volunteer",
    "volonteered": "volunteered",
    "volonteering": "volunteering",
    "volonteers": "volunteers",
    "volounteer": "volunteer",
    "volounteered": "volunteered",
    "volounteering": "volunteering",
    "volounteers": "volunteers",
    "volp": "voip",
    "volumne": "volume",
    "vonamge": "vonage",
    "vonder": "wonder",
    "vonnage": "vonage",
    "vooice": "voice",
    "vorking": "working",
    "vouce": "voice",
    "vradio": "radio",
    "vreity": "variety",
    "vrey": "very",
    "vriety": "variety",
    "vry": "very",
    "vuew": "view",
    "vulcanic": "volcanic",
    "vulnerablility": "vulnerability",
    "vurtual": "virtual",
    "vury": "very",
    "vwallpaper": "wallpaper",
    "vwas": "was",
    "vwpwebhost": "wpwebhost",
    "vyer": "very",
    "vyre": "very",
    "vza": "via",
    "waait": "wait",
    "waaiting": "waiting",
    "waanna": "wanna",
    "waant": "want",
    "waat": "what",
    "waats": "whats",
    "waave": "wave",
    "waay": "way",
    "wached": "watched",
    "waching": "watching",
    "wacked": "walked",
    "wackey": "wacky",
    "wacthing": "watching",
    "waether": "whether",
    "wafe": "wave",
    "waht": "what",
    "wahtever": "whatever",
    "waiing": "waiting",
    "wainting": "waiting",
    "waiste": "waste",
    "waitig": "waiting",
    "waitimng": "waiting",
    "waitinf": "waiting",
    "waitn": "wait",
    "waitng": "waiting",
    "waitning": "waiting",
    "waitt": "wait",
    "waj": "way",
    "wak": "way",
    "walching": "watching",
    "walfram": "wolfram",
    "walkd": "walked",
    "wallgreens": "walgreens",
    "wallppers": "wallpapers",
    "walpaper": "wallpaper",
    "wanan": "wanna",
    "wanetd": "wanted",
    "wannaa": "wanna",
    "wannah": "wanna",
    "wanne": "wanna",
    "wannna": "wanna",
    "wannt": "want",
    "wantd": "want",
    "wantd": "wants",
    "wantn": "want",
    "wanto": "want",
    "wantr": "want",
    "wantt": "want",
    "wantz": "want",
    "wanz": "want",
    "waoit": "wait",
    "warantee": "warranty",
    "wardobe": "wardrobe",
    "warefare": "warfare",
    "warewolf": "werewolf",
    "warnung": "warning",
    "warrent": "warrant",
    "warrenty": "warranty",
    "warrriors": "warriors",
    "wasent": "wasnt",
    "washingt": "washing",
    "wasnt": "wasn't",
    "wass": "was",
    "wastle": "waste",
    "wasx": "was",
    "wasy": "ways",
    "wasys": "ways",
    "wasz": "was",
    "watchhing": "watching",
    "watchig": "watching",
    "watchimg": "watching",
    "watchingg": "watching",
    "watchn": "watch",
    "watchs": "watches",
    "watchted": "watched",
    "watcing": "watching",
    "wated": "wanted",
    "watever": "whatever",
    "watiching": "watching",
    "watn": "want",
    "watned": "wanted",
    "wavd": "wave",
    "wavebord": "waveboard",
    "waven": "wave",
    "wavev": "wave",
    "wavew": "wave",
    "wavez": "wave",
    "wavie": "wave",
    "wavte": "wave",
    "wavve": "wave",
    "wayword": "wayward",
    "wayy": "way",
    "waz": "was",
    "waz": "way",
    "wbsite": "website",
    "weae": "wear",
    "weakend": "weakened",
    "weally": "really",
    "weaponary": "weaponry",
    "weas": "was",
    "weatbher": "weather",
    "webcasted": "webcast",
    "webding": "wedding",
    "webiste": "website",
    "webmastr": "webmaster",
    "webmatser": "webmaster",
    "webstie": "website",
    "wecked": "wrecked",
    "weeek": "week",
    "weeekend": "weekend",
    "weeeks": "weeks",
    "weekendo": "weekend",
    "weekened": "weekend",
    "weekk": "week",
    "weeknd": "weekend",
    "wehn": "when",
    "weilded": "wielded",
    "weired": "weird",
    "weith": "with",
    "welcame": "welcomed",
    "welll": "well",
    "wellz": "well",
    "welome": "welcome",
    "wendsay": "Wednesday",
    "wendsday": "Wednesday",
    "wennt": "went",
    "wensday": "Wednesday",
    "weorks": "works",
    "werd": "were",
    "wereabouts": "whereabouts",
    "werid": "weird",
    "werking": "working",
    "wesbite": "website",
    "wesite": "website",
    "wft": "wtf",
    "wgb": "web",
    "wgich": "which",
    "whaat": "what",
    "whaever": "whatever",
    "whaf": "what",
    "whah": "what",
    "whan": "when",
    "whant": "want",
    "whant": "what",
    "whants": "wants",
    "whart": "what",
    "whas": "whats",
    "whatb": "what",
    "whatch": "watch",
    "whatching": "watching",
    "whatevr": "whatever",
    "whati": "what",
    "whatt": "what",
    "whatts": "whats",
    "whatwver": "whatever",
    "whaty": "what",
    "whatz": "whats",
    "whay": "why",
    "whch": "which",
    "whcih": "which",
    "whe": "who",
    "wheather": "weather",
    "wheck": "check",
    "wheelbarrel": "wheelbarrow",
    "whem": "when",
    "wheni": "when",
    "whenn": "when",
    "whent": "went",
    "wheny": "when",
    "wher": "when",
    "wherabouts": "whereabouts",
    "wheras": "whereas",
    "wherby": "whereby",
    "wherease": "whereas",
    "whereever": "wherever",
    "wherin": "wherein",
    "wherr": "where",
    "wheter": "whether",
    "whic": "which",
    "whick": "which",
    "whiel": "while",
    "whihc": "which",
    "whiich": "which",
    "whike": "while",
    "whill": "will",
    "whille": "while",
    "whilw": "while",
    "whitch": "which",
    "whith": "with",
    "whithout": "without",
    "whlch": "which",
    "whle": "whole",
    "whn": "when",
    "whnt": "what",
    "wholey": "wholly",
    "wholley": "wholly",
    "whon": "whom",
    "whould": "would",
    "whst": "what",
    "wht": "why",
    "wht": "wit",
    "whta": "what",
    "whtatever": "whatever",
    "whtever": "whatever",
    "whth": "with",
    "whther": "whether",
    "whts": "whats",
    "whut": "what",
    "whuts": "whats",
    "whwn": "when",
    "whyh": "why",
    "whyy": "why",
    "wiating": "waiting",
    "widespead": "widespread",
    "widesread": "widespread",
    "wief": "wife",
    "wieght": "weight",
    "wierd": "weird",
    "wiew": "view",
    "wih": "with",
    "wihout": "without",
    "wiht": "with",
    "wihtin": "within",
    "wihtout": "without",
    "wiife": "wife",
    "wiii": "wii",
    "wiill": "will",
    "wiith": "with",
    "wiji": "wii",
    "wikth": "with",
    "wille": "will",
    "williamx": "williams",
    "willingess": "willingness",
    "willingless": "willingness",
    "willk": "will",
    "willl": "will",
    "willling": "willing",
    "wimdow": "window",
    "windown": "window",
    "winnning": "winning",
    "winnser": "winner",
    "winodws": "windows",
    "wioth": "with",
    "wiphone": "iphone",
    "wirh": "with",
    "wirte": "write",
    "wirting": "writing",
    "wisdespread": "widespread",
    "wishh": "wish",
    "wishn": "wish",
    "wisi": "wish",
    "wistle": "whistle",
    "witchs": "witches",
    "witd": "with",
    "witha": "with",
    "withb": "with",
    "witheld": "withheld",
    "withen": "within",
    "withh": "with",
    "withi": "with",
    "withing": "within",
    "withold": "withhold",
    "withought": "without",
    "withoyt": "without",
    "witht": "with",
    "withthe": "with the",
    "witih": "with",
    "witj": "with",
    "witn": "with",
    "witout": "without",
    "witrhout": "without",
    "wittness": "witness",
    "wity": "with",
    "wiull": "will",
    "wiuth": "with",
    "wixh": "with",
    "wizh": "wish",
    "wjhat": "what",
    "wke": "woke",
    "wlak": "walk",
    "wlakee": "walkee",
    "wlcome": "welcome",
    "wlk": "walk",
    "wlrote": "wrote",
    "wmore": "more",
    "wnat": "want",
    "wnated": "wanted",
    "wnats": "wants",
    "wnen": "when",
    "wnidows": "windows",
    "wnna": "wanna",
    "wnted": "wanted",
    "wnts": "wants",
    "wny": "why",
    "wobbble": "wobble",
    "wodering": "wondering",
    "wodner": "wonder",
    "woek": "woke",
    "woeking": "working",
    "woerk": "work",
    "wofram": "wolfram",
    "wohle": "whole",
    "woice": "voice",
    "woild": "would",
    "woith": "with",
    "woiuld": "would",
    "wokee": "woke",
    "wokr": "work",
    "wokring": "working",
    "wokrs": "works",
    "wolrd": "world",
    "womder": "wonder",
    "womnder": "wonder",
    "wondee": "wonder",
    "wondeful": "wonderful",
    "wondeirng": "wondering",
    "wonderfull": "wonderful",
    "wonderling": "wondering",
    "wonderng": "wondering",
    "wonderr": "wonder",
    "wondes": "wonders",
    "wondr": "wonder",
    "wondreing": "wondering",
    "wondrful": "wonderful",
    "wondring": "wondering",
    "woner": "wonder",
    "wonidering": "wondering",
    "wonly": "only",
    "wonna": "wanna",
    "wonnder": "wonder",
    "wooble": "wobble",
    "wooried": "worried",
    "woorks": "works",
    "wordlwide": "worldwide",
    "wordpresss": "wordpress",
    "worh": "worth",
    "workd": "works",
    "workds": "works",
    "workersl": "workers",
    "workf": "work",
    "workg": "work",
    "workig": "working",
    "workign": "working",
    "workinn": "working",
    "workinq": "working",
    "workk": "work",
    "workn": "work",
    "workn": "works",
    "workss": "works",
    "workststion": "workstation",
    "workth": "worth",
    "worls": "world",
    "worlwide": "worldwide",
    "wornder": "wonder",
    "worng": "wrong",
    "worring": "working",
    "worrk": "work",
    "worrld": "world",
    "worrried": "worried",
    "worsten": "worsen",
    "worstened": "worsened",
    "worstening": "worsening",
    "worstt": "worst",
    "worx": "work",
    "wory": "worry",
    "wosh": "wish",
    "woth": "with",
    "woth": "worth",
    "wothout": "without",
    "wotking": "working",
    "woudl": "would",
    "wouid": "would",
    "woukd": "would",
    "woukld": "would",
    "woulb": "would",
    "wouldd": "would",
    "wouldt": "would",
    "woulld": "would",
    "woulndt": "wouldnt",
    "woulnt": "wouldnt",
    "woulod": "would",
    "woulsd": "would",
    "woundering": "wondering",
    "wount": "wont",
    "wouold": "would",
    "wouoldnt": "wouldnt",
    "wourth": "worth",
    "wowuld": "would",
    "wpisode": "episode",
    "wpuld": "would",
    "wqe": "we",
    "wqill": "will",
    "wqs": "was",
    "wrd": "word",
    "wre": "were",
    "wrecklessness": "recklessness",
    "wresters": "wrestlers",
    "wriet": "write",
    "writen": "written",
    "writte": "write",
    "wrk": "work",
    "wrkers": "workers",
    "wrking": "working",
    "wrks": "works",
    "wrld": "world",
    "wrng": "wrong",
    "wrning": "warning",
    "wroet": "wrote",
    "wrok": "work",
    "wroking": "working",
    "wrold": "world",
    "wrost": "worst",
    "wrst": "worst",
    "wrth": "with",
    "wsa": "was",
    "wsiting": "waiting",
    "wsnt": "want",
    "wssh": "wash",
    "wtaching": "watching",
    "wtch": "watch",
    "wtff": "wtf",
    "wtfh": "wtf",
    "wthile": "while",
    "wtih": "with",
    "wunder": "wonder",
    "wuold": "would",
    "wupport": "support",
    "wurk": "work",
    "wvae": "wave",
    "wve": "wave",
    "wwant": "want",
    "wwar": "war",
    "wwhat": "what",
    "wwhen": "when",
    "wwith": "with",
    "xcept": "except",
    "xchange": "change",
    "xcited": "excited",
    "xclusive": "exclusive",
    "xcuse": "excuse",
    "xenophoby": "xenophobia",
    "xgps": "gps",
    "xnd": "and",
    "xome": "come",
    "xos": "os",
    "xplain": "explain",
    "xstand": "stand",
    "xxploring": "exploring",
    "yaay": "yay",
    "yaching": "yachting",
    "yaeh": "yeah",
    "yaer": "year",
    "yaerly": "yearly",
    "yaers": "years",
    "yahooo": "yahoo",
    "yaht": "yacht",
    "yaoo": "yahoo",
    "yatch": "yacht",
    "yays": "says",
    "yayy": "yay",
    "yeaah": "yeah",
    "yeahh": "yeah",
    "yeam": "yeah",
    "yearh": "year",
    "yearm": "year",
    "yeasr": "years",
    "yeasterday": "yesterday",
    "yeay": "yay",
    "yeild": "yield",
    "yeilding": "yielding",
    "yera": "year",
    "yeras": "years",
    "yersa": "years",
    "yeseterday": "yesterday",
    "yesteday": "yesterday",
    "yesterdayy": "yesterday",
    "yesterrday": "yesterday",
    "yestserday": "yesterday",
    "yesturday": "yesterday",
    "yetz": "yet",
    "yhe": "the",
    "yhing": "thing",
    "yhink": "think",
    "yhoo": "yahoo",
    "yhu": "you",
    "yiou": "you",
    "yiu": "you",
    "ymail": "gmail",
    "yn": "on",
    "yoiu": "you",
    "yoou": "you",
    "yoprk": "york",
    "yotube": "youtube",
    "youc": "you",
    "youh": "you",
    "youh": "your",
    "youj": "you",
    "younce": "pounce",
    "youor": "your",
    "yourelf": "yourself",
    "yourr": "your",
    "yourslef": "yourself",
    "yourt": "your",
    "youseff": "yousef",
    "youself": "yourself",
    "youtbe": "youtube",
    "youtubee": "youtube",
    "youv": "you",
    "youy": "your",
    "ype": "type",
    "ypur": "your",
    "yrd": "yr",
    "yrea": "year",
    "yrying": "trying",
    "ytakin": "takin",
    "ythat": "that",
    "ything": "thing",
    "ytou": "you",
    "ytu": "you",
    "yuo": "you",
    "yuonger": "younger",
    "yurns": "turns",
    "yweet": "tweet",
    "yyou": "you",
    "zbt": "abt",
    "zeebra": "zebra",
    "zeland": "zealand",
    "zhe": "the",
    "zilliw": "zillow",
    "ziphone": "iphone",
    "zish": "wish",
    "zombielanda": "zombieland",
    "zooz": "zoo",
    "zshare": "share",
    "zwine": "swine"
}
